<?php
// Set path to your application root
$app_root = dirname(__DIR__);

// Include initialization file
require_once $app_root . '/config/init.php';

// Log file
$log_file = $app_root . '/logs/auto_bid.log';

// Function to log messages
function log_message($message) {
    global $log_file;
    $timestamp = date('Y-m-d H:i:s');
    file_put_contents($log_file, "[$timestamp] $message" . PHP_EOL, FILE_APPEND);
}

log_message("Auto bid process started");

try {
    // Get active auctions with recent bids
    $sql = "SELECT v.vehicle_id, v.current_bid, v.model, v.brand, v.make
            FROM vehicles v
            WHERE v.status = 'active'
            AND v.end_date > NOW()
            AND v.current_bid > 0";
    
    $result = $conn->query($sql);
    
    if ($result->num_rows > 0) {
        log_message("Found " . $result->num_rows . " active auctions with bids");
        
        while ($vehicle = $result->fetch_assoc()) {
            $vehicle_id = $vehicle['vehicle_id'];
            $current_bid = $vehicle['current_bid'];
            $vehicle_name = ($vehicle['brand'] ?: $vehicle['make']) . ' ' . $vehicle['model'];
            
            log_message("Processing vehicle ID: $vehicle_id - $vehicle_name, Current bid: $current_bid");
            
            // Get auto bids for this vehicle
            $auto_bid_sql = "SELECT b.*, u.username, u.email, u.notification_preferences
                            FROM bids b
                            JOIN users u ON b.bidder_id = u.user_id
                            WHERE b.vehicle_id = ?
                            AND b.is_auto_bid = 1
                            AND b.max_bid_amount > ?
                            AND b.bidder_id != (
                                SELECT bidder_id FROM bids 
                                WHERE vehicle_id = ? 
                                ORDER BY bid_amount DESC, bid_time ASC 
                                LIMIT 1
                            )
                            ORDER BY b.max_bid_amount DESC, b.bid_time ASC";
            
            $auto_bid_stmt = $conn->prepare($auto_bid_sql);
            $auto_bid_stmt->bind_param("idi", $vehicle_id, $current_bid, $vehicle_id);
            $auto_bid_stmt->execute();
            $auto_bid_result = $auto_bid_stmt->get_result();
            
            if ($auto_bid_result->num_rows > 0) {
                log_message("Found " . $auto_bid_result->num_rows . " auto bids for vehicle ID: $vehicle_id");
                
                // Get the highest auto bid
                $auto_bid = $auto_bid_result->fetch_assoc();
                $bidder_id = $auto_bid['bidder_id'];
                $username = $auto_bid['username'];
                $max_bid = $auto_bid['max_bid_amount'];
                $increment = $auto_bid['bid_increment'] > 0 ? $auto_bid['bid_increment'] : 100000;
                
                log_message("Processing auto bid for user: $username (ID: $bidder_id), Max bid: $max_bid, Increment: $increment");
                
                // Calculate new bid amount
                $new_bid = $current_bid + $increment;
                
                // Make sure new bid doesn't exceed max bid
                if ($new_bid > $max_bid) {
                    $new_bid = $max_bid;
                }
                
                log_message("New bid amount: $new_bid");
                
                // Start transaction
                $conn->begin_transaction();
                
                try {
                    // Insert new bid
                    $insert_sql = "INSERT INTO bids (vehicle_id, bidder_id, bid_amount, bid_time, is_auto_bid, max_bid_amount, bid_increment) 
                                  VALUES (?, ?, ?, NOW(), 1, ?, ?)";
                    $insert_stmt = $conn->prepare($insert_sql);
                    $insert_stmt->bind_param("iiddd", $vehicle_id, $bidder_id, $new_bid, $max_bid, $increment);
                    $insert_stmt->execute();
                    
                    // Update vehicle current bid
                    $update_sql = "UPDATE vehicles SET current_bid = ? WHERE vehicle_id = ?";
                    $update_stmt = $conn->prepare($update_sql);
                    $update_stmt->bind_param("di", $new_bid, $vehicle_id);
                    $update_stmt->execute();
                    
                    // Get previous highest bidder
                    $prev_bidder_sql = "SELECT b.bidder_id, u.username, u.email, u.notification_preferences
                                       FROM bids b
                                       JOIN users u ON b.bidder_id = u.user_id
                                       WHERE b.vehicle_id = ?
                                       AND b.bidder_id != ?
                                       ORDER BY b.bid_amount DESC, b.bid_time ASC
                                       LIMIT 1";
                    $prev_bidder_stmt = $conn->prepare($prev_bidder_sql);
                    $prev_bidder_stmt->bind_param("ii", $vehicle_id, $bidder_id);
                    $prev_bidder_stmt->execute();
                    $prev_bidder_result = $prev_bidder_stmt->get_result();
                    
                    if ($prev_bidder_result->num_rows > 0) {
                        $prev_bidder = $prev_bidder_result->fetch_assoc();
                        $prev_bidder_id = $prev_bidder['bidder_id'];
                        $prev_username = $prev_bidder['username'];
                        
                        log_message("Notifying previous highest bidder: $prev_username (ID: $prev_bidder_id)");
                        
                        // Send outbid notification
                        $outbid_title = "Anda Telah Dikalahkan";
                        $outbid_message = "Bid Anda untuk $vehicle_name telah dikalahkan. Bid tertinggi saat ini: Rp" . number_format($new_bid, 0, ',', '.');
                        
                        $notification_sql = "INSERT INTO notifications (user_id, type, title, message, is_read, created_at) 
                                           VALUES (?, 'outbid', ?, ?, 0, NOW())";
                        $notification_stmt = $conn->prepare($notification_sql);
                        $notification_stmt->bind_param("iss", $prev_bidder_id, $outbid_title, $outbid_message);
                        $notification_stmt->execute();
                        
                        // Send email notification if enabled
                        $preferences = json_decode($prev_bidder['notification_preferences'], true);
                        if (isset($preferences['email']) && $preferences['email'] && isset($preferences['bid_alerts']) && $preferences['bid_alerts']) {
                            if (function_exists('send_notification_email')) {
                                send_notification_email(
                                    $prev_bidder['email'],
                                    $prev_bidder['username'],
                                    $outbid_title,
                                    $outbid_message,
                                    "vehicle.php?id=$vehicle_id",
                                    "Lihat Lelang"
                                );
                                log_message("Outbid email sent to: " . $prev_bidder['email']);
                            }
                        }
                    }
                    
                    // Send notification to the auto bidder
                    $auto_bid_title = "Auto Bid Berhasil";
                    $auto_bid_message = "Auto bid Anda untuk $vehicle_name berhasil dengan jumlah Rp" . number_format($new_bid, 0, ',', '.');
                    
                    $auto_notification_sql = "INSERT INTO notifications (user_id, type, title, message, is_read, created_at) 
                                            VALUES (?, 'auto_bid', ?, ?, 0, NOW())";
                    $auto_notification_stmt = $conn->prepare($auto_notification_sql);
                    $auto_notification_stmt->bind_param("iss", $bidder_id, $auto_bid_title, $auto_bid_message);
                    $auto_notification_stmt->execute();
                    
                    // Send email notification if enabled
                    $auto_preferences = json_decode($auto_bid['notification_preferences'], true);
                    if (isset($auto_preferences['email']) && $auto_preferences['email'] && isset($auto_preferences['bid_alerts']) && $auto_preferences['bid_alerts']) {
                        if (function_exists('send_notification_email')) {
                            send_notification_email(
                                $auto_bid['email'],
                                $auto_bid['username'],
                                $auto_bid_title,
                                $auto_bid_message,
                                "vehicle.php?id=$vehicle_id",
                                "Lihat Lelang"
                            );
                            log_message("Auto bid email sent to: " . $auto_bid['email']);
                        }
                    }
                    
                    $conn->commit();
                    log_message("Auto bid successfully processed for vehicle ID: $vehicle_id");
                } catch (Exception $e) {
                    $conn->rollback();
                    log_message("Error processing auto bid: " . $e->getMessage());
                }
            } else {
                log_message("No auto bids found for vehicle ID: $vehicle_id");
            }
        }
    } else {
        log_message("No active auctions with bids found");
    }
} catch (Exception $e) {
    log_message("Error: " . $e->getMessage());
}

log_message("Auto bid process completed");
?>
