<?php
/**
 * Cache System
 * LelangMobil Web App - Versi 2025
 */

class Cache {
    private $cache_dir;
    private $cache_time;
    
    public function __construct($cache_dir = null, $cache_time = 3600) {
        $this->cache_dir = $cache_dir ?? dirname(__DIR__) . '/cache';
        $this->cache_time = $cache_time;
        
        // Create cache directory if it doesn't exist
        if (!file_exists($this->cache_dir)) {
            mkdir($this->cache_dir, 0755, true);
        }
    }
    
    /**
     * Get cached data
     * 
     * @param string $key Cache key
     * @return mixed|null Cached data or null if not found or expired
     */
    public function get($key) {
        $file = $this->getFilePath($key);
        
        if (!file_exists($file)) {
            return null;
        }
        
        $data = file_get_contents($file);
        $data = unserialize($data);
        
        if (!is_array($data) || !isset($data['expires']) || !isset($data['data'])) {
            return null;
        }
        
        if ($data['expires'] < time()) {
            $this->delete($key);
            return null;
        }
        
        return $data['data'];
    }
    
    /**
     * Set cached data
     * 
     * @param string $key Cache key
     * @param mixed $data Data to cache
     * @param int $time Cache time in seconds
     * @return bool Success or failure
     */
    public function set($key, $data, $time = null) {
        $file = $this->getFilePath($key);
        $time = $time ?? $this->cache_time;
        
        $cache_data = [
            'expires' => time() + $time,
            'data' => $data
        ];
        
        $cache_data = serialize($cache_data);
        
        return file_put_contents($file, $cache_data) !== false;
    }
    
    /**
     * Delete cached data
     * 
     * @param string $key Cache key
     * @return bool Success or failure
     */
    public function delete($key) {
        $file = $this->getFilePath($key);
        
        if (file_exists($file)) {
            return unlink($file);
        }
        
        return true;
    }
    
    /**
     * Clear all cached data
     * 
     * @return bool Success or failure
     */
    public function clear() {
        $files = glob($this->cache_dir . '/*.cache');
        
        foreach ($files as $file) {
            if (is_file($file)) {
                unlink($file);
            }
        }
        
        return true;
    }
    
    /**
     * Get file path for cache key
     * 
     * @param string $key Cache key
     * @return string File path
     */
    private function getFilePath($key) {
        return $this->cache_dir . '/' . md5($key) . '.cache';
    }
}

// Create cache instance
$cache = new Cache();

/**
 * Get cached query result or execute query and cache result
 * 
 * @param string $sql SQL query
 * @param array $params Query parameters
 * @param string $types Parameter types
 * @param int $cache_time Cache time in seconds
 * @return mixed Query result
 */
function db_query_cached($sql, $params = [], $types = "", $cache_time = 300) {
    global $cache;
    
    // Generate cache key
    $cache_key = 'db_query_' . md5($sql . serialize($params));
    
    // Try to get from cache
    $result = $cache->get($cache_key);
    
    if ($result !== null) {
        return $result;
    }
    
    // Execute query
    $result = db_query($sql, $params, $types);
    
    if ($result) {
        // Convert result to array
        $data = [];
        while ($row = $result->fetch_assoc()) {
            $data[] = $row;
        }
        
        // Cache result
        $cache->set($cache_key, $data, $cache_time);
        
        return $data;
    }
    
    return [];
}

/**
 * Get cached row or execute query and cache result
 * 
 * @param string $sql SQL query
 * @param array $params Query parameters
 * @param string $types Parameter types
 * @param int $cache_time Cache time in seconds
 * @return array|null Row as associative array or null if not found
 */
function db_get_row_cached($sql, $params = [], $types = "", $cache_time = 300) {
    global $cache;
    
    // Generate cache key
    $cache_key = 'db_get_row_' . md5($sql . serialize($params));
    
    // Try to get from cache
    $result = $cache->get($cache_key);
    
    if ($result !== null) {
        return $result;
    }
    
    // Execute query
    $result = db_get_row($sql, $params, $types);
    
    if ($result) {
        // Cache result
        $cache->set($cache_key, $result, $cache_time);
    }
    
    return $result;
}

/**
 * Get cached rows or execute query and cache result
 * 
 * @param string $sql SQL query
 * @param array $params Query parameters
 * @param string $types Parameter types
 * @param int $cache_time Cache time in seconds
 * @return array Array of rows as associative arrays
 */
function db_get_rows_cached($sql, $params = [], $types = "", $cache_time = 300) {
    global $cache;
    
    // Generate cache key
    $cache_key = 'db_get_rows_' . md5($sql . serialize($params));
    
    // Try to get from cache
    $result = $cache->get($cache_key);
    
    if ($result !== null) {
        return $result;
    }
    
    // Execute query
    $result = db_get_rows($sql, $params, $types);
    
    // Cache result
    $cache->set($cache_key, $result, $cache_time);
    
    return $result;
}

/**
 * Invalidate cache for a specific table
 * 
 * @param string $table Table name
 * @return bool Success or failure
 */
function invalidate_table_cache($table) {
    global $cache;
    
    $files = glob(dirname(__DIR__) . '/cache/db_*.cache');
    
    foreach ($files as $file) {
        $content = file_get_contents($file);
        $content = unserialize($content);
        
        if (isset($content['data']) && is_array($content['data'])) {
            // Check if cache contains data for this table
            $data_string = serialize($content['data']);
            
            if (strpos($data_string, $table) !== false) {
                // Delete cache file
                unlink($file);
            }
        }
    }
    
    return true;
}
?>