-- Database structure for Car Auction Website

-- Create database if not exists
CREATE DATABASE IF NOT EXISTS `lelangmobil`;

USE `lelangmobil`;

-- Users table
CREATE TABLE IF NOT EXISTS users (
    user_id INT AUTO_INCREMENT PRIMARY KEY,
    username VARCHAR(50) NOT NULL UNIQUE,
    email VARCHAR(100) NOT NULL UNIQUE,
    password VARCHAR(255) NOT NULL,
    full_name VARCHAR(100),
    phone VARCHAR(20),
    address TEXT,
    balance DECIMAL(10, 2) DEFAULT 0.00,
    is_verified BOOLEAN DEFAULT FALSE,
    verification_token VARCHAR(100),
    token_expiry DATETIME,
    reset_token VARCHAR(100),
    reset_token_expiry DATETIME,
    is_admin BOOLEAN DEFAULT FALSE,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
);

-- Vehicles table
CREATE TABLE IF NOT EXISTS vehicles (
    vehicle_id INT AUTO_INCREMENT PRIMARY KEY,
    title VARCHAR(100) NOT NULL,
    description TEXT,
    make VARCHAR(50),
    model VARCHAR(50),
    year INT,
    mileage INT,
    condition_rating INT, -- Scale of 1-10
    starting_price DECIMAL(10, 2) NOT NULL,
    reserve_price DECIMAL(10, 2),
    current_bid DECIMAL(10, 2),
    current_bidder INT,
    image_main VARCHAR(255),
    auction_start DATETIME NOT NULL,
    auction_end DATETIME NOT NULL,
    status ENUM('upcoming', 'active', 'ended', 'sold', 'not_sold') DEFAULT 'upcoming',
    seller_id INT,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN KEY (seller_id) REFERENCES users(user_id),
    FOREIGN KEY (current_bidder) REFERENCES users(user_id)
);

-- Vehicle Images table
CREATE TABLE IF NOT EXISTS vehicle_images (
    image_id INT AUTO_INCREMENT PRIMARY KEY,
    vehicle_id INT,
    image_url VARCHAR(255) NOT NULL,
    is_main BOOLEAN DEFAULT FALSE,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (vehicle_id) REFERENCES vehicles(vehicle_id) ON DELETE CASCADE
);

-- Vehicle Specifications table
CREATE TABLE IF NOT EXISTS vehicle_specs (
    spec_id INT AUTO_INCREMENT PRIMARY KEY,
    vehicle_id INT,
    spec_name VARCHAR(50) NOT NULL,
    spec_value VARCHAR(100) NOT NULL,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (vehicle_id) REFERENCES vehicles(vehicle_id) ON DELETE CASCADE
);

-- Bids table
CREATE TABLE IF NOT EXISTS bids (
    bid_id INT AUTO_INCREMENT PRIMARY KEY,
    vehicle_id INT,
    bidder_id INT,
    bid_amount DECIMAL(10, 2) NOT NULL,
    bid_time TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    is_winning BIT DEFAULT 0,
    FOREIGN KEY (vehicle_id) REFERENCES vehicles(vehicle_id) ON DELETE CASCADE,
    FOREIGN KEY (bidder_id) REFERENCES users(user_id)
);

-- Transactions table (for top-ups)
CREATE TABLE IF NOT EXISTS transactions (
    transaction_id INT AUTO_INCREMENT PRIMARY KEY,
    user_id INT,
    amount DECIMAL(10, 2) NOT NULL,
    type ENUM('deposit', 'withdrawal', 'bid_hold', 'bid_release', 'winning_payment') NOT NULL,
    status ENUM('pending', 'completed', 'rejected') DEFAULT 'pending',
    reference_id INT,
    reference_number VARCHAR(50),
    payment_method VARCHAR(50),
    bank_account VARCHAR(50),
    notes TEXT,
    admin_id INT,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN KEY (user_id) REFERENCES users(user_id),
    FOREIGN KEY (admin_id) REFERENCES users(user_id)
);

-- Settings table
CREATE TABLE IF NOT EXISTS settings (
    setting_key VARCHAR(100) PRIMARY KEY,
    setting_value TEXT,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
);

-- Insert default settings
INSERT INTO settings (setting_key, setting_value) VALUES
('site_title', 'LelangMobil - Platform Lelang Mobil Online Terpercaya'),
('site_description', 'Platform lelang mobil online terpercaya di Indonesia'),
('admin_email', 'admin@lelangmobil.com'),
('currency', 'Rp'),
('min_bid_increment_percent', '5'),
('smtp_host', 'mail.lelangmobil.com'),
('smtp_port', '465'),
('smtp_username', 'support@lelangmobil.com'),
('smtp_password', 'Arunk@123'),
('smtp_secure', 'ssl'),
('smtp_from_email', 'support@lelangmobil.com'),
('smtp_from_name', 'LelangMobil');
