/**
 * Account Ultra Modern JavaScript
 * Created: 3 May 2025
 * Supports interactive features for the ultra-modern account dashboard
 */

document.addEventListener('DOMContentLoaded', function() {
    // Ultra modern tab navigation
    initializeTabs();
    
    // File upload preview
    initializeFileUpload();
    
    // Preset amount buttons
    initializePresetButtons();
    
    // Bank selection
    initializeBankSelection();
    
    // 3D tilt effect for cards
    initializeCardTilt();
    
    // Animated counters
    initializeCounters();
});

/**
 * Initialize tab navigation system
 */
function initializeTabs() {
    const tabItems = document.querySelectorAll('.ultra-tab-item');
    const tabContents = document.querySelectorAll('.tab-pane');
    
    if (!tabItems.length) return;
    
    tabItems.forEach(tab => {
        tab.addEventListener('click', function() {
            // Remove active class from all tabs
            tabItems.forEach(item => item.classList.remove('active'));
            
            // Add active class to clicked tab
            this.classList.add('active');
            
            // Show corresponding content
            const tabId = this.getAttribute('data-tab');
            tabContents.forEach(content => {
                content.classList.remove('active');
                if (content.id === tabId) {
                    content.classList.add('active');
                    
                    // Add entrance animation
                    content.classList.add('fade-in');
                    setTimeout(() => {
                        content.classList.remove('fade-in');
                    }, 500);
                }
            });
        });
    });
}

/**
 * Initialize file upload preview
 */
function initializeFileUpload() {
    const fileInputs = document.querySelectorAll('.ultra-file-input');
    
    fileInputs.forEach(input => {
        const fileLabel = input.nextElementSibling;
        const selectedFile = fileLabel.querySelector('.selected-file');
        
        input.addEventListener('change', function(e) {
            if (this.files && this.files[0]) {
                const fileName = this.files[0].name;
                selectedFile.textContent = fileName;
                fileLabel.classList.add('has-file');
                
                // Show preview if it's an image
                const reader = new FileReader();
                reader.onload = function(e) {
                    selectedFile.innerHTML = `
                        <div class="file-preview">
                            <img src="${e.target.result}" alt="Preview">
                            <span class="file-name">${fileName}</span>
                        </div>
                    `;
                }
                reader.readAsDataURL(this.files[0]);
            } else {
                selectedFile.textContent = '';
                fileLabel.classList.remove('has-file');
            }
        });
        
        // Drag and drop functionality
        fileLabel.addEventListener('dragover', function(e) {
            e.preventDefault();
            this.classList.add('dragover');
        });
        
        fileLabel.addEventListener('dragleave', function() {
            this.classList.remove('dragover');
        });
        
        fileLabel.addEventListener('drop', function(e) {
            e.preventDefault();
            this.classList.remove('dragover');
            
            if (e.dataTransfer.files.length) {
                input.files = e.dataTransfer.files;
                
                // Trigger change event
                const event = new Event('change', { bubbles: true });
                input.dispatchEvent(event);
            }
        });
    });
}

/**
 * Initialize preset amount buttons
 */
function initializePresetButtons() {
    const presetButtons = document.querySelectorAll('.ultra-preset-btn');
    const amountInput = document.getElementById('amount');
    
    if (!presetButtons.length || !amountInput) return;
    
    presetButtons.forEach(button => {
        button.addEventListener('click', function() {
            const amount = this.getAttribute('data-amount');
            
            // Remove active class from all buttons
            presetButtons.forEach(btn => btn.classList.remove('active'));
            
            // Add active class to clicked button
            this.classList.add('active');
            
            // Set amount in input field with animation
            amountInput.value = '';
            let displayAmount = '';
            const amountStr = amount.toString();
            
            let i = 0;
            const typeInterval = setInterval(() => {
                displayAmount += amountStr.charAt(i);
                amountInput.value = displayAmount;
                i++;
                
                if (i >= amountStr.length) {
                    clearInterval(typeInterval);
                }
            }, 50);
        });
    });
    
    // Format amount input as currency
    amountInput.addEventListener('input', function() {
        let value = this.value.replace(/[^\d]/g, '');
        
        if (value) {
            // Format with thousand separator
            this.value = new Intl.NumberFormat('id-ID').format(value);
        }
    });
}

/**
 * Initialize bank selection
 */
function initializeBankSelection() {
    const bankOptions = document.querySelectorAll('.ultra-bank-option');
    
    bankOptions.forEach(option => {
        const radioInput = option.querySelector('input[type="radio"]');
        
        option.addEventListener('click', function() {
            // Uncheck all radios
            document.querySelectorAll('.ultra-bank-option input[type="radio"]').forEach(radio => {
                radio.checked = false;
                radio.closest('.ultra-bank-option').classList.remove('selected');
            });
            
            // Check clicked radio
            radioInput.checked = true;
            option.classList.add('selected');
        });
    });
}

/**
 * Initialize tilt effect for cards
 */
function initializeCardTilt() {
    const cards = document.querySelectorAll('.ultra-card, .ultra-profile, .ultra-stat-card');
    
    cards.forEach(card => {
        card.addEventListener('mousemove', function(e) {
            // Get card dimensions and mouse position
            const rect = this.getBoundingClientRect();
            const x = e.clientX - rect.left;
            const y = e.clientY - rect.top;
            
            // Calculate rotation values
            const centerX = rect.width / 2;
            const centerY = rect.height / 2;
            
            const rotateX = (y - centerY) / 20;
            const rotateY = (centerX - x) / 20;
            
            // Apply transform
            this.style.transform = `perspective(1000px) rotateX(${rotateX}deg) rotateY(${rotateY}deg) scale3d(1.02, 1.02, 1.02)`;
        });
        
        card.addEventListener('mouseleave', function() {
            // Reset transform
            this.style.transform = 'perspective(1000px) rotateX(0) rotateY(0) scale3d(1, 1, 1)';
        });
    });
}

/**
 * Initialize animated counters for statistics
 */
function initializeCounters() {
    const statValues = document.querySelectorAll('.ultra-stat-value');
    
    statValues.forEach(stat => {
        const finalValue = stat.textContent;
        
        // Check if it's a number or currency
        if (finalValue.includes('Rp')) {
            // Currency animation
            const numericValue = parseInt(finalValue.replace(/[^\d]/g, ''));
            animateCurrencyCounter(stat, numericValue);
        } else {
            // Number animation
            const numericValue = parseInt(finalValue.replace(/[^\d]/g, ''));
            animateCounter(stat, numericValue);
        }
    });
}

/**
 * Animate number counter
 */
function animateCounter(element, finalValue) {
    let startValue = 0;
    const duration = 1500;
    const increment = finalValue / (duration / 16);
    
    const counter = setInterval(() => {
        startValue += increment;
        
        if (startValue >= finalValue) {
            element.textContent = finalValue;
            clearInterval(counter);
        } else {
            element.textContent = Math.floor(startValue);
        }
    }, 16);
}

/**
 * Animate currency counter
 */
function animateCurrencyCounter(element, finalValue) {
    let startValue = 0;
    const duration = 1500;
    const increment = finalValue / (duration / 16);
    
    const counter = setInterval(() => {
        startValue += increment;
        
        if (startValue >= finalValue) {
            element.textContent = `Rp ${new Intl.NumberFormat('id-ID').format(finalValue)}`;
            clearInterval(counter);
        } else {
            element.textContent = `Rp ${new Intl.NumberFormat('id-ID').format(Math.floor(startValue))}`;
        }
    }, 16);
}
