/**
 * Auction Wallet Connector
 * Menghubungkan sistem auction dan wallet untuk integrasi yang seamless
 * Versi: 1.0 (Mei 2025)
 */

// Inisialisasi global state
const AuctionWalletConnector = {
    walletBalance: 0,
    holdAmount: 0,
    availableAmount: 0,
    activeBids: [],
    activeBidCount: 0,
    bidListeners: [],
    walletListeners: [],
    
    /**
     * Inisialisasi connector
     */
    init: function() {
        // Deteksi halaman auction atau wallet
        const isAuctionPage = document.querySelector('.vehicle-auction-container') !== null;
        const isWalletPage = document.querySelector('.wallet-tab-content') !== null;
        
        // Dapatkan data awal jika di halaman yang relevan
        if (isAuctionPage || isWalletPage) {
            this.fetchWalletInfo();
            this.setupEventListeners();
        }
        
        // Polling untuk update setiap 30 detik
        this.startPolling();
        
        // Integrasi dengan notification system
        this.integrateWithNotificationSystem();
        
        console.log("Auction Wallet Connector initialized.");
    },
    
    /**
     * Mengambil data wallet terbaru dari API
     */
    fetchWalletInfo: function() {
        fetch('/api/wallet-info.php', {
            method: 'GET',
            headers: {
                'Content-Type': 'application/json',
                'X-Requested-With': 'XMLHttpRequest'
            },
            credentials: 'same-origin'
        })
        .then(response => response.json())
        .then(data => {
            if (data.status === 'success') {
                this.walletBalance = parseFloat(data.balance);
                this.holdAmount = parseFloat(data.hold_amount);
                this.availableAmount = parseFloat(data.available_balance);
                this.activeBidCount = parseInt(data.active_bids_count);
                
                // Update UI elements
                this.updateWalletUI();
                
                // Notify listeners
                this.notifyWalletListeners({
                    type: 'wallet_update',
                    balance: this.walletBalance,
                    holdAmount: this.holdAmount,
                    availableAmount: this.availableAmount,
                    activeBidCount: this.activeBidCount
                });
                
                // Cache data untuk offline use
                this.cacheWalletData();
            } else {
                console.error('Error fetching wallet info:', data.message);
            }
        })
        .catch(error => {
            console.error('Failed to fetch wallet info:', error);
            // Fallback ke cached data jika koneksi bermasalah
            this.loadCachedWalletData();
        });
    },
    
    /**
     * Setup event listeners untuk komponen auction dan wallet
     */
    setupEventListeners: function() {
        // Listen untuk submit bid form
        const bidForm = document.getElementById('bid-form');
        if (bidForm) {
            bidForm.addEventListener('submit', (e) => {
                // Form akan di-submit via AJAX oleh vehicle-auction-2025.js
                // Kita hanya perlu mencatat event ini untuk monitoring
                this.notifyBidListeners({
                    type: 'bid_submit',
                    timestamp: new Date().toISOString()
                });
            });
        }
        
        // Listen untuk tombol Top-up
        const topupButtons = document.querySelectorAll('.btn-topup, .balance-action-btn-2025');
        topupButtons.forEach(button => {
            button.addEventListener('click', (e) => {
                // Tambahkan tracking untuk analytics (opsional)
                if (typeof gtag !== 'undefined') {
                    gtag('event', 'topup_click', {
                        'event_category': 'wallet',
                        'event_label': 'topup_button'
                    });
                }
            });
        });
    },
    
    /**
     * Update UI saldo/wallet di semua komponen
     */
    updateWalletUI: function() {
        // Format numbers untuk tampilan
        const formattedBalance = this.formatCurrency(this.walletBalance);
        const formattedHold = this.formatCurrency(this.holdAmount);
        const formattedAvailable = this.formatCurrency(this.availableAmount);
        
        // Update elemen balance umum
        document.querySelectorAll('.wallet-balance').forEach(el => {
            el.textContent = formattedBalance;
        });
        
        // Update elemen specific format
        document.querySelectorAll('[data-format="balance"]').forEach(el => {
            el.textContent = formattedBalance;
        });
        
        document.querySelectorAll('[data-format="hold"]').forEach(el => {
            el.textContent = formattedHold;
        });
        
        document.querySelectorAll('[data-format="available"]').forEach(el => {
            el.textContent = formattedAvailable;
        });
        
        // Update bid count
        document.querySelectorAll('.active-bids-count').forEach(el => {
            el.textContent = this.activeBidCount;
        });
        
        // Update CSS classes berdasarkan saldo
        this.updateBalanceStatusClasses();
    },
    
    /**
     * Update CSS classes berdasarkan status saldo
     */
    updateBalanceStatusClasses: function() {
        const balanceElements = document.querySelectorAll('.balance-amount-2025, .wallet-balance');
        
        balanceElements.forEach(el => {
            // Reset classes
            el.classList.remove('balance-low', 'balance-medium', 'balance-high');
            
            // Apply appropriate class
            if (this.walletBalance < 100000) {
                el.classList.add('balance-low');
            } else if (this.walletBalance < 1000000) {
                el.classList.add('balance-medium');
            } else {
                el.classList.add('balance-high');
            }
        });
    },
    
    /**
     * Format currency untuk tampilan
     */
    formatCurrency: function(amount) {
        return new Intl.NumberFormat('id-ID').format(amount);
    },
    
    /**
     * Integrasi dengan notification system
     */
    integrateWithNotificationSystem: function() {
        // Check if NotificationSystem exists
        if (typeof NotificationSystem !== 'undefined') {
            // Register bid success handler
            this.addBidListener(bidEvent => {
                if (bidEvent.type === 'bid_success') {
                    NotificationSystem.showNotification({
                        title: 'Bid Berhasil',
                        message: `Bid sebesar Rp ${this.formatCurrency(bidEvent.amount)} berhasil diproses`,
                        type: 'success',
                        duration: 5000
                    });
                    
                    // Update wallet setelah bid berhasil
                    setTimeout(() => this.fetchWalletInfo(), 1000);
                }
            });
            
            // Register wallet update handler
            this.addWalletListener(walletEvent => {
                if (walletEvent.type === 'wallet_update') {
                    // Tampilkan notifikasi hanya jika ada perubahan signifikan
                    const cachedBalance = parseFloat(localStorage.getItem('wallet_balance') || '0');
                    if (Math.abs(this.walletBalance - cachedBalance) > 1000) {
                        NotificationSystem.showNotification({
                            title: 'Saldo Diperbarui',
                            message: `Saldo Anda: Rp ${this.formatCurrency(this.walletBalance)}`,
                            type: 'info',
                            duration: 3000
                        });
                    }
                }
            });
        }
    },
    
    /**
     * Mulai polling untuk update data
     */
    startPolling: function() {
        // Update data setiap 30 detik
        setInterval(() => {
            this.fetchWalletInfo();
        }, 30000);
    },
    
    /**
     * Simpan data wallet ke localStorage
     */
    cacheWalletData: function() {
        try {
            localStorage.setItem('wallet_balance', this.walletBalance);
            localStorage.setItem('wallet_hold', this.holdAmount);
            localStorage.setItem('wallet_available', this.availableAmount);
            localStorage.setItem('wallet_bids_count', this.activeBidCount);
            localStorage.setItem('wallet_last_update', new Date().toISOString());
        } catch (e) {
            console.warn('Failed to cache wallet data:', e);
        }
    },
    
    /**
     * Load data wallet dari localStorage
     */
    loadCachedWalletData: function() {
        try {
            this.walletBalance = parseFloat(localStorage.getItem('wallet_balance') || '0');
            this.holdAmount = parseFloat(localStorage.getItem('wallet_hold') || '0');
            this.availableAmount = parseFloat(localStorage.getItem('wallet_available') || '0');
            this.activeBidCount = parseInt(localStorage.getItem('wallet_bids_count') || '0');
            
            // Update UI dengan data cached
            this.updateWalletUI();
        } catch (e) {
            console.warn('Failed to load cached wallet data:', e);
        }
    },
    
    /**
     * Register bid event listener
     */
    addBidListener: function(callback) {
        this.bidListeners.push(callback);
    },
    
    /**
     * Register wallet event listener
     */
    addWalletListener: function(callback) {
        this.walletListeners.push(callback);
    },
    
    /**
     * Notify bid listeners
     */
    notifyBidListeners: function(event) {
        this.bidListeners.forEach(listener => {
            try {
                listener(event);
            } catch (e) {
                console.error('Error in bid listener:', e);
            }
        });
    },
    
    /**
     * Notify wallet listeners
     */
    notifyWalletListeners: function(event) {
        this.walletListeners.forEach(listener => {
            try {
                listener(event);
            } catch (e) {
                console.error('Error in wallet listener:', e);
            }
        });
    }
};

// Initialize saat DOM ready
document.addEventListener('DOMContentLoaded', () => {
    AuctionWalletConnector.init();
});
