/**
 * DOM Safety
 * LelangMobil Web App - Versi 2025
 * 
 * Script untuk memperbaiki masalah DOM manipulation yang umum terjadi
 */

// Jalankan setelah DOM content loaded
document.addEventListener('DOMContentLoaded', function() {
  // Patch insertBefore method untuk mencegah error
  patchInsertBefore();
  
  // Patch appendChild method untuk mencegah error
  patchAppendChild();
  
  // Patch removeChild method untuk mencegah error
  patchRemoveChild();
  
  console.log('DOM safety patches applied');
});

/**
 * Patch insertBefore method untuk mencegah error
 * "Failed to execute 'insertBefore' on 'Node': The node before which the new node is to be inserted is not a child of this node."
 */
function patchInsertBefore() {
  const originalInsertBefore = Node.prototype.insertBefore;
  
  Node.prototype.insertBefore = function(newNode, referenceNode) {
    try {
      // Cek apakah referenceNode adalah child dari node ini
      if (referenceNode && !this.contains(referenceNode)) {
        console.warn('insertBefore: Reference node is not a child of this node, appending instead');
        return this.appendChild(newNode);
      }
      
      // Panggil method asli
      return originalInsertBefore.call(this, newNode, referenceNode);
    } catch (error) {
      console.error('Error in insertBefore:', error);
      // Fallback ke appendChild jika terjadi error
      return this.appendChild(newNode);
    }
  };
}

/**
 * Patch appendChild method untuk mencegah error
 */
function patchAppendChild() {
  const originalAppendChild = Node.prototype.appendChild;
  
  Node.prototype.appendChild = function(node) {
    try {
      // Panggil method asli
      return originalAppendChild.call(this, node);
    } catch (error) {
      console.error('Error in appendChild:', error);
      return null;
    }
  };
}

/**
 * Patch removeChild method untuk mencegah error
 */
function patchRemoveChild() {
  const originalRemoveChild = Node.prototype.removeChild;
  
  Node.prototype.removeChild = function(node) {
    try {
      // Cek apakah node adalah child dari node ini
      if (!this.contains(node)) {
        console.warn('removeChild: Node is not a child of this node');
        return node;
      }
      
      // Panggil method asli
      return originalRemoveChild.call(this, node);
    } catch (error) {
      console.error('Error in removeChild:', error);
      return node;
    }
  };
}

/**
 * Fungsi helper untuk menambahkan elemen ke DOM dengan aman
 */
function safeAppend(parent, child) {
  if (!parent || !child) {
    console.warn('safeAppend: Invalid parent or child node');
    return;
  }
  
  try {
    parent.appendChild(child);
  } catch (error) {
    console.error('Error in safeAppend:', error);
  }
}

/**
 * Fungsi helper untuk menghapus elemen dari DOM dengan aman
 */
function safeRemove(element) {
  if (!element) {
    console.warn('safeRemove: Invalid element');
    return;
  }
  
  try {
    if (element.parentNode) {
      element.parentNode.removeChild(element);
    }
  } catch (error) {
    console.error('Error in safeRemove:', error);
  }
}

// Expose helper functions globally
window.safeAppend = safeAppend;
window.safeRemove = safeRemove;