/**
 * Image Lazy Loading and Optimization
 */
class ImageLoader {
    constructor(options = {}) {
        this.options = {
            rootMargin: '50px 0px',
            threshold: 0.1,
            loadingClass: 'loading',
            loadedClass: 'loaded',
            errorClass: 'error',
            ...options
        };
        
        this.observer = null;
        this.init();
    }
    
    init() {
        // Check if IntersectionObserver is supported
        if ('IntersectionObserver' in window) {
            this.observer = new IntersectionObserver(this.onIntersection.bind(this), {
                rootMargin: this.options.rootMargin,
                threshold: this.options.threshold
            });
            
            // Observe all images with data-src attribute
            document.querySelectorAll('img[data-src]').forEach(img => {
                this.observer.observe(img);
            });
        } else {
            // Fallback for older browsers
            this.loadImagesImmediately();
        }
    }
    
    onIntersection(entries) {
        entries.forEach(entry => {
            if (entry.isIntersecting) {
                this.loadImage(entry.target);
                this.observer.unobserve(entry.target);
            }
        });
    }
    
    loadImage(img) {
        const src = img.dataset.src;
        if (!src) return;
        
        img.classList.add(this.options.loadingClass);
        
        // Create a temporary image to load
        const tempImg = new Image();
        
        tempImg.onload = () => {
            img.src = src;
            img.classList.remove(this.options.loadingClass);
            img.classList.add(this.options.loadedClass);
            this.removeDataAttributes(img);
        };
        
        tempImg.onerror = () => {
            img.classList.remove(this.options.loadingClass);
            img.classList.add(this.options.errorClass);
            console.error(`Failed to load image: ${src}`);
        };
        
        tempImg.src = src;
    }
    
    loadImagesImmediately() {
        document.querySelectorAll('img[data-src]').forEach(img => {
            this.loadImage(img);
        });
    }
    
    removeDataAttributes(img) {
        Object.keys(img.dataset).forEach(key => {
            delete img.dataset[key];
        });
    }
    
    // Helper method to generate responsive image srcset
    static generateSrcset(imagePath) {
        const sizes = [320, 640, 960, 1280];
        const srcset = sizes.map(size => {
            const path = imagePath.replace(/\.\w+$/, `-${size}w.jpg`);
            return `${path} ${size}w`;
        });
        return srcset.join(', ');
    }
    
    // Helper method to optimize image loading based on viewport
    static optimizeImageLoading(container) {
        const images = container.querySelectorAll('img[data-src]');
        const viewportWidth = window.innerWidth;
        
        images.forEach(img => {
            const containerWidth = img.parentElement.offsetWidth;
            const devicePixelRatio = window.devicePixelRatio || 1;
            const optimalWidth = containerWidth * devicePixelRatio;
            
            // Find the closest size in the srcset
            if (img.dataset.srcset) {
                const srcset = img.dataset.srcset.split(', ');
                let bestSrc = img.dataset.src;
                let bestWidth = Infinity;
                
                srcset.forEach(src => {
                    const [url, width] = src.split(' ');
                    const w = parseInt(width);
                    if (w >= optimalWidth && w < bestWidth) {
                        bestSrc = url;
                        bestWidth = w;
                    }
                });
                
                img.dataset.src = bestSrc;
            }
        });
    }
}

// Initialize image loader when DOM is ready
document.addEventListener('DOMContentLoaded', () => {
    const imageLoader = new ImageLoader();
    
    // Re-run optimization on window resize
    let resizeTimeout;
    window.addEventListener('resize', () => {
        clearTimeout(resizeTimeout);
        resizeTimeout = setTimeout(() => {
            ImageLoader.optimizeImageLoading(document.body);
        }, 250);
    });
});