/**
 * LelangMobil - Enhanced Image Uploader
 * This script handles the multi-image upload functionality with previews
 */

document.addEventListener('DOMContentLoaded', function() {
    // Initialize the image uploader if it exists on the page
    initImageUploader();
});

function initImageUploader() {
    const uploader = document.getElementById('vehicle-image-uploader');
    if (!uploader) return;

    const fileInput = document.getElementById('vehicle-images');
    const uploadArea = document.querySelector('.upload-area');
    const previewContainer = document.querySelector('.image-preview-list');
    const progressBar = document.querySelector('.upload-progress-value');
    const fileSizeWarning = document.querySelector('.file-size-warning');
    const fileTypeError = document.querySelector('.file-type-error');
    const imageCountElement = document.querySelector('.current-image-count');
    
    // Max file size (20MB in bytes)
    const MAX_FILE_SIZE = 20 * 1024 * 1024;
    
    // Max number of files
    const MAX_FILES = 20;
    
    // Allowed file types
    const ALLOWED_TYPES = ['image/jpeg', 'image/jpg', 'image/png'];
    
    // Store file objects for form submission
    let uploadedFiles = [];
    
    // Handle drag and drop events
    ['dragenter', 'dragover', 'dragleave', 'drop'].forEach(eventName => {
        uploadArea.addEventListener(eventName, preventDefaults, false);
    });
    
    function preventDefaults(e) {
        e.preventDefault();
        e.stopPropagation();
    }
    
    ['dragenter', 'dragover'].forEach(eventName => {
        uploadArea.addEventListener(eventName, highlight, false);
    });
    
    ['dragleave', 'drop'].forEach(eventName => {
        uploadArea.addEventListener(eventName, unhighlight, false);
    });
    
    function highlight() {
        uploadArea.classList.add('drag-over');
    }
    
    function unhighlight() {
        uploadArea.classList.remove('drag-over');
    }
    
    // Handle file drop
    uploadArea.addEventListener('drop', handleDrop, false);
    
    function handleDrop(e) {
        const dt = e.dataTransfer;
        const files = dt.files;
        
        if (files.length > 0) {
            handleFiles(files);
        }
    }
    
    // Handle file selection via input
    fileInput.addEventListener('change', function() {
        handleFiles(this.files);
    });
    
    function handleFiles(files) {
        // Check if adding these files would exceed the limit
        if (uploadedFiles.length + files.length > MAX_FILES) {
            alert(`Anda hanya dapat mengunggah maksimal ${MAX_FILES} gambar.`);
            return;
        }
        
        // Reset warnings
        fileSizeWarning.style.display = 'none';
        fileTypeError.style.display = 'none';
        
        Array.from(files).forEach(file => {
            // Check file type
            if (!ALLOWED_TYPES.includes(file.type)) {
                fileTypeError.style.display = 'block';
                fileTypeError.textContent = `File ${file.name} bukan format gambar yang valid (hanya JPG, JPEG, PNG).`;
                return;
            }
            
            // Check file size
            if (file.size > MAX_FILE_SIZE) {
                fileSizeWarning.style.display = 'block';
                fileSizeWarning.textContent = `File ${file.name} melebihi batas ukuran 20MB.`;
                return;
            }
            
            // Add valid file to our collection
            uploadedFiles.push({
                file: file,
                id: generateUniqueId(),
                isMain: uploadedFiles.length === 0, // First file is main by default
                caption: ''
            });
        });
        
        // Update UI
        renderPreviews();
        updateImageCount();
        
        // Clear the file input
        fileInput.value = '';
    }
    
    function renderPreviews() {
        // Clear the preview container
        previewContainer.innerHTML = '';
        
        // Generate preview for each file
        uploadedFiles.forEach((item, index) => {
            const preview = createPreviewElement(item, index);
            previewContainer.appendChild(preview);
        });
    }
    
    function createPreviewElement(item, index) {
        const previewItem = document.createElement('div');
        previewItem.className = 'image-preview-item';
        previewItem.dataset.id = item.id;
        
        // Create image preview
        const reader = new FileReader();
        reader.onload = function(e) {
            // Image container
            const imgWrap = document.createElement('div');
            imgWrap.className = 'preview-img-wrap';
            
            // Image element
            const img = document.createElement('img');
            img.src = e.target.result;
            img.className = 'preview-img';
            imgWrap.appendChild(img);
            
            // Main image badge if applicable
            if (item.isMain) {
                const mainBadge = document.createElement('div');
                mainBadge.className = 'main-image-badge';
                mainBadge.textContent = 'Utama';
                imgWrap.appendChild(mainBadge);
            }
            
            // Preview tools
            const tools = document.createElement('div');
            tools.className = 'preview-tools';
            
            // Delete button
            const deleteBtn = document.createElement('button');
            deleteBtn.className = 'preview-tool-btn delete';
            deleteBtn.innerHTML = '<i class="fa fa-trash"></i>';
            deleteBtn.title = 'Hapus';
            deleteBtn.addEventListener('click', function() {
                removeFile(item.id);
            });
            
            tools.appendChild(deleteBtn);
            imgWrap.appendChild(tools);
            
            // Order tools
            const orderTools = document.createElement('div');
            orderTools.className = 'image-order-tools';
            
            // Move left button (if not first)
            if (index > 0) {
                const moveLeftBtn = document.createElement('button');
                moveLeftBtn.className = 'order-btn';
                moveLeftBtn.innerHTML = '<i class="fa fa-arrow-left"></i>';
                moveLeftBtn.title = 'Pindah ke kiri';
                moveLeftBtn.addEventListener('click', function() {
                    moveFile(index, index - 1);
                });
                orderTools.appendChild(moveLeftBtn);
            }
            
            // Move right button (if not last)
            if (index < uploadedFiles.length - 1) {
                const moveRightBtn = document.createElement('button');
                moveRightBtn.className = 'order-btn';
                moveRightBtn.innerHTML = '<i class="fa fa-arrow-right"></i>';
                moveRightBtn.title = 'Pindah ke kanan';
                moveRightBtn.addEventListener('click', function() {
                    moveFile(index, index + 1);
                });
                orderTools.appendChild(moveRightBtn);
            }
            
            imgWrap.appendChild(orderTools);
            
            // Make main button (if not main)
            if (!item.isMain) {
                const makeMainBtn = document.createElement('button');
                makeMainBtn.className = 'make-main-btn';
                makeMainBtn.textContent = 'Jadikan Utama';
                makeMainBtn.addEventListener('click', function() {
                    setMainImage(item.id);
                });
                imgWrap.appendChild(makeMainBtn);
            }
            
            previewItem.appendChild(imgWrap);
            
            // Caption input
            const captionDiv = document.createElement('div');
            captionDiv.className = 'preview-caption';
            
            const captionInput = document.createElement('input');
            captionInput.type = 'text';
            captionInput.value = item.caption;
            captionInput.placeholder = 'Keterangan gambar...';
            captionInput.addEventListener('change', function() {
                updateCaption(item.id, this.value);
            });
            
            captionDiv.appendChild(captionInput);
            previewItem.appendChild(captionDiv);
            
            // File info badge
            const infoBadge = document.createElement('div');
            infoBadge.className = 'image-count-badge';
            const fileSize = (item.file.size / (1024 * 1024)).toFixed(1);
            infoBadge.textContent = `${fileSize}MB`;
            imgWrap.appendChild(infoBadge);
        };
        
        reader.readAsDataURL(item.file);
        return previewItem;
    }
    
    function removeFile(id) {
        // Find the index of the file to remove
        const index = uploadedFiles.findIndex(item => item.id === id);
        if (index === -1) return;
        
        // Check if we're removing the main image
        const wasMain = uploadedFiles[index].isMain;
        
        // Remove the file
        uploadedFiles.splice(index, 1);
        
        // If we removed the main image and we have other images, set a new main
        if (wasMain && uploadedFiles.length > 0) {
            uploadedFiles[0].isMain = true;
        }
        
        // Update UI
        renderPreviews();
        updateImageCount();
    }
    
    function moveFile(fromIndex, toIndex) {
        // Make sure indices are valid
        if (fromIndex < 0 || fromIndex >= uploadedFiles.length || 
            toIndex < 0 || toIndex >= uploadedFiles.length) {
            return;
        }
        
        // Reorder the array
        const item = uploadedFiles.splice(fromIndex, 1)[0];
        uploadedFiles.splice(toIndex, 0, item);
        
        // Update UI
        renderPreviews();
    }
    
    function setMainImage(id) {
        // Reset all files to non-main
        uploadedFiles.forEach(item => {
            item.isMain = false;
        });
        
        // Set the selected file as main
        const mainItem = uploadedFiles.find(item => item.id === id);
        if (mainItem) {
            mainItem.isMain = true;
        }
        
        // Update UI
        renderPreviews();
    }
    
    function updateCaption(id, caption) {
        const item = uploadedFiles.find(item => item.id === id);
        if (item) {
            item.caption = caption;
        }
    }
    
    function updateImageCount() {
        if (imageCountElement) {
            imageCountElement.textContent = uploadedFiles.length;
        }
    }
    
    function generateUniqueId() {
        return 'img_' + Math.random().toString(36).substr(2, 9);
    }
    
    // Handle form submission
    const vehicleForm = document.getElementById('add-vehicle-form');
    if (vehicleForm) {
        vehicleForm.addEventListener('submit', function(e) {
            if (uploadedFiles.length === 0) {
                // No images uploaded, but we'll let the required attribute handle this
                return;
            }
            
            // Show loading state
            uploader.classList.add('uploading');
            
            // Create a FormData object
            const formData = new FormData(this);
            
            // Remove any existing file inputs (they'll be replaced with our managed files)
            formData.delete('images[]');
            
            // Add each file to the form data
            uploadedFiles.forEach((item, index) => {
                // Add the file
                formData.append('images[]', item.file);
                
                // Add extra metadata
                formData.append('image_captions[]', item.caption);
                
                // For the main image
                if (item.isMain) {
                    formData.append('main_image_index', index);
                }
            });
            
            // Let the normal form submission continue
        });
    }
}
