/**
 * Multi-Step Form JavaScript
 * Controls navigation between steps, validation, and dynamic content
 */
document.addEventListener('DOMContentLoaded', function() {
    // Step navigation
    const steps = document.querySelectorAll('.step');
    const formSteps = document.querySelectorAll('.form-step');
    const nextButtons = document.querySelectorAll('.next-step');
    const prevButtons = document.querySelectorAll('.prev-step');
    
    // Initialize condition ratings if not already defined
    if (!window.conditionRatings) {
        window.conditionRatings = {
            "10": "Sempurna (10/10) - Seperti baru",
            "9": "Sangat Baik (9/10) - Hampir seperti baru",
            "8": "Baik (8/10) - Terawat dengan baik, minor wear",
            "7": "Baik (7/10) - Kondisi normal sesuai usia",
            "6": "Cukup Baik (6/10) - Beberapa masalah kecil",
            "5": "Rata-rata (5/10) - Beberapa perbaikan diperlukan",
            "4": "Di bawah rata-rata (4/10) - Membutuhkan perbaikan",
            "3": "Kurang Baik (3/10) - Masalah signifikan",
            "2": "Buruk (2/10) - Banyak komponen bermasalah",
            "1": "Sangat Buruk (1/10) - Kondisi tidak layak jalan"
        };
    }
    
    // Common features that can be added with a click
    const commonFeatures = [
        { name: "Air Conditioning", icon: "fa-snowflake" },
        { name: "Power Steering", icon: "fa-steering-wheel" },
        { name: "Power Windows", icon: "fa-window-maximize" },
        { name: "Central Lock", icon: "fa-lock" },
        { name: "ABS", icon: "fa-car-crash" },
        { name: "Airbags", icon: "fa-shield-alt" },
        { name: "Bluetooth", icon: "fa-bluetooth" },
        { name: "Touchscreen", icon: "fa-tablet-alt" },
        { name: "Backup Camera", icon: "fa-camera-retro" },
        { name: "Sunroof", icon: "fa-sun" },
        { name: "Alloy Wheels", icon: "fa-circle" },
        { name: "Parking Sensors", icon: "fa-parking" }
    ];
    
    // Common specs that can be added with a click
    const commonSpecs = [
        { name: "Wheel Drive", value: "FWD/RWD/AWD" },
        { name: "Jumlah Pintu", value: "4" },
        { name: "Jumlah Kursi", value: "5" },
        { name: "Power Output", value: "HP" },
        { name: "Torque", value: "Nm" },
        { name: "Fuel Tank Capacity", value: "Liter" },
        { name: "Ground Clearance", value: "mm" },
        { name: "Airbags", value: "2" },
        { name: "Wheelbase", value: "mm" }
    ];
    
    // Navigate to next step
    nextButtons.forEach(button => {
        button.addEventListener('click', function() {
            const currentStep = document.querySelector('.form-step.active');
            const currentStepIndex = Array.from(formSteps).indexOf(currentStep);
            
            if (validateStep(currentStepIndex)) {
                // Update step indicators
                steps[currentStepIndex].classList.add('completed');
                steps[currentStepIndex].classList.remove('active');
                steps[currentStepIndex + 1].classList.add('active');
                
                // Update form steps
                currentStep.classList.remove('active');
                formSteps[currentStepIndex + 1].classList.add('active');
                
                // If it's the final step, generate summary
                if (currentStepIndex + 1 === formSteps.length - 1) {
                    generateSummary();
                }
                
                // Scroll to top
                window.scrollTo({ top: 0, behavior: 'smooth' });
            }
        });
    });
    
    // Navigate to previous step
    prevButtons.forEach(button => {
        button.addEventListener('click', function() {
            const currentStep = document.querySelector('.form-step.active');
            const currentStepIndex = Array.from(formSteps).indexOf(currentStep);
            
            // Update step indicators
            steps[currentStepIndex].classList.remove('active');
            steps[currentStepIndex - 1].classList.remove('completed');
            steps[currentStepIndex - 1].classList.add('active');
            
            // Update form steps
            currentStep.classList.remove('active');
            formSteps[currentStepIndex - 1].classList.add('active');
            
            // Scroll to top
            window.scrollTo({ top: 0, behavior: 'smooth' });
        });
    });
    
    // Step indicator clicks
    steps.forEach((step, index) => {
        step.addEventListener('click', function() {
            // Only allow going to completed steps or next step
            const currentActiveIndex = Array.from(steps).findIndex(s => s.classList.contains('active'));
            
            if (index <= currentActiveIndex + 1) {
                // Remove active class from all steps
                steps.forEach(s => s.classList.remove('active'));
                formSteps.forEach(fs => fs.classList.remove('active'));
                
                // Update step indicators and form steps
                step.classList.add('active');
                formSteps[index].classList.add('active');
                
                // If it's the final step, generate summary
                if (index === formSteps.length - 1) {
                    generateSummary();
                }
            }
        });
    });
    
    // Validation for each step
    function validateStep(stepIndex) {
        let isValid = true;
        const currentStep = formSteps[stepIndex];
        
        // Find all required fields in the current step
        const requiredFields = currentStep.querySelectorAll('[required]');
        
        requiredFields.forEach(field => {
            // Reset previous validation visuals
            field.classList.remove('is-invalid');
            const errorMessage = field.parentElement.querySelector('.invalid-feedback');
            if (errorMessage) {
                errorMessage.remove();
            }
            
            // Check if field is empty
            if (!field.value) {
                isValid = false;
                field.classList.add('is-invalid');
                
                // Add error message
                const feedback = document.createElement('div');
                feedback.className = 'invalid-feedback';
                feedback.innerText = 'Field ini wajib diisi';
                field.parentElement.appendChild(feedback);
            }
        });
        
        // Step-specific validations
        if (stepIndex === 1) {
            // Price validations
            const startingPrice = parseFloat(document.getElementById('starting_price').value.replace(/\./g, '').replace(',', '.'));
            const reservePrice = document.getElementById('reserve_price').value ? parseFloat(document.getElementById('reserve_price').value.replace(/\./g, '').replace(',', '.')) : 0;
            const buyNowPrice = document.getElementById('buy_now_price').value ? parseFloat(document.getElementById('buy_now_price').value.replace(/\./g, '').replace(',', '.')) : 0;
            
            if (reservePrice > 0 && reservePrice < startingPrice) {
                isValid = false;
                document.getElementById('reserve_price').classList.add('is-invalid');
                
                const feedback = document.createElement('div');
                feedback.className = 'invalid-feedback';
                feedback.innerText = 'Harga minimum harus lebih besar dari atau sama dengan harga awal';
                document.getElementById('reserve_price').parentElement.appendChild(feedback);
            }
            
            if (buyNowPrice > 0 && buyNowPrice <= startingPrice) {
                isValid = false;
                document.getElementById('buy_now_price').classList.add('is-invalid');
                
                const feedback = document.createElement('div');
                feedback.className = 'invalid-feedback';
                feedback.innerText = 'Harga beli langsung harus lebih besar dari harga awal';
                document.getElementById('buy_now_price').parentElement.appendChild(feedback);
            }
            
            if (reservePrice > 0 && buyNowPrice > 0 && buyNowPrice <= reservePrice) {
                isValid = false;
                document.getElementById('buy_now_price').classList.add('is-invalid');
                
                const feedback = document.createElement('div');
                feedback.className = 'invalid-feedback';
                feedback.innerText = 'Harga beli langsung harus lebih besar dari harga minimum';
                document.getElementById('buy_now_price').parentElement.appendChild(feedback);
            }
        }
        
        return isValid;
    }
    
    // Feature management
    const addFeatureBtn = document.getElementById('add-feature');
    const featuresContainer = document.getElementById('features-container');
    const addCommonFeaturesBtn = document.getElementById('add-common-features');
    
    if (addFeatureBtn) {
        addFeatureBtn.addEventListener('click', function() {
            const featureIndex = document.querySelectorAll('.feature-item').length;
            const newFeature = document.createElement('div');
            newFeature.className = 'feature-item';
            newFeature.innerHTML = `
                <div class="row">
                    <div class="col-md-5">
                        <div class="form-group">
                            <input type="text" name="features[]" class="form-control" placeholder="Nama Fitur">
                        </div>
                    </div>
                    <div class="col-md-4">
                        <div class="form-group">
                            <input type="text" name="feature_icons[]" class="form-control" placeholder="Icon (fa-car)" value="fa-check">
                        </div>
                    </div>
                    <div class="col-md-2">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="feature_highlighted[${featureIndex}]" value="1">
                            <label class="form-check-label small">Highlight</label>
                        </div>
                    </div>
                    <div class="col-md-1">
                        <span class="feature-remove"><i class="fa fa-times"></i></span>
                    </div>
                </div>
            `;
            featuresContainer.appendChild(newFeature);
            
            // Add remove event handler
            newFeature.querySelector('.feature-remove').addEventListener('click', function() {
                featuresContainer.removeChild(newFeature);
                updateFeatureIndices();
            });
        });
    }
    
    // Add common features
    if (addCommonFeaturesBtn) {
        addCommonFeaturesBtn.addEventListener('click', function() {
            commonFeatures.forEach(feature => {
                // Check if this feature already exists
                const existingFeatures = Array.from(document.querySelectorAll('input[name="features[]"]')).map(input => input.value.toLowerCase());
                if (!existingFeatures.includes(feature.name.toLowerCase())) {
                    const featureIndex = document.querySelectorAll('.feature-item').length;
                    const newFeature = document.createElement('div');
                    newFeature.className = 'feature-item';
                    newFeature.innerHTML = `
                        <div class="row">
                            <div class="col-md-5">
                                <div class="form-group">
                                    <input type="text" name="features[]" class="form-control" value="${feature.name}">
                                </div>
                            </div>
                            <div class="col-md-4">
                                <div class="form-group">
                                    <input type="text" name="feature_icons[]" class="form-control" value="${feature.icon}">
                                </div>
                            </div>
                            <div class="col-md-2">
                                <div class="form-check">
                                    <input class="form-check-input" type="checkbox" name="feature_highlighted[${featureIndex}]" value="1">
                                    <label class="form-check-label small">Highlight</label>
                                </div>
                            </div>
                            <div class="col-md-1">
                                <span class="feature-remove"><i class="fa fa-times"></i></span>
                            </div>
                        </div>
                    `;
                    featuresContainer.appendChild(newFeature);
                    
                    // Add remove event handler
                    newFeature.querySelector('.feature-remove').addEventListener('click', function() {
                        featuresContainer.removeChild(newFeature);
                        updateFeatureIndices();
                    });
                }
            });
        });
    }
    
    // Existing feature remove handlers
    document.querySelectorAll('.feature-remove').forEach(button => {
        button.addEventListener('click', function() {
            const featureItem = this.closest('.feature-item');
            featureItem.parentNode.removeChild(featureItem);
            updateFeatureIndices();
        });
    });
    
    // Update feature highlight indices after removal
    function updateFeatureIndices() {
        const highlights = document.querySelectorAll('input[name^="feature_highlighted"]');
        highlights.forEach((highlight, index) => {
            highlight.name = `feature_highlighted[${index}]`;
        });
    }
    
    // Spec management
    const addSpecBtn = document.getElementById('add-spec');
    const specsContainer = document.getElementById('specifications-container');
    const addCommonSpecsBtn = document.getElementById('add-common-specs');
    
    if (addSpecBtn) {
        addSpecBtn.addEventListener('click', function() {
            const newSpec = document.createElement('div');
            newSpec.className = 'row g-2 mb-2 specification-row';
            newSpec.innerHTML = `
                <div class="col-md-5">
                    <input type="text" name="spec_name[]" class="form-control" placeholder="Nama Spesifikasi">
                </div>
                <div class="col-md-5">
                    <input type="text" name="spec_value[]" class="form-control" placeholder="Nilai">
                </div>
                <div class="col-md-2">
                    <button type="button" class="btn btn-danger remove-spec"><i class="fa fa-times"></i></button>
                </div>
            `;
            specsContainer.appendChild(newSpec);
            
            // Add remove handler
            newSpec.querySelector('.remove-spec').addEventListener('click', function() {
                specsContainer.removeChild(newSpec);
            });
        });
    }
    
    // Add common specs
    if (addCommonSpecsBtn) {
        addCommonSpecsBtn.addEventListener('click', function() {
            commonSpecs.forEach(spec => {
                // Check if this spec already exists
                const existingSpecs = Array.from(document.querySelectorAll('input[name="spec_name[]"]')).map(input => input.value.toLowerCase());
                if (!existingSpecs.includes(spec.name.toLowerCase())) {
                    const newSpec = document.createElement('div');
                    newSpec.className = 'row g-2 mb-2 specification-row';
                    newSpec.innerHTML = `
                        <div class="col-md-5">
                            <input type="text" name="spec_name[]" class="form-control" value="${spec.name}">
                        </div>
                        <div class="col-md-5">
                            <input type="text" name="spec_value[]" class="form-control" value="${spec.value}">
                        </div>
                        <div class="col-md-2">
                            <button type="button" class="btn btn-danger remove-spec"><i class="fa fa-times"></i></button>
                        </div>
                    `;
                    specsContainer.appendChild(newSpec);
                    
                    // Add remove handler
                    newSpec.querySelector('.remove-spec').addEventListener('click', function() {
                        specsContainer.removeChild(newSpec);
                    });
                }
            });
        });
    }
    
    // Existing spec remove handlers
    document.querySelectorAll('.remove-spec').forEach(button => {
        button.addEventListener('click', function() {
            if (specsContainer.children.length > 1) {
                const specRow = this.closest('.specification-row');
                specRow.parentNode.removeChild(specRow);
            }
        });
    });
    
    // Hide empty remove buttons
    document.querySelectorAll('.specification-row').forEach(row => {
        const inputs = row.querySelectorAll('input');
        const removeBtn = row.querySelector('.remove-spec');
        
        let hasValue = false;
        inputs.forEach(input => {
            if (input.value) {
                hasValue = true;
            }
        });
        
        if (hasValue && removeBtn) {
            removeBtn.style.display = 'block';
        }
    });
    
    // Show/hide specification remove button when fields have content
    document.addEventListener('input', function(e) {
        if (e.target.matches('input[name="spec_name[]"]') || e.target.matches('input[name="spec_value[]"]')) {
            const row = e.target.closest('.specification-row');
            const nameInput = row.querySelector('input[name="spec_name[]"]');
            const valueInput = row.querySelector('input[name="spec_value[]"]');
            const removeBtn = row.querySelector('.remove-spec');
            
            if ((nameInput.value || valueInput.value) && removeBtn) {
                removeBtn.style.display = 'block';
            } else if (removeBtn) {
                removeBtn.style.display = 'none';
            }
        }
    });
    
    // Image preview functionality
    const imageInput = document.getElementById('images');
    const imagePreview = document.getElementById('image-preview');
    
    if (imageInput && imagePreview) {
        imageInput.addEventListener('change', function() {
            // Clear previous preview except for empty message
            const emptyMessage = imagePreview.querySelector('.empty-preview-message');
            imagePreview.innerHTML = '';
            
            if (this.files.length > 0) {
                // Files selected, show previews
                Array.from(this.files).forEach((file, index) => {
                    // Validate file
                    if (!file.type.match('image.*')) {
                        return;
                    }
                    
                    const reader = new FileReader();
                    reader.onload = function(e) {
                        const col = document.createElement('div');
                        col.className = 'col-md-4 col-sm-6';
                        
                        const previewItem = document.createElement('div');
                        previewItem.className = 'image-preview-item';
                        
                        // Badge for main photo
                        if (index === 0) {
                            const badge = document.createElement('div');
                            badge.className = 'image-preview-badge';
                            badge.innerHTML = 'Foto Utama';
                            previewItem.appendChild(badge);
                        }
                        
                        // Image
                        const img = document.createElement('img');
                        img.src = e.target.result;
                        img.alt = 'Preview';
                        previewItem.appendChild(img);
                        
                        // Caption
                        const caption = document.createElement('div');
                        caption.className = 'image-preview-caption';
                        caption.innerHTML = `
                            <div class="form-group">
                                <input type="text" name="image_captions[]" class="form-control form-control-sm" placeholder="Caption untuk foto ini" maxlength="100">
                            </div>
                            <div class="small text-muted mt-1">${file.name} (${(file.size / 1024 / 1024).toFixed(2)} MB)</div>
                        `;
                        previewItem.appendChild(caption);
                        
                        col.appendChild(previewItem);
                        imagePreview.appendChild(col);
                    };
                    
                    reader.readAsDataURL(file);
                });
            } else {
                // No files selected, show empty message
                imagePreview.appendChild(emptyMessage);
            }
        });
    }
    
    // Inspection report toggle
    const hasInspection = document.getElementById('has_inspection');
    const inspectionDetails = document.getElementById('inspection-details');
    
    if (hasInspection && inspectionDetails) {
        hasInspection.addEventListener('change', function() {
            if (this.checked) {
                inspectionDetails.style.display = 'block';
            } else {
                inspectionDetails.style.display = 'none';
            }
        });
    }
    
    // Generate summary on final step
    function generateSummary() {
        const summaryContainer = document.getElementById('vehicle-summary');
        if (!summaryContainer) return;
        
        // Extract form data
        const make = document.getElementById('make').value;
        const model = document.getElementById('model').value;
        const year = document.getElementById('year').value;
        const title = document.getElementById('title').value;
        const bodyType = document.getElementById('body_type').value;
        const color = document.getElementById('color').value;
        const mileage = document.getElementById('mileage').value;
        const transmission = document.getElementById('transmission').value;
        const fuelType = document.getElementById('fuel_type').value;
        const engineSize = document.getElementById('engine_size').value;
        const condition = document.getElementById('condition_rating').value;
        const location = document.getElementById('location').value;
        
        // Price info
        const startingPrice = document.getElementById('starting_price').value;
        const reservePrice = document.getElementById('reserve_price').value;
        const buyNowPrice = document.getElementById('buy_now_price').value;
        const auctionEnd = document.getElementById('auction_end').value;
        const isFeatured = document.getElementById('featured').checked;
        
        // Build HTML
        let summaryHTML = `
            <div class="summary-section">
                <h5>Informasi Dasar Kendaraan</h5>
                <div class="row">
                    <div class="col-md-6">
                        <p><strong>Judul:</strong> ${title}</p>
                        <p><strong>Merek/Model:</strong> ${make} ${model} (${year})</p>
                        <p><strong>Tipe Bodi:</strong> ${bodyType}</p>
                        <p><strong>Warna:</strong> ${color}</p>
                    </div>
                    <div class="col-md-6">
                        <p><strong>Kilometrage:</strong> ${mileage} KM</p>
                        <p><strong>Transmisi:</strong> ${transmission}</p>
                        <p><strong>Bahan Bakar:</strong> ${fuelType}</p>
                        <p><strong>Kapasitas Mesin:</strong> ${engineSize || '-'} CC</p>
                    </div>
                </div>
                <p><strong>Kondisi:</strong> ${window.conditionRatings[condition] || `Rating ${condition}/10`}</p>
                <p><strong>Lokasi:</strong> ${location}</p>
            </div>
            
            <div class="summary-section">
                <h5>Informasi Lelang</h5>
                <div class="row">
                    <div class="col-md-6">
                        <p><strong>Harga Awal:</strong> Rp ${startingPrice}</p>
                        <p><strong>Harga Minimum:</strong> ${reservePrice ? `Rp ${reservePrice}` : 'Tidak ada'}</p>
                    </div>
                    <div class="col-md-6">
                        <p><strong>Harga Beli Langsung:</strong> ${buyNowPrice ? `Rp ${buyNowPrice}` : 'Tidak ada'}</p>
                        <p><strong>Berakhir pada:</strong> ${formatDateTime(auctionEnd)}</p>
                    </div>
                </div>
                <p><strong>Status:</strong> ${isFeatured ? '<span class="badge bg-primary">Lelang Unggulan</span>' : '<span class="badge bg-secondary">Lelang Biasa</span>'}</p>
            </div>
        `;
        
        // Add Features section if available
        const features = document.querySelectorAll('input[name="features[]"]');
        if (features.length > 0) {
            let featuresHTML = '<div class="summary-section"><h5>Fitur Kendaraan</h5><ul class="feature-summary-list">';
            features.forEach((feature, index) => {
                if (feature.value) {
                    featuresHTML += `<li>${feature.value}</li>`;
                }
            });
            featuresHTML += '</ul></div>';
            summaryHTML += featuresHTML;
        }
        
        // Add Specs section if available
        const specNames = document.querySelectorAll('input[name="spec_name[]"]');
        const specValues = document.querySelectorAll('input[name="spec_value[]"]');
        let hasSpecs = false;
        
        for (let i = 0; i < specNames.length; i++) {
            if (specNames[i].value && specValues[i].value) {
                hasSpecs = true;
                break;
            }
        }
        
        if (hasSpecs) {
            let specsHTML = '<div class="summary-section"><h5>Spesifikasi Teknis</h5><div class="row">';
            for (let i = 0; i < specNames.length; i++) {
                if (specNames[i].value && specValues[i].value) {
                    specsHTML += `
                        <div class="col-md-6">
                            <p><strong>${specNames[i].value}:</strong> ${specValues[i].value}</p>
                        </div>
                    `;
                }
            }
            specsHTML += '</div></div>';
            summaryHTML += specsHTML;
        }
        
        // Add inspection section if available
        if (hasInspection && hasInspection.checked) {
            const inspectorName = document.getElementById('inspector_name').value;
            const inspectionDate = document.getElementById('inspection_date').value;
            const inspectionDetailsText = document.getElementById('inspection_details_text').value;
            const inspectionFile = document.getElementById('inspection_file').value;
            
            if (inspectorName || inspectionDate || inspectionDetailsText) {
                summaryHTML += `
                    <div class="summary-section">
                        <h5>Laporan Inspeksi</h5>
                        <p><strong>Inspektor/Bengkel:</strong> ${inspectorName || '-'}</p>
                        <p><strong>Tanggal Inspeksi:</strong> ${inspectionDate || '-'}</p>
                        <p><strong>Ringkasan:</strong> ${inspectionDetailsText || '-'}</p>
                        <p><strong>File Inspeksi:</strong> ${inspectionFile ? 'Terlampir' : 'Tidak ada'}</p>
                    </div>
                `;
            }
        }
        
        // Add photo info
        const images = document.getElementById('images');
        if (images && images.files.length > 0) {
            summaryHTML += `
                <div class="summary-section">
                    <h5>Foto Kendaraan</h5>
                    <p><strong>Jumlah Foto:</strong> ${images.files.length} foto</p>
                </div>
            `;
        }
        
        summaryContainer.innerHTML = summaryHTML;
    }
    
    // Helper: Format datetime for summary
    function formatDateTime(dateTimeString) {
        if (!dateTimeString) return '-';
        
        const dt = new Date(dateTimeString);
        return dt.toLocaleString('id-ID', {
            day: 'numeric',
            month: 'long',
            year: 'numeric',
            hour: '2-digit',
            minute: '2-digit'
        });
    }
    
    // Number formatting
    const formatNumberInputs = document.querySelectorAll('.format-number');
    formatNumberInputs.forEach(input => {
        input.addEventListener('input', function(e) {
            // Get value and remove non-digits
            let value = this.value.replace(/\D/g, '');
            
            // Add thousand separators
            if (value.length > 0) {
                value = parseInt(value).toLocaleString('id-ID');
            }
            
            this.value = value;
        });
    });
    
    // Price formatting
    const formatPriceInputs = document.querySelectorAll('.format-price');
    formatPriceInputs.forEach(input => {
        input.addEventListener('input', function(e) {
            // Get value and remove non-digits
            let value = this.value.replace(/\D/g, '');
            
            // Add thousand separators
            if (value.length > 0) {
                value = parseInt(value).toLocaleString('id-ID');
            }
            
            this.value = value;
        });
    });
});
