/**
 * Modern Notification System 2025
 * LelangMobil Web App - Versi 2025
 */

class NotificationSystem2025 {
  constructor(options = {}) {
    this.options = {
      position: options.position || 'top-right',
      duration: options.duration || 5000,
      maxNotifications: options.maxNotifications || 5,
      container: options.container || document.body,
      sound: options.sound !== undefined ? options.sound : true,
      soundFile: options.soundFile || 'assets/notification-sound.mp3',
      animation: options.animation || 'slide',
      theme: options.theme || 'light',
      zIndex: options.zIndex || 9999,
      closeOnClick: options.closeOnClick !== undefined ? options.closeOnClick : true,
      pauseOnHover: options.pauseOnHover !== undefined ? options.pauseOnHover : true,
      showProgressBar: options.showProgressBar !== undefined ? options.showProgressBar : true,
      newestOnTop: options.newestOnTop !== undefined ? options.newestOnTop : true,
      clickCallback: options.clickCallback || null,
      closeCallback: options.closeCallback || null,
      showCallback: options.showCallback || null,
    };
    
    this.notifications = [];
    this.notificationCount = 0;
    this.audioElement = null;
    
    this.init();
  }
  
  init() {
    // Create container if it doesn't exist
    this.container = document.querySelector('.notification-container-2025');
    if (!this.container) {
      this.container = document.createElement('div');
      this.container.className = 'notification-container-2025';
      this.options.container.appendChild(this.container);
    }
    
    // Set position
    this.container.style.position = 'fixed';
    switch (this.options.position) {
      case 'top-left':
        this.container.style.top = '20px';
        this.container.style.left = '20px';
        break;
      case 'top-center':
        this.container.style.top = '20px';
        this.container.style.left = '50%';
        this.container.style.transform = 'translateX(-50%)';
        break;
      case 'top-right':
        this.container.style.top = '20px';
        this.container.style.right = '20px';
        break;
      case 'bottom-left':
        this.container.style.bottom = '20px';
        this.container.style.left = '20px';
        break;
      case 'bottom-center':
        this.container.style.bottom = '20px';
        this.container.style.left = '50%';
        this.container.style.transform = 'translateX(-50%)';
        break;
      case 'bottom-right':
        this.container.style.bottom = '20px';
        this.container.style.right = '20px';
        break;
    }
    
    // Set z-index
    this.container.style.zIndex = this.options.zIndex;
    
    // Create audio element for notification sound
    if (this.options.sound) {
      this.audioElement = document.createElement('audio');
      this.audioElement.src = this.options.soundFile;
      this.audioElement.setAttribute('preload', 'auto');
      this.audioElement.setAttribute('hidden', 'true');
      document.body.appendChild(this.audioElement);
    }
    
    // Initialize notification bell if exists
    this.initNotificationBell();
    
    // Initialize notification dropdown if exists
    this.initNotificationDropdown();
  }
  
  initNotificationBell() {
    const bell = document.querySelector('.notification-bell-2025');
    if (bell) {
      bell.addEventListener('click', (e) => {
        e.preventDefault();
        e.stopPropagation();
        
        const dropdown = document.querySelector('.notification-dropdown-2025');
        if (dropdown) {
          dropdown.classList.toggle('show');
          
          // Remove unread indicator when dropdown is opened
          const badge = bell.querySelector('.notification-badge-2025');
          if (badge) {
            badge.style.display = 'none';
          }
          
          // Mark notifications as read
          const unreadItems = dropdown.querySelectorAll('.notification-dropdown-2025-item.unread');
          unreadItems.forEach(item => {
            item.classList.remove('unread');
            
            // Send read status to server
            const notificationId = item.dataset.id;
            if (notificationId) {
              this.markAsRead(notificationId);
            }
          });
        }
      });
      
      // Close dropdown when clicking outside
      document.addEventListener('click', (e) => {
        const dropdown = document.querySelector('.notification-dropdown-2025');
        if (dropdown && dropdown.classList.contains('show') && !dropdown.contains(e.target) && !bell.contains(e.target)) {
          dropdown.classList.remove('show');
        }
      });
    }
  }
  
  initNotificationDropdown() {
    const dropdown = document.querySelector('.notification-dropdown-2025');
    if (dropdown) {
      // Handle mark all as read
      const markAllReadBtn = dropdown.querySelector('.mark-all-read');
      if (markAllReadBtn) {
        markAllReadBtn.addEventListener('click', (e) => {
          e.preventDefault();
          
          const unreadItems = dropdown.querySelectorAll('.notification-dropdown-2025-item.unread');
          unreadItems.forEach(item => {
            item.classList.remove('unread');
            
            // Send read status to server
            const notificationId = item.dataset.id;
            if (notificationId) {
              this.markAsRead(notificationId);
            }
          });
          
          // Remove badge
          const badge = document.querySelector('.notification-bell-2025 .notification-badge-2025');
          if (badge) {
            badge.style.display = 'none';
          }
          
          // Show success message
          this.show({
            title: 'Sukses',
            message: 'Semua notifikasi telah ditandai sebagai dibaca',
            type: 'success'
          });
        });
      }
      
      // Handle notification item click
      const items = dropdown.querySelectorAll('.notification-dropdown-2025-item');
      items.forEach(item => {
        item.addEventListener('click', () => {
          // Mark as read
          item.classList.remove('unread');
          
          // Send read status to server
          const notificationId = item.dataset.id;
          if (notificationId) {
            this.markAsRead(notificationId);
          }
          
          // Handle redirect if has link
          const link = item.dataset.link;
          if (link) {
            window.location.href = link;
          }
        });
      });
    }
  }
  
  markAsRead(notificationId) {
    // Send AJAX request to mark notification as read
    fetch('api/notifications.php', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify({
        action: 'mark_read',
        notification_id: notificationId
      })
    })
    .then(response => response.json())
    .then(data => {
      if (data.success) {
        console.log('Notification marked as read');
      }
    })
    .catch(error => {
      console.error('Error marking notification as read:', error);
    });
  }
  
  show(options) {
    // Check if we've reached the maximum number of notifications
    if (this.notifications.length >= this.options.maxNotifications) {
      // Remove the oldest notification
      this.close(this.notifications[0].id);
    }
    
    const id = 'notification-' + (++this.notificationCount);
    
    // Create notification element
    const notification = document.createElement('div');
    notification.className = `notification-2025 notification-2025-${options.type || 'info'}`;
    notification.id = id;
    notification.innerHTML = `
      <div class="notification-2025-icon">
        ${this.getIconForType(options.type)}
      </div>
      <div class="notification-2025-content">
        <div class="notification-2025-title">${options.title || 'Notification'}</div>
        <div class="notification-2025-message">${options.message || ''}</div>
      </div>
      <div class="notification-2025-close">
        <i class="fa fa-times"></i>
      </div>
      ${this.options.showProgressBar ? '<div class="notification-2025-progress"><div class="notification-2025-progress-bar"></div></div>' : ''}
    `;
    
    // Add to DOM
    if (this.options.newestOnTop) {
      this.container.prepend(notification);
    } else {
      this.container.appendChild(notification);
    }
    
    // Store notification data
    const notificationData = {
      id,
      element: notification,
      timeout: null,
      startTime: new Date(),
      duration: options.duration || this.options.duration,
      remaining: options.duration || this.options.duration,
      paused: false
    };
    
    this.notifications.push(notificationData);
    
    // Add event listeners
    const closeButton = notification.querySelector('.notification-2025-close');
    closeButton.addEventListener('click', () => this.close(id));
    
    if (this.options.closeOnClick) {
      notification.addEventListener('click', (e) => {
        if (e.target !== closeButton && !closeButton.contains(e.target)) {
          this.close(id);
          
          // Execute click callback if provided
          if (typeof this.options.clickCallback === 'function') {
            this.options.clickCallback(options);
          }
          
          // Handle redirect if has link
          if (options.link) {
            window.location.href = options.link;
          }
        }
      });
    }
    
    if (this.options.pauseOnHover) {
      notification.addEventListener('mouseenter', () => this.pause(id));
      notification.addEventListener('mouseleave', () => this.resume(id));
    }
    
    // Play sound
    if (this.options.sound && this.audioElement) {
      this.audioElement.play().catch(e => console.log('Error playing notification sound:', e));
    }
    
    // Animate in
    setTimeout(() => {
      notification.classList.add('show');
      
      // Execute show callback if provided
      if (typeof this.options.showCallback === 'function') {
        this.options.showCallback(options);
      }
      
      // Start progress bar animation
      if (this.options.showProgressBar) {
        const progressBar = notification.querySelector('.notification-2025-progress-bar');
        progressBar.style.transition = `width ${notificationData.duration}ms linear`;
        progressBar.style.width = '0%';
      }
      
      // Auto close after duration
      notificationData.timeout = setTimeout(() => {
        this.close(id);
      }, notificationData.duration);
    }, 10);
    
    return id;
  }
  
  pause(id) {
    const notification = this.notifications.find(n => n.id === id);
    if (notification && !notification.paused) {
      notification.paused = true;
      clearTimeout(notification.timeout);
      
      // Calculate remaining time
      const elapsed = new Date() - notification.startTime;
      notification.remaining = notification.duration - elapsed;
      
      // Pause progress bar
      if (this.options.showProgressBar) {
        const progressBar = notification.element.querySelector('.notification-2025-progress-bar');
        const width = (elapsed / notification.duration) * 100;
        progressBar.style.transition = 'none';
        progressBar.style.width = `${100 - width}%`;
      }
    }
  }
  
  resume(id) {
    const notification = this.notifications.find(n => n.id === id);
    if (notification && notification.paused) {
      notification.paused = false;
      notification.startTime = new Date() - (notification.duration - notification.remaining);
      
      // Resume progress bar
      if (this.options.showProgressBar) {
        const progressBar = notification.element.querySelector('.notification-2025-progress-bar');
        progressBar.style.transition = `width ${notification.remaining}ms linear`;
        progressBar.style.width = '0%';
      }
      
      // Resume timeout
      notification.timeout = setTimeout(() => {
        this.close(id);
      }, notification.remaining);
    }
  }
  
  close(id) {
    const index = this.notifications.findIndex(n => n.id === id);
    if (index !== -1) {
      const notification = this.notifications[index];
      
      // Clear timeout
      clearTimeout(notification.timeout);
      
      // Remove from DOM with animation
      notification.element.classList.remove('show');
      
      setTimeout(() => {
        if (notification.element.parentNode) {
          notification.element.parentNode.removeChild(notification.element);
        }
        
        // Remove from notifications array
        this.notifications.splice(index, 1);
        
        // Execute close callback if provided
        if (typeof this.options.closeCallback === 'function') {
          this.options.closeCallback(id);
        }
      }, 500); // Match the CSS transition duration
    }
  }
  
  closeAll() {
    // Create a copy of the array to avoid issues during iteration
    const notificationsCopy = [...this.notifications];
    notificationsCopy.forEach(notification => {
      this.close(notification.id);
    });
  }
  
  getIconForType(type) {
    switch (type) {
      case 'success':
        return '<i class="fa fa-check-circle"></i>';
      case 'error':
        return '<i class="fa fa-exclamation-circle"></i>';
      case 'warning':
        return '<i class="fa fa-exclamation-triangle"></i>';
      case 'info':
      default:
        return '<i class="fa fa-info-circle"></i>';
    }
  }
  
  // Helper methods for common notification types
  success(options) {
    return this.show({
      type: 'success',
      ...options
    });
  }
  
  error(options) {
    return this.show({
      type: 'error',
      ...options
    });
  }
  
  warning(options) {
    return this.show({
      type: 'warning',
      ...options
    });
  }
  
  info(options) {
    return this.show({
      type: 'info',
      ...options
    });
  }
  
  // Update notification bell badge
  updateBadge(count) {
    const bell = document.querySelector('.notification-bell-2025');
    if (bell) {
      let badge = bell.querySelector('.notification-badge-2025');
      
      if (count > 0) {
        if (!badge) {
          badge = document.createElement('span');
          badge.className = 'notification-badge-2025';
          bell.appendChild(badge);
        }
        
        badge.textContent = count > 99 ? '99+' : count;
        badge.style.display = 'flex';
        
        // Add animation to bell
        bell.classList.add('active');
        setTimeout(() => {
          bell.classList.remove('active');
        }, 1000);
      } else if (badge) {
        badge.style.display = 'none';
      }
    }
  }
  
  // Load notifications from server
  loadNotifications(url = 'api/notifications.php', container = '.notification-dropdown-2025-body') {
    const notificationContainer = document.querySelector(container);
    if (!notificationContainer) return;
    
    // Show loading state
    notificationContainer.innerHTML = '<div class="text-center p-3"><i class="fa fa-spinner fa-spin"></i> Loading...</div>';
    
    fetch(url)
      .then(response => response.json())
      .then(data => {
        if (data.success) {
          if (data.notifications && data.notifications.length > 0) {
            notificationContainer.innerHTML = '';
            
            data.notifications.forEach(notification => {
              const item = document.createElement('div');
              item.className = `notification-dropdown-2025-item ${notification.is_read ? '' : 'unread'}`;
              item.dataset.id = notification.notification_id;
              if (notification.link) {
                item.dataset.link = notification.link;
              }
              
              item.innerHTML = `
                <div class="notification-dropdown-2025-item-icon ${notification.type || 'info'}">
                  ${this.getIconForType(this.mapNotificationType(notification.type))}
                </div>
                <div class="notification-dropdown-2025-item-content">
                  <div class="notification-dropdown-2025-item-title">${notification.title}</div>
                  <div class="notification-dropdown-2025-item-message">${notification.message}</div>
                  <div class="notification-dropdown-2025-item-time">${this.formatTimeAgo(notification.created_at)}</div>
                </div>
              `;
              
              notificationContainer.appendChild(item);
              
              // Add click event
              item.addEventListener('click', () => {
                // Mark as read
                if (!notification.is_read) {
                  item.classList.remove('unread');
                  this.markAsRead(notification.notification_id);
                }
                
                // Handle redirect if has link
                if (notification.link) {
                  window.location.href = notification.link;
                }
              });
            });
            
            // Update badge
            const unreadCount = data.notifications.filter(n => !n.is_read).length;
            this.updateBadge(unreadCount);
          } else {
            notificationContainer.innerHTML = `
              <div class="notification-empty-2025">
                <i class="fa fa-bell-slash"></i>
                <p>Tidak ada notifikasi</p>
              </div>
            `;
          }
        } else {
          notificationContainer.innerHTML = `
            <div class="notification-empty-2025">
              <i class="fa fa-exclamation-circle"></i>
              <p>Gagal memuat notifikasi</p>
            </div>
          `;
        }
      })
      .catch(error => {
        console.error('Error loading notifications:', error);
        notificationContainer.innerHTML = `
          <div class="notification-empty-2025">
            <i class="fa fa-exclamation-circle"></i>
            <p>Gagal memuat notifikasi</p>
          </div>
        `;
      });
  }
  
  // Map notification type from server to display type
  mapNotificationType(type) {
    const typeMap = {
      'transaction': 'info',
      'payment': 'success',
      'alert': 'error',
      'info': 'info',
      'system': 'warning',
      'success': 'success',
      'error': 'error',
      'warning': 'warning'
    };
    
    return typeMap[type] || 'info';
  }
  
  // Format time ago
  formatTimeAgo(timestamp) {
    const now = new Date();
    const date = new Date(timestamp);
    const seconds = Math.floor((now - date) / 1000);
    
    let interval = Math.floor(seconds / 31536000);
    if (interval >= 1) {
      return interval + ' tahun yang lalu';
    }
    
    interval = Math.floor(seconds / 2592000);
    if (interval >= 1) {
      return interval + ' bulan yang lalu';
    }
    
    interval = Math.floor(seconds / 86400);
    if (interval >= 1) {
      return interval + ' hari yang lalu';
    }
    
    interval = Math.floor(seconds / 3600);
    if (interval >= 1) {
      return interval + ' jam yang lalu';
    }
    
    interval = Math.floor(seconds / 60);
    if (interval >= 1) {
      return interval + ' menit yang lalu';
    }
    
    if (seconds < 10) {
      return 'baru saja';
    }
    
    return Math.floor(seconds) + ' detik yang lalu';
  }
}

// Initialize notification system
document.addEventListener('DOMContentLoaded', function() {
  // Create global notification instance
  window.notificationSystem = new NotificationSystem2025({
    position: 'top-right',
    duration: 5000,
    sound: true,
    showProgressBar: true,
    pauseOnHover: true,
    newestOnTop: true
  });
  
  // Load notifications if dropdown exists
  const notificationDropdown = document.querySelector('.notification-dropdown-2025');
  if (notificationDropdown) {
    window.notificationSystem.loadNotifications();
  }
  
  // Check for flash messages
  const flashMessages = document.querySelectorAll('.flash-message');
  flashMessages.forEach(flash => {
    const type = flash.dataset.type || 'info';
    const title = flash.dataset.title || 'Notifikasi';
    const message = flash.textContent.trim();
    
    if (message) {
      window.notificationSystem.show({
        type,
        title,
        message
      });
    }
    
    // Remove flash message from DOM
    flash.parentNode.removeChild(flash);
  });
});