/**
 * Premium Tilt Effect untuk LelangMobil
 * Versi: 2.1 (2025-05-02)
 * 
 * Efek 3D tilt untuk tema otomotif premium
 */

// Impor library vanilla-tilt jika belum ada
if (typeof VanillaTilt === 'undefined') {
    const script = document.createElement('script');
    script.src = 'https://cdnjs.cloudflare.com/ajax/libs/vanilla-tilt/1.7.2/vanilla-tilt.min.js';
    script.async = true;
    document.head.appendChild(script);
    console.log('Vanilla-tilt library loaded dynamically');
}

document.addEventListener('DOMContentLoaded', function() {
    // Inisialisasi efek tilt pada semua elemen dengan class js-tilt-card
    initTiltEffect();
    
    // Inisialisasi animasi speedometer
    initSpeedometerEffects();
    
    // Inisialisasi animasi counter
    initCounterAnimation();
});

/**
 * Inisialisasi efek tilt 3D pada card
 */
function initTiltEffect() {
    const tiltElements = document.querySelectorAll('.js-tilt-card');
    
    tiltElements.forEach(element => {
        // Efek tilt hanya untuk desktop
        if (window.innerWidth >= 992) {
            element.addEventListener('mousemove', handleTilt);
            element.addEventListener('mouseleave', resetTilt);
        }
    });
}

/**
 * Handle efek tilt saat mouse bergerak
 * @param {Event} e Mouse event
 */
function handleTilt(e) {
    const card = this;
    const cardRect = card.getBoundingClientRect();
    const centerX = cardRect.left + cardRect.width / 2;
    const centerY = cardRect.top + cardRect.height / 2;
    const mouseX = e.clientX - centerX;
    const mouseY = e.clientY - centerY;
    
    // Kekuatan tilt (makin kecil nilai, makin kuat efeknya)
    const tiltStrength = 25;
    
    // Hitung rotasi
    const rotateX = mouseY / tiltStrength * -1;
    const rotateY = mouseX / tiltStrength;
    
    // Terapkan transformasi
    card.style.transform = `perspective(1000px) rotateX(${rotateX}deg) rotateY(${rotateY}deg) scale3d(1.05, 1.05, 1.05)`;
    
    // Efek highlight mengikuti cursor
    const glareElements = card.querySelectorAll('.ultra-stat-icon, .balance-icon');
    glareElements.forEach(element => {
        // Kalkulasi posisi highlight relatif terhadap mouse
        const elementRect = element.getBoundingClientRect();
        const elementCenterX = elementRect.left + elementRect.width / 2;
        const elementCenterY = elementRect.top + elementRect.height / 2;
        const distanceX = e.clientX - elementCenterX;
        const distanceY = e.clientY - elementCenterY;
        
        // Terapkan efek shadow bergerak
        element.style.boxShadow = `
            ${-distanceX / 15}px ${-distanceY / 15}px 15px rgba(255, 255, 255, 0.1),
            ${distanceX / 30}px ${distanceY / 30}px 30px rgba(0, 0, 0, 0.2)
        `;
    });
}

/**
 * Reset posisi card saat mouse keluar
 */
function resetTilt() {
    // Reset transformasi
    this.style.transform = 'perspective(1000px) rotateX(0) rotateY(0) scale3d(1, 1, 1)';
    
    // Reset efek highlight
    const glareElements = this.querySelectorAll('.ultra-stat-icon, .balance-icon');
    glareElements.forEach(element => {
        element.style.boxShadow = '';
    });
}

/**
 * Inisialisasi efek speedometer
 */
function initSpeedometerEffects() {
    // Animasi balancer-icon
    const balanceIcons = document.querySelectorAll('.balance-icon');
    balanceIcons.forEach(icon => {
        // Tambahkan coin elements
        for (let i = 0; i < 3; i++) {
            const coin = document.createElement('div');
            coin.className = 'coin';
            coin.style.left = `${Math.random() * 30}px`;
            coin.style.top = `${Math.random() * 30}px`;
            coin.style.animationDelay = `${Math.random() * 2}s`;
            icon.appendChild(coin);
        }
    });
    
    // Efek speedometer pada container
    const containers = document.querySelectorAll('.account-container');
    containers.forEach(container => {
        window.addEventListener('scroll', () => {
            const scrollY = window.scrollY;
            // Efek parallax pada background speedometer
            if (scrollY < 500) {
                container.style.setProperty('--speed-rotation', `${scrollY / 10}deg`);
            }
        });
    });
}

/**
 * Inisialisasi animasi counter untuk angka
 */
function initCounterAnimation() {
    const counterElements = document.querySelectorAll('.count-number');
    
    // Observe elements untuk animasi saat terlihat
    const observer = new IntersectionObserver((entries) => {
        entries.forEach(entry => {
            if (entry.isIntersecting) {
                animateCounter(entry.target);
                observer.unobserve(entry.target);
            }
        });
    }, { threshold: 0.1 });
    
    counterElements.forEach(counter => {
        observer.observe(counter);
    });
}

/**
 * Animasi penghitung untuk elemen
 * @param {HTMLElement} element Element yang akan dianimasi
 */
function animateCounter(element) {
    const target = parseInt(element.getAttribute('data-target'));
    const duration = 2000; // 2 detik
    const start = Date.now();
    const startValue = 0;
    
    // Fungsi step untuk animasi
    const step = () => {
        const now = Date.now();
        const elapsed = now - start;
        const progress = Math.min(elapsed / duration, 1);
        
        // Efek easing
        const easedProgress = cubicEaseOut(progress);
        const currentValue = Math.floor(startValue + (target - startValue) * easedProgress);
        
        // Update nilai
        element.textContent = currentValue.toLocaleString();
        
        if (progress < 1) {
            requestAnimationFrame(step);
        } else {
            element.textContent = target.toLocaleString();
        }
    };
    
    requestAnimationFrame(step);
}

/**
 * Cubic ease out function untuk animasi lebih natural
 * @param {number} t Nilai progress 0-1
 * @returns {number} Nilai easing
 */
function cubicEaseOut(t) {
    return 1 - Math.pow(1 - t, 3);
}
