/**
 * Register Service Worker
 * LelangMobil Web App - Versi 2025
 */

document.addEventListener('DOMContentLoaded', function() {
  if ('serviceWorker' in navigator) {
    navigator.serviceWorker.register('/service-worker.js')
      .then(registration => {
        console.log('Service Worker registered with scope:', registration.scope);
        initPushNotifications(registration);
      })
      .catch(error => {
        console.error('Service Worker registration failed:', error);
      });
  }
});

/**
 * Initialize Push Notifications
 */
function initPushNotifications(registration) {
  // Check if user is logged in
  const userIdMeta = document.querySelector('meta[name="user-id"]');
  if (!userIdMeta) return;
  
  // Check if push notifications are supported
  if (!('PushManager' in window)) {
    console.log('Push notifications not supported');
    return;
  }
  
  // Check notification permission
  if (Notification.permission === 'granted') {
    subscribeToPushNotifications(registration);
  } else if (Notification.permission !== 'denied') {
    // Ask for permission
    const notificationButton = document.createElement('div');
    notificationButton.className = 'notification-permission-button';
    notificationButton.innerHTML = '<i class="fa fa-bell"></i>';
    notificationButton.title = 'Aktifkan Notifikasi';
    
    notificationButton.addEventListener('click', function() {
      requestNotificationPermission(registration);
      this.remove();
    });
    
    document.body.appendChild(notificationButton);
  }
}

/**
 * Request Notification Permission
 */
function requestNotificationPermission(registration) {
  Notification.requestPermission()
    .then(permission => {
      if (permission === 'granted') {
        console.log('Notification permission granted');
        subscribeToPushNotifications(registration);
      } else {
        console.log('Notification permission denied');
      }
    });
}

/**
 * Subscribe to Push Notifications
 */
function subscribeToPushNotifications(registration) {
  const userId = document.querySelector('meta[name="user-id"]').content;
  
  // Get server's public key
  fetch('/api/push-key.php')
    .then(response => response.json())
    .then(data => {
      if (!data.publicKey) {
        throw new Error('Public key not available');
      }
      
      const applicationServerKey = urlB64ToUint8Array(data.publicKey);
      
      // Subscribe
      return registration.pushManager.subscribe({
        userVisibleOnly: true,
        applicationServerKey: applicationServerKey
      });
    })
    .then(subscription => {
      // Send subscription to server
      return fetch('/api/push-subscribe.php', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json'
        },
        body: JSON.stringify({
          userId: userId,
          subscription: subscription
        })
      });
    })
    .then(response => response.json())
    .then(data => {
      if (data.success) {
        console.log('Push notification subscription successful');
      } else {
        console.error('Push notification subscription failed:', data.message);
      }
    })
    .catch(error => {
      console.error('Error subscribing to push notifications:', error);
    });
}

/**
 * Convert base64 to Uint8Array
 */
function urlB64ToUint8Array(base64String) {
  const padding = '='.repeat((4 - base64String.length % 4) % 4);
  const base64 = (base64String + padding)
    .replace(/\-/g, '+')
    .replace(/_/g, '/');
  
  const rawData = window.atob(base64);
  const outputArray = new Uint8Array(rawData.length);
  
  for (let i = 0; i < rawData.length; ++i) {
    outputArray[i] = rawData.charCodeAt(i);
  }
  
  return outputArray;
}