/**
 * Modern Vehicle Page JavaScript
 * LelangMobil Premium - Enhanced Vehicle Detail View
 */

document.addEventListener('DOMContentLoaded', function() {
    // Image gallery handling
    initializeGallery();
    
    // Countdown timer
    initializeCountdown();
    
    // 3D tilt effect for vehicle cards
    initializeTiltEffect();
    
    // Modern spotlight cursor effect
    initializeSpotlightEffect();
    
    // Add animations for page elements
    animateElements();
});

/**
 * Initialize image gallery interactions
 */
function initializeGallery() {
    const thumbnails = document.querySelectorAll('.ultra-thumbnail');
    const carousel = document.getElementById('carouselGallery');
    
    if (!carousel) return;
    
    // Bootstrap carousel already handles most functionality
    // Additional interaction for thumbnails
    thumbnails.forEach(thumb => {
        thumb.addEventListener('click', function() {
            // Remove active class from all thumbnails
            thumbnails.forEach(t => t.classList.remove('active'));
            // Add active class to clicked thumbnail
            this.classList.add('active');
            
            // Get the slide index from the thumbnail's data attribute
            const slideIndex = this.getAttribute('data-bs-slide-to');
            
            // Create and dispatch a custom event
            const slideEvent = new CustomEvent('slide-to', {
                detail: { slideIndex: slideIndex }
            });
            carousel.dispatchEvent(slideEvent);
        });
    });
    
    // Add zoom effect for gallery images
    const galleryImages = document.querySelectorAll('.carousel-item img');
    galleryImages.forEach(img => {
        img.addEventListener('click', function() {
            this.classList.toggle('zoomed');
            
            if (this.classList.contains('zoomed')) {
                this.style.transform = 'scale(1.5)';
                this.style.cursor = 'zoom-out';
            } else {
                this.style.transform = 'scale(1)';
                this.style.cursor = 'zoom-in';
            }
        });
    });
}

/**
 * Initialize countdown timer for auctions
 */
function initializeCountdown() {
    const timerElement = document.getElementById('auction-timer');
    if (!timerElement) return;
    
    const timerData = timerElement.dataset;
    if (!timerData.seconds) return;
    
    let totalSeconds = parseInt(timerData.seconds);
    const auctionEnded = timerData.ended === 'true';
    
    if (auctionEnded) {
        timerElement.innerHTML = '<span class="time-label">Lelang telah berakhir</span>';
        return;
    }
    
    function updateTimer() {
        if (totalSeconds <= 0) {
            timerElement.innerHTML = '<span class="time-label">Lelang telah berakhir</span>';
            return;
        }
        
        const days = Math.floor(totalSeconds / 86400);
        const hours = Math.floor((totalSeconds % 86400) / 3600);
        const minutes = Math.floor((totalSeconds % 3600) / 60);
        const seconds = Math.floor(totalSeconds % 60);
        
        let timerHTML = '';
        
        if (days > 0) {
            timerHTML += `<span class="time-remaining">${days}d </span>`;
        }
        
        timerHTML += `<span class="time-remaining">${hours.toString().padStart(2, '0')}:${minutes.toString().padStart(2, '0')}:${seconds.toString().padStart(2, '0')}</span>`;
        timerHTML += '<span class="time-label">Sisa Waktu</span>';
        
        timerElement.innerHTML = timerHTML;
        
        totalSeconds--;
    }
    
    // Initial update
    updateTimer();
    
    // Update timer every second
    const countdownInterval = setInterval(updateTimer, 1000);
    
    // Cleanup interval on page unload
    window.addEventListener('beforeunload', function() {
        clearInterval(countdownInterval);
    });
}

/**
 * Initialize 3D tilt effect for cards
 */
function initializeTiltEffect() {
    const cards = document.querySelectorAll('.vehicle-detail-card, .bid-section');
    
    cards.forEach(card => {
        card.addEventListener('mousemove', e => {
            const rect = card.getBoundingClientRect();
            const x = e.clientX - rect.left;
            const y = e.clientY - rect.top;
            
            const centerX = rect.width / 2;
            const centerY = rect.height / 2;
            
            const maxRotation = 3; // Maximum rotation in degrees
            
            const rotateX = (maxRotation * (y - centerY)) / centerY;
            const rotateY = (-maxRotation * (x - centerX)) / centerX;
            
            card.style.transform = `perspective(1000px) rotateX(${rotateX}deg) rotateY(${rotateY}deg)`;
        });
        
        card.addEventListener('mouseleave', () => {
            card.style.transform = 'perspective(1000px) rotateX(0) rotateY(0)';
        });
    });
}

/**
 * Initialize spotlight effect for the cursor
 */
function initializeSpotlightEffect() {
    const galleryContainer = document.querySelector('.ultra-gallery-container');
    if (!galleryContainer) return;
    
    galleryContainer.addEventListener('mousemove', e => {
        const rect = galleryContainer.getBoundingClientRect();
        const x = e.clientX - rect.left;
        const y = e.clientY - rect.top;
        
        galleryContainer.style.background = `radial-gradient(circle at ${x}px ${y}px, rgba(255,255,255,0.2), transparent), linear-gradient(145deg, #ffffff, #f5f7fa)`;
    });
    
    galleryContainer.addEventListener('mouseleave', () => {
        galleryContainer.style.background = 'linear-gradient(145deg, #ffffff, #f5f7fa)';
    });
}

/**
 * Add animations to page elements
 */
function animateElements() {
    const elements = document.querySelectorAll('.vehicle-detail-card, .bid-section, .detail-content, .spec-item');
    
    const observer = new IntersectionObserver((entries) => {
        entries.forEach(entry => {
            if (entry.isIntersecting) {
                entry.target.classList.add('fade-in-up');
                observer.unobserve(entry.target);
            }
        });
    }, { threshold: 0.1 });
    
    elements.forEach(element => {
        observer.observe(element);
    });
}

/**
 * Format currency with proper thousands separator
 */
function formatCurrency(amount) {
    return 'Rp ' + parseInt(amount).toLocaleString('id-ID');
}

/**
 * Validate bid form input
 */
function validateBidForm() {
    const bidInput = document.getElementById('bid-amount');
    const bidButton = document.getElementById('place-bid-btn');
    const currentBid = parseFloat(bidInput.dataset.current || 0);
    const bidIncrement = parseFloat(bidInput.dataset.increment || 1000000);
    const errorMsg = document.getElementById('bid-error-msg');
    
    if (!bidInput || !bidButton) return;
    
    bidInput.addEventListener('input', function() {
        const bidValue = parseFloat(this.value.replace(/[^\d]/g, ''));
        const minBid = currentBid + bidIncrement;
        
        if (isNaN(bidValue) || bidValue < minBid) {
            if (errorMsg) {
                errorMsg.textContent = `Bid minimal ${formatCurrency(minBid)}`;
                errorMsg.style.display = 'block';
            }
            bidButton.disabled = true;
        } else {
            if (errorMsg) {
                errorMsg.style.display = 'none';
            }
            bidButton.disabled = false;
        }
        
        // Format the input with currency
        if (!isNaN(bidValue)) {
            this.value = formatCurrency(bidValue);
        }
    });
}
