<?php
/**
 * Account Dashboard - Legacy Compatibility
 * LelangMobil Web App - Versi 2025
 */

// Log akses ke file legacy untuk analisis penggunaan
error_log("Legacy account.php accessed, redirecting to account-modern.php");

// Capture any query parameters
$query = $_SERVER['QUERY_STRING'] ? '?' . $_SERVER['QUERY_STRING'] : '';

// Redirect to modern version
header("Location: account-modern.php{$query}");
exit;

// Include database connection dengan penanganan kesalahan
try {
    require_once 'config/database.php';
} catch (Throwable $e) {
    // Log error dan tampilkan halaman error minimal jika database.php gagal
    error_log("Fatal error including database.php: " . $e->getMessage());
    echo '<!DOCTYPE html><html><head><title>Error Database - LelangMobil</title><style>body{font-family:Arial;margin:0;padding:20px;background:#f5f5f5}.error-box{max-width:500px;margin:100px auto;background:white;padding:20px;border-radius:5px;box-shadow:0 2px 10px rgba(0,0,0,0.1)}</style></head><body><div class="error-box"><h2>Terjadi Kesalahan</h2><p>Tidak dapat mengakses database. Silakan coba beberapa saat lagi.</p><a href="index.php">Kembali ke Beranda</a></div></body></html>';
    exit;
}

// Include functions dengan penanganan kesalahan
try {
    require_once 'config/functions.php';
} catch (Throwable $e) {
    // Cukup log error tapi lanjutkan, functions.php mungkin tidak vital
    error_log("Error including functions.php: " . $e->getMessage());
}

// Start session if not already started
if (session_status() == PHP_SESSION_NONE) {
    session_start();
}

// Redirect if not logged in
if (!isset($_SESSION['user_id'])) {
    header("Location: login.php");
    exit;
}

// Flag untuk mengaktifkan tampilan Modern 2025
$use_modern_2025 = true;

$error = '';
$success = '';
$user_id = $_SESSION['user_id'];

// Get user information dengan error handling dan timeout yang lebih baik
try {
    // Set timeout yang singkat untuk query pengguna agar tidak memperlambat loading
    set_time_limit(5);
    $user_query = "SELECT * FROM users WHERE user_id = ?";
    
    // Coba gunakan database query cache untuk mempercepat loading
    $user_cached = db_get_cached($conn, $user_query, [$user_id], 'i');
    
    if (!isset($user_cached['error']) && isset($user_cached['data']) && count($user_cached['data']) > 0) {
        // Gunakan data dari cache yang berhasil
        $user = $user_cached['data'][0];
    } else {
        // Fallback jika cache error, gunakan query langsung
        $user_stmt = $conn->prepare($user_query);
        if (!$user_stmt) {
            throw new Exception("Failed to prepare user query: " . $conn->error);
        }
        
        $user_stmt->bind_param("i", $user_id);
        $execute_result = $user_stmt->execute();
        
        if (!$execute_result) {
            throw new Exception("Failed to execute user query: " . $user_stmt->error);
        }
        
        $user_result = $user_stmt->get_result();
        
        if (!$user_result) {
            throw new Exception("Failed to get result set: " . $user_stmt->error);
        }
        
        if ($user_result->num_rows === 0) {
            throw new Exception("User data not found for ID: {$user_id}");
        }
        
        $user = $user_result->fetch_assoc();
    }
    
    // Reset time limit ke nilai sebelumnya
    set_time_limit(15);
} catch (Throwable $e) {
    error_log("Error fetching user data in account.php: " . $e->getMessage());
    
    // Alih-alih die(), gunakan variabel error yang akan ditampilkan dengan cara yang lebih user-friendly
    $critical_error = "Tidak dapat memuat data pengguna. Silakan coba lagi nanti.";
}

// Get Total Bids Count dengan cara yang aman
try {
    // Cek apakah fungsi helper tersedia
    if (function_exists('get_active_bids_count')) {
        $active_bids_count = get_active_bids_count($conn, $user_id);
    } else {
        // Alternatif jika fungsi helper tidak tersedia - memastikan kompatibilitas kolom
        try {
            // Periksa struktur tabel untuk menentukan nama kolom yang benar
            $column_check_sql = "SHOW COLUMNS FROM bids LIKE 'bidder_id'";
            $column_check_stmt = $conn->prepare($column_check_sql);
            $column_check_stmt->execute();
            $column_check_result = $column_check_stmt->get_result();
            
            if ($column_check_result && $column_check_result->num_rows > 0) {
                // Gunakan bidder_id jika kolom ada
                $active_bids_sql = "SELECT COUNT(*) as total 
                            FROM bids 
                            JOIN vehicles ON bids.vehicle_id = vehicles.vehicle_id 
                            WHERE bids.bidder_id = ? AND vehicles.auction_end > NOW()";
            } else {
                // Gunakan user_id sebagai fallback
                $active_bids_sql = "SELECT COUNT(*) as total 
                            FROM bids 
                            JOIN vehicles ON bids.vehicle_id = vehicles.vehicle_id 
                            WHERE bids.user_id = ? AND vehicles.auction_end > NOW()";
            }
            $active_bids_stmt = $conn->prepare($active_bids_sql);
            $active_bids_stmt->bind_param("i", $user_id);
            $active_bids_stmt->execute();
            $active_bids_result = $active_bids_stmt->get_result();
            $active_bids_count = $active_bids_result->fetch_assoc()['total'] ?? 0;
        } catch (Throwable $e) {
            error_log("Error in direct active_bids query: " . $e->getMessage());
            $active_bids_count = 0; // Default jika query error
        }
    }
} catch (Throwable $e) {
    error_log("Error getting active bids count: " . $e->getMessage());
    $active_bids_count = 0; // Nilai default jika terjadi error
}

// Get wallet balance with caching
try {
    $wallet_query = "SELECT balance FROM users WHERE user_id = ?";
    $wallet_cached = db_get_cached($conn, $wallet_query, [$user_id], 'i');
    
    if (!isset($wallet_cached['error']) && isset($wallet_cached['data']) && count($wallet_cached['data']) > 0) {
        $wallet_balance = $wallet_cached['data'][0]['balance'];
    } else {
        // Fallback ke query langsung
        $wallet_stmt = $conn->prepare($wallet_query);
        $wallet_stmt->bind_param("i", $user_id);
        $wallet_stmt->execute();
        $wallet_result = $wallet_stmt->get_result();
        $wallet_row = $wallet_result->fetch_assoc();
        $wallet_balance = isset($wallet_row['balance']) ? $wallet_row['balance'] : 0;
    }
} catch (Throwable $e) {
    error_log("Error getting wallet balance in account.php: " . $e->getMessage());
    $wallet_balance = 0; // Fallback value
}

// Get transactions count with caching
try {
    $trans_count_query = "SELECT COUNT(*) as total FROM transactions WHERE user_id = ?";
    $trans_count_cached = db_get_cached($conn, $trans_count_query, [$user_id], 'i');
    
    if (!isset($trans_count_cached['error']) && isset($trans_count_cached['data']) && count($trans_count_cached['data']) > 0) {
        $transactions_count = $trans_count_cached['data'][0]['total'];
    } else {
        // Fallback ke query langsung
        $trans_count_stmt = $conn->prepare($trans_count_query);
        $trans_count_stmt->bind_param("i", $user_id);
        $trans_count_stmt->execute();
        $trans_count_result = $trans_count_stmt->get_result();
        $trans_count_row = $trans_count_result->fetch_assoc();
        $transactions_count = isset($trans_count_row['total']) ? $trans_count_row['total'] : 0;
    }
} catch (Throwable $e) {
    error_log("Error getting transactions count in account.php: " . $e->getMessage());
    $transactions_count = 0; // Fallback value
}

// Get recent transactions for dashboard display only
try {
    $transactions_sql = "SELECT * FROM transactions WHERE user_id = ? ORDER BY created_at DESC LIMIT 5";
    $transactions_stmt = $conn->prepare($transactions_sql);
    $transactions_stmt->bind_param("i", $user_id);
    $transactions_stmt->execute();
    $transactions_result = $transactions_stmt->get_result();
} catch (Throwable $e) {
    error_log("Error fetching recent transactions: " . $e->getMessage());
}

// Handle success or error messages from redirects
if (!empty($_GET['success'])) {
    $success_messages = [
        'profile_updated' => 'Profil berhasil diperbarui.',
        'password_changed' => 'Password berhasil diubah.',
        'topup_requested' => 'Permintaan top up telah dibuat. Silakan unggah bukti pembayaran.',
        'payment_uploaded' => 'Bukti pembayaran berhasil diunggah.',
        'withdraw_requested' => 'Permintaan penarikan berhasil dibuat.'
    ];
    
    if (isset($success_messages[$_GET['success']])) {
        $success = $success_messages[$_GET['success']];
    }
}

if (!empty($_GET['error'])) {
    $error_messages = [
        'profile_update_failed' => 'Gagal memperbarui profil.',
        'password_change_failed' => 'Gagal mengubah password.',
        'topup_failed' => 'Gagal membuat permintaan top up.',
        'payment_upload_failed' => 'Gagal mengunggah bukti pembayaran.',
        'withdraw_failed' => 'Gagal membuat permintaan penarikan.'
    ];
    
    if (isset($error_messages[$_GET['error']])) {
        $error = $error_messages[$_GET['error']];
    }
}

// Aktifkan flag untuk halaman dashboard dan tema modern
$page_title = "Dashboard Akun";
$is_dashboard_page = true;
$use_modern_dashboard = true;

// Cek adanya critical error dan tampilkan halaman minimal jika ada
if (isset($critical_error)) {
    // Tampilkan halaman error tanpa memuat header.php yang mungkin menyebabkan masalah
    echo '<!DOCTYPE html>
    <html lang="id">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>Error - LelangMobil</title>
        <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
        <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
        <style>
        .error-container { 
            max-width: 600px; 
            margin: 100px auto; 
            padding: 30px; 
            background-color: #fff; 
            border-radius: 8px; 
            box-shadow: 0 0 20px rgba(0,0,0,0.1); 
            text-align: center; 
        }
        .error-icon { 
            font-size: 64px; 
            color: #dc3545; 
            margin-bottom: 20px; 
        }
        .error-title { 
            font-size: 24px; 
            margin-bottom: 15px; 
            color: #333; 
        }
        .error-message { 
            color: #666; 
            margin-bottom: 25px; 
        }
        .btn-home {
            background-color: #007bff;
            color: #fff;
            padding: 10px 20px;
            border-radius: 4px;
            text-decoration: none;
            transition: background-color 0.3s;
        }
        .btn-home:hover {
            background-color: #0056b3;
            color: #fff;
        }
        </style>
    </head>
    <body style="background-color: #f8f9fa;">
        <div class="error-container">
            <div class="error-icon">
                <i class="fa fa-exclamation-circle"></i>
            </div>
            <h1 class="error-title">Oops! Terjadi Kesalahan</h1>
            <p class="error-message">' . htmlspecialchars($critical_error) . '</p>
            <a href="index.php" class="btn-home">
                <i class="fa fa-home me-2"></i>Kembali ke Beranda
            </a>
        </div>
    </body>
    </html>';
    exit;
}

// Include header dengan error handling
try {
    include("includes/header.php");
    
    // Load Modern 2025 CSS jika flag diaktifkan
    if ($use_modern_2025) {
        echo '<link rel="stylesheet" href="css/modern-2025.css">';  
        echo '<link rel="stylesheet" href="css/account-modern-2025.css">';  
    }
} catch (Throwable $e) {
    // Tampilkan minimal header HTML jika header gagal diload
    echo '<!DOCTYPE html>
    <html lang="id">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>' . htmlspecialchars($page_title) . ' - LelangMobil</title>
        <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
        <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
        <style>
        .modern-alert { padding: 15px; border-radius: 4px; margin-bottom: 20px; display: flex; align-items: center; }
        .modern-alert i { margin-right: 10px; font-size: 24px; }
        .modern-alert-danger { background-color: #f8d7da; border: 1px solid #f5c6cb; color: #721c24; }
        </style>
    </head>
    <body>
    <div class="container py-5">
        <div class="modern-alert modern-alert-danger">
            <i class="fa fa-exclamation-circle"></i>
            <div>Error memuat header: ' . htmlspecialchars($e->getMessage()) . '</div>
        </div>';
    error_log("Error including header.php: " . $e->getMessage());
}
?>

<!-- Main Content Container -->
<div class="container-fluid py-5">
    <?php if (!empty($success)): ?>
    <div class="modern-alert modern-alert-success mb-4 fade-in">
        <i class="fa fa-check-circle"></i>
        <div><?php echo $success; ?></div>
    </div>
    <?php endif; ?>
    
    <?php if ($use_modern_2025): ?>
    <!-- Modern 2025 Account Dashboard -->
    <div class="dashboard-container-2025">
        <?php if (!empty($error)): ?>
        <div class="alert alert-danger fade-in-up">
            <i class="fas fa-exclamation-circle me-2"></i>
            <?php echo $error; ?>
        </div>
        <?php endif; ?>
        
        <?php if (!empty($success)): ?>
        <div class="alert alert-success fade-in-up">
            <i class="fas fa-check-circle me-2"></i>
            <?php echo $success; ?>
        </div>
        <?php endif; ?>
        
        <!-- User Profile Header -->
        <div class="profile-header-2025 fade-in-up">
            <div class="profile-avatar-2025">
                <img src="<?php echo isset($user_data['avatar']) && !empty($user_data['avatar']) ? 'uploads/avatars/' . $user_data['avatar'] : 'assets/img/default-user.svg'; ?>" 
                     alt="Profile Avatar" 
                     onerror="this.src='assets/img/default-user.svg';">
            </div>
            <div class="profile-info-2025">
                <h2 class="profile-name-2025"><?php echo isset($user_data['fullname']) ? htmlspecialchars($user_data['fullname']) : 'User'; ?></h2>
                <div class="profile-email-2025">
                    <i class="fas fa-envelope"></i>
                    <?php echo isset($user_data['email']) ? htmlspecialchars($user_data['email']) : '-'; ?>
                </div>
                
                <div class="profile-stats-2025">
                    <div class="profile-stat-item-2025">
                        <div class="stat-icon">
                            <i class="fas fa-wallet"></i>
                        </div>
                        <div class="stat-content">
                            <div class="stat-value">Rp <?php echo number_format($wallet_balance, 0, ',', '.'); ?></div>
                            <div class="stat-label">Saldo</div>
                        </div>
                    </div>
                    
                    <div class="profile-stat-item-2025">
                        <div class="stat-icon">
                            <i class="fas fa-gavel"></i>
                        </div>
                        <div class="stat-content">
                            <div class="stat-value"><?php echo $active_bids_count; ?></div>
                            <div class="stat-label">Bid Aktif</div>
                        </div>
                    </div>
                    
                    <div class="profile-stat-item-2025">
                        <div class="stat-icon">
                            <i class="fas fa-exchange-alt"></i>
                        </div>
                        <div class="stat-content">
                            <div class="stat-value"><?php echo $transactions_count; ?></div>
                            <div class="stat-label">Transaksi</div>
                        </div>
                    </div>
                </div>
                
                <div class="profile-actions-2025">
                    <a href="topup.php" class="btn profile-action-btn profile-action-primary">
                        <i class="fas fa-plus-circle"></i> Top Up
                    </a>
                    <a href="withdraw.php" class="btn profile-action-btn profile-action-primary">
                        <i class="fas fa-money-bill-wave"></i> Tarik Dana
                    </a>
                    <a href="profile-edit.php" class="btn profile-action-btn profile-action-secondary">
                        <i class="fas fa-user-edit"></i> Edit Profil
                    </a>
                </div>
            </div>
        </div>
        
        <!-- Tabs Navigation -->
        <div class="tabs-container-2025 fade-in-up">
            <div class="nav-tabs-2025">
                <a href="account.php" class="nav-tab-item-2025 active">
                    <i class="fas fa-tachometer-alt"></i> Dashboard
                </a>
                <a href="bids.php" class="nav-tab-item-2025">
                    <i class="fas fa-gavel"></i> Bid Saya
                </a>
                <a href="transactions.php" class="nav-tab-item-2025">
                    <i class="fas fa-history"></i> Riwayat Transaksi
                </a>
                <a href="wishlist.php" class="nav-tab-item-2025">
                    <i class="fas fa-heart"></i> Wishlist
                </a>
                <a href="profile-settings.php" class="nav-tab-item-2025">
                    <i class="fas fa-cog"></i> Pengaturan
                </a>
            </div>
        </div>
    <?php else: ?>
    <!-- Legacy Account Dashboard -->
    <?php if (!empty($error)): ?>
    <div class="modern-alert modern-alert-danger mb-4 fade-in">
        <i class="fa fa-exclamation-circle"></i>
        <div><?php echo $error; ?></div>
    </div>
    <?php endif; ?>
    
    <div class="row">
        <!-- Sidebar Navigation -->
        <div class="col-lg-3">
            <?php endif; ?>
            
            <?php
            try {
                include("includes/account-navbar.php"); 
            } catch (Throwable $e) {
                echo '<div class="modern-alert modern-alert-danger mb-4">
                    <i class="fa fa-exclamation-circle"></i>
                    <div>Error memuat navigasi: ' . htmlspecialchars($e->getMessage()) . '</div>
                </div>';
                
                // Tampilkan navbar alternatif simple
                echo '<div class="list-group mb-4">
                    <a href="account.php" class="list-group-item list-group-item-action active">Dashboard</a>
                    <a href="profile-modern.php" class="list-group-item list-group-item-action">Profil</a>
                    <a href="bids-modern.php" class="list-group-item list-group-item-action">Riwayat Bid</a>
                    <a href="transactions-modern.php" class="list-group-item list-group-item-action">Transaksi</a>
                </div>';
                
                error_log("Error including account-navbar.php: " . $e->getMessage());
            }
            ?>
        </div>
        
        <!-- Main Content -->
        <div class="col-lg-9">
            <h2 class="mb-4 fade-in"><?php echo $page_title; ?></h2>
            
            <!-- Dashboard Stats & Widgets -->
            <?php 
            try {
                include("includes/dashboard-stats.php"); 
            } catch (Throwable $e) {
                echo '<div class="modern-alert modern-alert-danger mb-4">
                    <i class="fa fa-exclamation-circle"></i>
                    <div>Error memuat statistik dashboard: ' . htmlspecialchars($e->getMessage()) . '</div>
                </div>';
                error_log("Error including dashboard-stats.php: " . $e->getMessage());
            }
            ?>
            
            <!-- Active Auctions -->
            <?php 
            try {
                include("includes/active-auctions-widget.php"); 
            } catch (Throwable $e) {
                echo '<div class="modern-alert modern-alert-danger mb-4">
                    <i class="fa fa-exclamation-circle"></i>
                    <div>Error memuat lelang aktif: ' . htmlspecialchars($e->getMessage()) . '</div>
                </div>';
                error_log("Error including active-auctions-widget.php: " . $e->getMessage());
            }
            ?>
            
            <!-- Link ke halaman Bid dan Transaksi -->
            <div class="row mt-4">
                <div class="col-lg-6 mb-4">
                    <div class="modern-card h-100 fade-in">
                        <div class="modern-card-body text-center py-5">
                            <div class="icon-feature mb-3">
                                <i class="fa fa-gavel fa-3x"></i>
                            </div>
                            <h4>Riwayat Bid</h4>
                            <p class="text-muted mb-4">Lihat semua tawaran yang telah Anda lakukan pada lelang kendaraan</p>
                            <a href="bids-modern.php" class="modern-button modern-button-primary">
                                <i class="fa fa-eye me-2"></i>Lihat Riwayat Bid
                            </a>
                        </div>
                    </div>
                </div>
                
                <div class="col-lg-6 mb-4">
                    <div class="modern-card h-100 fade-in">
                        <div class="modern-card-body text-center py-5">
                            <div class="icon-feature mb-3">
                                <i class="fa fa-history fa-3x"></i>
                            </div>
                            <h4>Riwayat Transaksi</h4>
                            <p class="text-muted mb-4">Lihat seluruh riwayat transaksi keuangan akun Anda</p>
                            <a href="transactions-modern.php" class="modern-button modern-button-primary">
                                <i class="fa fa-eye me-2"></i>Lihat Transaksi
                            </a>
                        </div>
                    </div>
                </div>
            </div>
            
            <!-- Link ke halaman Profil dan Top Up -->
            <div class="row mt-2">
                <div class="col-lg-6 mb-4">
                    <div class="modern-card h-100 fade-in">
                        <div class="modern-card-body text-center py-5">
                            <div class="icon-feature mb-3">
                                <i class="fa fa-user fa-3x"></i>
                            </div>
                            <h4>Profil Saya</h4>
                            <p class="text-muted mb-4">Kelola informasi profil dan ubah password akun Anda</p>
                            <a href="profile-modern.php" class="modern-button modern-button-primary">
                                <i class="fa fa-edit me-2"></i>Kelola Profil
                            </a>
                        </div>
                    </div>
                </div>
                
                <div class="col-lg-6 mb-4">
                    <div class="modern-card h-100 fade-in">
                        <div class="modern-card-body text-center py-5">
                            <div class="icon-feature mb-3">
                                <i class="fa fa-wallet fa-3x"></i>
                            </div>
                            <h4>Top Up Saldo</h4>
                            <p class="text-muted mb-4">Tambah saldo akun Anda untuk melakukan penawaran</p>
                            <a href="topup-modern.php" class="modern-button modern-button-primary">
                                <i class="fa fa-plus-circle me-2"></i>Top Up Saldo
                            </a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<style>
.icon-feature {
    width: 80px;
    height: 80px;
    margin: 0 auto;
    background-color: rgba(var(--primary-rgb), 0.1);
    color: var(--primary-color);
    border-radius: 50%;
    display: flex;
    align-items: center;
    justify-content: center;
    margin-bottom: 1.5rem;
    transition: all 0.3s ease;
}

.modern-card:hover .icon-feature {
    transform: scale(1.1);
    background-color: var(--primary-color);
    color: #fff;
}
</style>

<?php include("includes/footer.php"); ?>
