<?php
/**
 * Error Monitoring System
 * LelangMobil Web App - Versi 2025
 */

class ErrorMonitor {
    private $log_dir;
    private $notification_email;
    private $notification_threshold;
    private $last_notification;
    
    public function __construct($log_dir = null, $notification_email = null, $notification_threshold = 3600) {
        $this->log_dir = $log_dir ?? dirname(__DIR__) . '/logs';
        $this->notification_email = $notification_email ?? 'admin@lelangmobil.com';
        $this->notification_threshold = $notification_threshold;
        $this->last_notification = 0;
        
        // Create log directory if it doesn't exist
        if (!file_exists($this->log_dir)) {
            mkdir($this->log_dir, 0755, true);
        }
        
        // Set custom error handler
        set_error_handler([$this, 'handleError']);
        set_exception_handler([$this, 'handleException']);
        register_shutdown_function([$this, 'handleFatalError']);
    }
    
    /**
     * Handle PHP errors
     * 
     * @param int $errno Error number
     * @param string $errstr Error message
     * @param string $errfile File where error occurred
     * @param int $errline Line where error occurred
     * @return bool True to prevent default error handler
     */
    public function handleError($errno, $errstr, $errfile, $errline) {
        // Don't report errors that are suppressed with @
        if (error_reporting() === 0) {
            return false;
        }
        
        // Get error type
        $error_type = $this->getErrorType($errno);
        
        // Log error
        $this->logError($error_type, $errstr, $errfile, $errline);
        
        // Send notification for severe errors
        if ($errno == E_ERROR || $errno == E_PARSE || $errno == E_CORE_ERROR || $errno == E_COMPILE_ERROR || $errno == E_USER_ERROR) {
            $this->sendNotification($error_type, $errstr, $errfile, $errline);
        }
        
        // Don't execute PHP's internal error handler
        return true;
    }
    
    /**
     * Handle exceptions
     * 
     * @param Exception $exception Exception object
     * @return void
     */
    public function handleException($exception) {
        // Log exception
        $this->logError(
            'Exception',
            $exception->getMessage(),
            $exception->getFile(),
            $exception->getLine(),
            $exception->getTraceAsString()
        );
        
        // Send notification
        $this->sendNotification(
            'Exception',
            $exception->getMessage(),
            $exception->getFile(),
            $exception->getLine(),
            $exception->getTraceAsString()
        );
    }
    
    /**
     * Handle fatal errors
     * 
     * @return void
     */
    public function handleFatalError() {
        $error = error_get_last();
        
        if ($error !== null && ($error['type'] === E_ERROR || $error['type'] === E_PARSE || $error['type'] === E_COMPILE_ERROR)) {
            // Log error
            $this->logError(
                $this->getErrorType($error['type']),
                $error['message'],
                $error['file'],
                $error['line']
            );
            
            // Send notification
            $this->sendNotification(
                $this->getErrorType($error['type']),
                $error['message'],
                $error['file'],
                $error['line']
            );
        }
    }
    
    /**
     * Log error to file
     * 
     * @param string $type Error type
     * @param string $message Error message
     * @param string $file File where error occurred
     * @param int $line Line where error occurred
     * @param string $trace Stack trace (optional)
     * @return void
     */
    private function logError($type, $message, $file, $line, $trace = '') {
        $log_file = $this->log_dir . '/error.log';
        
        $log_message = date('[Y-m-d H:i:s]') . " {$type}: {$message} in {$file} on line {$line}\n";
        
        if (!empty($trace)) {
            $log_message .= "Stack trace:\n{$trace}\n";
        }
        
        file_put_contents($log_file, $log_message, FILE_APPEND);
    }
    
    /**
     * Send notification email
     * 
     * @param string $type Error type
     * @param string $message Error message
     * @param string $file File where error occurred
     * @param int $line Line where error occurred
     * @param string $trace Stack trace (optional)
     * @return void
     */
    private function sendNotification($type, $message, $file, $line, $trace = '') {
        // Check if notification threshold has passed
        if (time() - $this->last_notification < $this->notification_threshold) {
            return;
        }
        
        $this->last_notification = time();
        
        // Prepare email content
        $subject = "[LelangMobil] {$type} Error";
        
        $body = "An error occurred on " . date('Y-m-d H:i:s') . "\n\n";
        $body .= "Type: {$type}\n";
        $body .= "Message: {$message}\n";
        $body .= "File: {$file}\n";
        $body .= "Line: {$line}\n\n";
        
        if (!empty($trace)) {
            $body .= "Stack trace:\n{$trace}\n\n";
        }
        
        $body .= "Server: " . $_SERVER['SERVER_NAME'] . "\n";
        $body .= "Request URI: " . $_SERVER['REQUEST_URI'] . "\n";
        $body .= "User Agent: " . $_SERVER['HTTP_USER_AGENT'] . "\n";
        $body .= "IP Address: " . $_SERVER['REMOTE_ADDR'] . "\n";
        
        // Send email
        if (function_exists('mail')) {
            mail($this->notification_email, $subject, $body);
        }
        
        // If mailer.php is available, use it
        if (function_exists('send_email')) {
            send_email($this->notification_email, $subject, nl2br($body));
        }
    }
    
    /**
     * Get error type string from error number
     * 
     * @param int $errno Error number
     * @return string Error type
     */
    private function getErrorType($errno) {
        switch ($errno) {
            case E_ERROR:
                return 'Fatal Error';
            case E_WARNING:
                return 'Warning';
            case E_PARSE:
                return 'Parse Error';
            case E_NOTICE:
                return 'Notice';
            case E_CORE_ERROR:
                return 'Core Error';
            case E_CORE_WARNING:
                return 'Core Warning';
            case E_COMPILE_ERROR:
                return 'Compile Error';
            case E_COMPILE_WARNING:
                return 'Compile Warning';
            case E_USER_ERROR:
                return 'User Error';
            case E_USER_WARNING:
                return 'User Warning';
            case E_USER_NOTICE:
                return 'User Notice';
            case E_STRICT:
                return 'Strict';
            case E_RECOVERABLE_ERROR:
                return 'Recoverable Error';
            case E_DEPRECATED:
                return 'Deprecated';
            case E_USER_DEPRECATED:
                return 'User Deprecated';
            default:
                return 'Unknown Error';
        }
    }
}

// Create error monitor instance
$error_monitor = new ErrorMonitor();
?>