<?php
/**
 * Session Manager
 * LelangMobil Web App - Versi 2025
 * 
 * File ini menangani semua operasi terkait session untuk mencegah error "headers already sent"
 */

// Pastikan session belum dimulai sebelum memulai session baru
if (session_status() == PHP_SESSION_NONE) {
    // Atur parameter session yang aman
    ini_set('session.use_only_cookies', 1);
    ini_set('session.use_strict_mode', 1);
    
    // Atur cookie parameters yang aman
    session_set_cookie_params([
        'lifetime' => 3600, // 1 jam
        'path' => '/',
        'domain' => '',
        'secure' => isset($_SERVER['HTTPS']),
        'httponly' => true,
        'samesite' => 'Lax'
    ]);
    
    // Mulai session
    session_start();
    
    // Regenerasi ID session secara periodik untuk mencegah session fixation
    if (!isset($_SESSION['last_regeneration'])) {
        session_regenerate_id(true);
        $_SESSION['last_regeneration'] = time();
    } else if (time() - $_SESSION['last_regeneration'] > 1800) { // 30 menit
        session_regenerate_id(true);
        $_SESSION['last_regeneration'] = time();
    }
}

/**
 * Cek apakah user sudah login
 * 
 * @return bool True jika user sudah login, false jika belum
 */
function is_logged_in() {
    return isset($_SESSION['user_id']);
}

/**
 * Cek apakah user adalah admin
 * 
 * @return bool True jika user adalah admin, false jika bukan
 */
function is_admin() {
    return isset($_SESSION['is_admin']) && $_SESSION['is_admin'] == 1;
}

/**
 * Redirect ke halaman login jika user belum login
 * 
 * @param string $redirect_url URL untuk redirect setelah login
 * @return void
 */
function require_login($redirect_url = '') {
    if (!is_logged_in()) {
        $redirect = empty($redirect_url) ? '' : '?redirect=' . urlencode($redirect_url);
        header("Location: login.php$redirect");
        exit;
    }
}

/**
 * Redirect ke halaman error jika user bukan admin
 * 
 * @return void
 */
function require_admin() {
    if (!is_admin()) {
        header("Location: error.php?code=403");
        exit;
    }
}

/**
 * Set flash message yang akan ditampilkan pada halaman berikutnya
 * 
 * @param string $type Tipe pesan (success, error, warning, info)
 * @param string $message Isi pesan
 * @return void
 */
function set_flash_message($type, $message) {
    $_SESSION['flash_message'] = [
        'type' => $type,
        'message' => $message,
        'time' => time()
    ];
}

/**
 * Ambil flash message dan hapus dari session
 * 
 * @return array|null Flash message atau null jika tidak ada
 */
function get_flash_message() {
    if (isset($_SESSION['flash_message'])) {
        $message = $_SESSION['flash_message'];
        unset($_SESSION['flash_message']);
        
        // Hanya kembalikan pesan jika belum lebih dari 5 menit
        if (time() - $message['time'] < 300) {
            return $message;
        }
    }
    return null;
}

/**
 * Cek remember me cookie dan login user jika valid
 * 
 * @param object $conn Koneksi database
 * @return bool True jika berhasil login dengan cookie, false jika tidak
 */
function check_remember_me($conn) {
    if (!is_logged_in() && isset($_COOKIE['remember_token']) && isset($_COOKIE['remember_user'])) {
        $token = $_COOKIE['remember_token'];
        $user_id = $_COOKIE['remember_user'];
        
        $sql = "SELECT * FROM users WHERE user_id = ? AND remember_token = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("is", $user_id, $token);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows > 0) {
            $user = $result->fetch_assoc();
            
            // Set session variables
            $_SESSION['user_id'] = $user['user_id'];
            $_SESSION['username'] = $user['username'];
            $_SESSION['is_admin'] = $user['is_admin'];
            
            // Update last login time
            $update_sql = "UPDATE users SET last_login = NOW() WHERE user_id = ?";
            $update_stmt = $conn->prepare($update_sql);
            $update_stmt->bind_param("i", $user['user_id']);
            $update_stmt->execute();
            
            return true;
        }
        
        // Token tidak valid, hapus cookie
        setcookie('remember_token', '', time() - 3600, '/');
        setcookie('remember_user', '', time() - 3600, '/');
    }
    
    return false;
}
?>