<?php
/**
 * Transaction Helper
 * LelangMobil Web App - Versi 2025
 */

/**
 * Create a new transaction with proper validation and error handling
 * 
 * @param int $user_id User ID
 * @param float $amount Transaction amount
 * @param string $type Transaction type (deposit, withdrawal, bid_hold, bid_release, winning_payment)
 * @param string $payment_method Payment method (optional)
 * @param string $reference Reference number or ID (optional)
 * @return int|bool Transaction ID or false on failure
 */
function create_transaction($user_id, $amount, $type, $payment_method = null, $reference = null) {
    global $conn;
    
    // Start transaction
    $conn->begin_transaction();
    
    try {
        // Insert transaction record
        $sql = "INSERT INTO transactions (user_id, amount, type, status, payment_method, reference_number, created_at) 
                VALUES (?, ?, ?, 'pending', ?, ?, NOW())";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("idsss", $user_id, $amount, $type, $payment_method, $reference);
        $stmt->execute();
        $transaction_id = $stmt->insert_id;
        
        // Update user balance for deposit/withdrawal
        if ($type == 'deposit') {
            // For deposits, we don't update balance until admin approves
        } elseif ($type == 'withdrawal') {
            // For withdrawals, we hold the amount immediately
            $update_sql = "UPDATE users SET balance = balance - ? WHERE user_id = ? AND balance >= ?";
            $update_stmt = $conn->prepare($update_sql);
            $update_stmt->bind_param("did", $amount, $user_id, $amount);
            $update_stmt->execute();
            
            if ($update_stmt->affected_rows == 0) {
                // Not enough balance
                throw new Exception("Insufficient balance");
            }
        } elseif ($type == 'bid_hold') {
            // For bid holds, we hold the amount immediately
            $update_sql = "UPDATE users SET balance = balance - ? WHERE user_id = ? AND balance >= ?";
            $update_stmt = $conn->prepare($update_sql);
            $update_stmt->bind_param("did", $amount, $user_id, $amount);
            $update_stmt->execute();
            
            if ($update_stmt->affected_rows == 0) {
                // Not enough balance
                throw new Exception("Insufficient balance");
            }
        }
        
        // Commit transaction
        $conn->commit();
        
        // Send notification to user
        $notification_title = "Transaksi Baru";
        $notification_message = "Transaksi " . get_transaction_type($type) . " sebesar " . format_money($amount) . " telah dibuat.";
        
        if (function_exists('send_notification')) {
            send_notification($user_id, 'transaction', $notification_title, $notification_message);
        }
        
        return $transaction_id;
        
    } catch (Exception $e) {
        // Rollback on error
        $conn->rollback();
        error_log("Transaction error: " . $e->getMessage());
        return false;
    }
}

/**
 * Process transaction status change with proper validation
 * 
 * @param int $transaction_id Transaction ID
 * @param string $status New status (completed, rejected)
 * @param int $admin_id Admin ID who processed the transaction (optional)
 * @return bool Success or failure
 */
function update_transaction_status($transaction_id, $status, $admin_id = null) {
    global $conn;
    
    // Start transaction
    $conn->begin_transaction();
    
    try {
        // Get transaction details
        $sql = "SELECT * FROM transactions WHERE transaction_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $transaction_id);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows == 0) {
            throw new Exception("Transaction not found");
        }
        
        $transaction = $result->fetch_assoc();
        $user_id = $transaction['user_id'];
        $amount = $transaction['amount'];
        $type = $transaction['type'];
        $current_status = $transaction['status'];
        
        // Prevent duplicate processing
        if ($current_status == $status) {
            $conn->commit();
            return true;
        }
        
        // Update transaction status
        $update_sql = "UPDATE transactions SET status = ?, admin_id = ?, updated_at = NOW() WHERE transaction_id = ?";
        $update_stmt = $conn->prepare($update_sql);
        $update_stmt->bind_param("sii", $status, $admin_id, $transaction_id);
        $update_stmt->execute();
        
        // Process balance updates based on status change
        if ($status == 'completed') {
            if ($type == 'deposit') {
                // Add funds to user balance
                $balance_sql = "UPDATE users SET balance = balance + ? WHERE user_id = ?";
                $balance_stmt = $conn->prepare($balance_sql);
                $balance_stmt->bind_param("di", $amount, $user_id);
                $balance_stmt->execute();
            }
            // For withdrawals, we already deducted the balance when creating the transaction
        } elseif ($status == 'rejected') {
            if ($type == 'withdrawal' || $type == 'bid_hold') {
                // Return funds to user balance
                $balance_sql = "UPDATE users SET balance = balance + ? WHERE user_id = ?";
                $balance_stmt = $conn->prepare($balance_sql);
                $balance_stmt->bind_param("di", $amount, $user_id);
                $balance_stmt->execute();
            }
        }
        
        // Commit transaction
        $conn->commit();
        
        // Send notification to user
        $notification_title = "Status Transaksi Diperbarui";
        $notification_message = "Transaksi #" . $transaction_id . " telah " . 
                               ($status == 'completed' ? 'selesai' : 
                               ($status == 'rejected' ? 'ditolak' : 'diperbarui'));
        
        if (function_exists('send_notification')) {
            send_notification($user_id, 'transaction', $notification_title, $notification_message);
        }
        
        return true;
        
    } catch (Exception $e) {
        // Rollback on error
        $conn->rollback();
        error_log("Transaction status update error: " . $e->getMessage());
        return false;
    }
}

/**
 * Get user balance with transaction history
 * 
 * @param int $user_id User ID
 * @return array Balance information
 */
function get_user_balance_info($user_id) {
    global $conn;
    
    try {
        // Get user balance
        $balance_sql = "SELECT balance FROM users WHERE user_id = ?";
        $balance_stmt = $conn->prepare($balance_sql);
        $balance_stmt->bind_param("i", $user_id);
        $balance_stmt->execute();
        $balance_result = $balance_stmt->get_result();
        
        if ($balance_result->num_rows == 0) {
            throw new Exception("User not found");
        }
        
        $balance = $balance_result->fetch_assoc()['balance'];
        
        // Get pending deposits
        $pending_deposits_sql = "SELECT SUM(amount) as total FROM transactions 
                                WHERE user_id = ? AND type = 'deposit' AND status = 'pending'";
        $pending_deposits_stmt = $conn->prepare($pending_deposits_sql);
        $pending_deposits_stmt->bind_param("i", $user_id);
        $pending_deposits_stmt->execute();
        $pending_deposits = $pending_deposits_stmt->get_result()->fetch_assoc()['total'] ?? 0;
        
        // Get pending withdrawals
        $pending_withdrawals_sql = "SELECT SUM(amount) as total FROM transactions 
                                   WHERE user_id = ? AND type = 'withdrawal' AND status = 'pending'";
        $pending_withdrawals_stmt = $conn->prepare($pending_withdrawals_sql);
        $pending_withdrawals_stmt->bind_param("i", $user_id);
        $pending_withdrawals_stmt->execute();
        $pending_withdrawals = $pending_withdrawals_stmt->get_result()->fetch_assoc()['total'] ?? 0;
        
        // Get held amount for bids
        $held_amount_sql = "SELECT SUM(amount) as total FROM transactions 
                           WHERE user_id = ? AND type = 'bid_hold' AND status = 'completed'";
        $held_amount_stmt = $conn->prepare($held_amount_sql);
        $held_amount_stmt->bind_param("i", $user_id);
        $held_amount_stmt->execute();
        $held_amount = $held_amount_stmt->get_result()->fetch_assoc()['total'] ?? 0;
        
        return [
            'balance' => $balance,
            'pending_deposits' => $pending_deposits,
            'pending_withdrawals' => $pending_withdrawals,
            'held_amount' => $held_amount,
            'available_balance' => $balance
        ];
        
    } catch (Exception $e) {
        error_log("Error getting user balance info: " . $e->getMessage());
        return [
            'balance' => 0,
            'pending_deposits' => 0,
            'pending_withdrawals' => 0,
            'held_amount' => 0,
            'available_balance' => 0
        ];
    }
}

/**
 * Process bid with transaction handling
 * 
 * @param int $user_id User ID
 * @param int $vehicle_id Vehicle ID
 * @param float $bid_amount Bid amount
 * @param bool $is_auto_bid Is auto bid
 * @param float $max_bid_amount Max bid amount for auto bid
 * @param float $bid_increment Bid increment for auto bid
 * @return int|bool Bid ID or false on failure
 */
function process_bid($user_id, $vehicle_id, $bid_amount, $is_auto_bid = false, $max_bid_amount = 0, $bid_increment = 0) {
    global $conn;
    
    // Start transaction
    $conn->begin_transaction();
    
    try {
        // Check if user has enough balance
        $user_sql = "SELECT balance FROM users WHERE user_id = ?";
        $user_stmt = $conn->prepare($user_sql);
        $user_stmt->bind_param("i", $user_id);
        $user_stmt->execute();
        $user_result = $user_stmt->get_result();
        
        if ($user_result->num_rows == 0) {
            throw new Exception("User not found");
        }
        
        $user_balance = $user_result->fetch_assoc()['balance'];
        
        // Check if vehicle exists and is active
        $vehicle_sql = "SELECT * FROM vehicles WHERE vehicle_id = ? AND status = 'active'";
        $vehicle_stmt = $conn->prepare($vehicle_sql);
        $vehicle_stmt->bind_param("i", $vehicle_id);
        $vehicle_stmt->execute();
        $vehicle_result = $vehicle_stmt->get_result();
        
        if ($vehicle_result->num_rows == 0) {
            throw new Exception("Vehicle not found or not active");
        }
        
        $vehicle = $vehicle_result->fetch_assoc();
        $current_bid = $vehicle['current_bid'] ?? $vehicle['starting_price'];
        
        // Check if bid amount is higher than current bid
        if ($bid_amount <= $current_bid) {
            throw new Exception("Bid amount must be higher than current bid");
        }
        
        // Calculate amount to hold (for auto bid, hold the max amount)
        $hold_amount = $is_auto_bid ? $max_bid_amount : $bid_amount;
        
        // Check if user has enough balance
        if ($user_balance < $hold_amount) {
            throw new Exception("Insufficient balance");
        }
        
        // Create transaction for bid hold
        $transaction_sql = "INSERT INTO transactions (user_id, amount, type, status, reference_id, created_at) 
                           VALUES (?, ?, 'bid_hold', 'completed', ?, NOW())";
        $transaction_stmt = $conn->prepare($transaction_sql);
        $transaction_stmt->bind_param("idi", $user_id, $hold_amount, $vehicle_id);
        $transaction_stmt->execute();
        
        // Update user balance
        $balance_sql = "UPDATE users SET balance = balance - ? WHERE user_id = ?";
        $balance_stmt = $conn->prepare($balance_sql);
        $balance_stmt->bind_param("di", $hold_amount, $user_id);
        $balance_stmt->execute();
        
        // Insert bid
        $bid_sql = "INSERT INTO bids (vehicle_id, bidder_id, bid_amount, is_auto_bid, max_bid_amount, bid_increment, bid_time) 
                   VALUES (?, ?, ?, ?, ?, ?, NOW())";
        $bid_stmt = $conn->prepare($bid_sql);
        $bid_stmt->bind_param("iididd", $vehicle_id, $user_id, $bid_amount, $is_auto_bid, $max_bid_amount, $bid_increment);
        $bid_stmt->execute();
        $bid_id = $bid_stmt->insert_id;
        
        // Update vehicle current bid
        $update_sql = "UPDATE vehicles SET current_bid = ?, current_bidder = ? WHERE vehicle_id = ?";
        $update_stmt = $conn->prepare($update_sql);
        $update_stmt->bind_param("dii", $bid_amount, $user_id, $vehicle_id);
        $update_stmt->execute();
        
        // Commit transaction
        $conn->commit();
        
        // Send notification to previous bidder if exists
        if ($vehicle['current_bidder'] && $vehicle['current_bidder'] != $user_id) {
            $notification_title = "Bid Anda Terlampaui";
            $notification_message = "Bid Anda untuk " . $vehicle['title'] . " telah dilampaui. Bid tertinggi saat ini adalah " . format_money($bid_amount);
            
            if (function_exists('send_notification')) {
                send_notification($vehicle['current_bidder'], 'bid', $notification_title, $notification_message);
            }
        }
        
        return $bid_id;
        
    } catch (Exception $e) {
        // Rollback on error
        $conn->rollback();
        error_log("Bid processing error: " . $e->getMessage());
        return false;
    }
}

/**
 * Process auction end
 * 
 * @param int $vehicle_id Vehicle ID
 * @return bool Success or failure
 */
function process_auction_end($vehicle_id) {
    global $conn;
    
    // Start transaction
    $conn->begin_transaction();
    
    try {
        // Get vehicle details
        $vehicle_sql = "SELECT * FROM vehicles WHERE vehicle_id = ?";
        $vehicle_stmt = $conn->prepare($vehicle_sql);
        $vehicle_stmt->bind_param("i", $vehicle_id);
        $vehicle_stmt->execute();
        $vehicle_result = $vehicle_stmt->get_result();
        
        if ($vehicle_result->num_rows == 0) {
            throw new Exception("Vehicle not found");
        }
        
        $vehicle = $vehicle_result->fetch_assoc();
        $current_bid = $vehicle['current_bid'];
        $current_bidder = $vehicle['current_bidder'];
        $reserve_price = $vehicle['reserve_price'];
        
        // Update vehicle status
        if ($current_bidder && $current_bid >= $reserve_price) {
            // Sold
            $status = 'sold';
            
            // Release held funds for winning bidder
            $release_sql = "INSERT INTO transactions (user_id, amount, type, status, reference_id, created_at) 
                           VALUES (?, ?, 'bid_release', 'completed', ?, NOW())";
            $release_stmt = $conn->prepare($release_sql);
            $release_stmt->bind_param("idi", $current_bidder, $current_bid, $vehicle_id);
            $release_stmt->execute();
            
            // Create winning payment transaction
            $payment_sql = "INSERT INTO transactions (user_id, amount, type, status, reference_id, created_at) 
                           VALUES (?, ?, 'winning_payment', 'completed', ?, NOW())";
            $payment_stmt = $conn->prepare($payment_sql);
            $payment_stmt->bind_param("idi", $current_bidder, $current_bid, $vehicle_id);
            $payment_stmt->execute();
            
            // Send notification to winner
            $notification_title = "Selamat! Anda Memenangkan Lelang";
            $notification_message = "Anda telah memenangkan lelang untuk " . $vehicle['title'] . " dengan harga " . format_money($current_bid);
            
            if (function_exists('send_notification')) {
                send_notification($current_bidder, 'auction_win', $notification_title, $notification_message);
            }
        } else {
            // Not sold
            $status = 'not_sold';
            
            // Release held funds for all bidders
            $bids_sql = "SELECT DISTINCT bidder_id FROM bids WHERE vehicle_id = ?";
            $bids_stmt = $conn->prepare($bids_sql);
            $bids_stmt->bind_param("i", $vehicle_id);
            $bids_stmt->execute();
            $bids_result = $bids_stmt->get_result();
            
            while ($bid = $bids_result->fetch_assoc()) {
                $bidder_id = $bid['bidder_id'];
                
                // Get total held amount for this bidder
                $held_sql = "SELECT SUM(amount) as total FROM transactions 
                            WHERE user_id = ? AND type = 'bid_hold' AND reference_id = ? AND status = 'completed'";
                $held_stmt = $conn->prepare($held_sql);
                $held_stmt->bind_param("ii", $bidder_id, $vehicle_id);
                $held_stmt->execute();
                $held_amount = $held_stmt->get_result()->fetch_assoc()['total'] ?? 0;
                
                if ($held_amount > 0) {
                    // Release funds
                    $release_sql = "INSERT INTO transactions (user_id, amount, type, status, reference_id, created_at) 
                                   VALUES (?, ?, 'bid_release', 'completed', ?, NOW())";
                    $release_stmt = $conn->prepare($release_sql);
                    $release_stmt->bind_param("idi", $bidder_id, $held_amount, $vehicle_id);
                    $release_stmt->execute();
                    
                    // Update user balance
                    $balance_sql = "UPDATE users SET balance = balance + ? WHERE user_id = ?";
                    $balance_stmt = $conn->prepare($balance_sql);
                    $balance_stmt->bind_param("di", $held_amount, $bidder_id);
                    $balance_stmt->execute();
                    
                    // Send notification
                    $notification_title = "Lelang Berakhir Tanpa Pemenang";
                    $notification_message = "Lelang untuk " . $vehicle['title'] . " telah berakhir tanpa pemenang. Dana Anda telah dikembalikan.";
                    
                    if (function_exists('send_notification')) {
                        send_notification($bidder_id, 'auction_end', $notification_title, $notification_message);
                    }
                }
            }
        }
        
        // Update vehicle status
        $update_sql = "UPDATE vehicles SET status = ? WHERE vehicle_id = ?";
        $update_stmt = $conn->prepare($update_sql);
        $update_stmt->bind_param("si", $status, $vehicle_id);
        $update_stmt->execute();
        
        // Commit transaction
        $conn->commit();
        
        return true;
        
    } catch (Exception $e) {
        // Rollback on error
        $conn->rollback();
        error_log("Auction end processing error: " . $e->getMessage());
        return false;
    }
}
?>