<?php
/**
 * Error Handler
 * LelangMobil Web App - Versi 2025
 * 
 * File untuk menangani error dan mencatat log
 */

// Set error handler
set_error_handler('custom_error_handler');
set_exception_handler('custom_exception_handler');
register_shutdown_function('fatal_error_handler');

// Direktori log
$log_dir = __DIR__ . '/logs';

// Buat direktori log jika belum ada
if (!file_exists($log_dir)) {
    mkdir($log_dir, 0755, true);
}

/**
 * Custom error handler
 */
function custom_error_handler($errno, $errstr, $errfile, $errline) {
    global $log_dir;
    
    // Jangan laporkan error yang dimatikan oleh error_reporting
    if (!(error_reporting() & $errno)) {
        return false;
    }
    
    // Dapatkan jenis error
    $error_type = get_error_type($errno);
    
    // Format pesan error
    $error_message = date('[Y-m-d H:i:s]') . " {$error_type}: {$errstr} in {$errfile} on line {$errline}\n";
    
    // Tulis ke log
    error_log($error_message, 3, "{$log_dir}/error.log");
    
    // Jika fatal error, tampilkan halaman error
    if ($errno == E_ERROR || $errno == E_USER_ERROR) {
        ob_clean();
        include 'error.php';
        exit;
    }
    
    return true;
}

/**
 * Custom exception handler
 */
function custom_exception_handler($exception) {
    global $log_dir;
    
    // Format pesan exception
    $error_message = date('[Y-m-d H:i:s]') . " Uncaught Exception: " . $exception->getMessage() . 
                     " in " . $exception->getFile() . " on line " . $exception->getLine() . "\n";
    $error_message .= "Stack trace: " . $exception->getTraceAsString() . "\n";
    
    // Tulis ke log
    error_log($error_message, 3, "{$log_dir}/error.log");
    
    // Tampilkan halaman error
    ob_clean();
    include 'error.php';
    exit;
}

/**
 * Fatal error handler
 */
function fatal_error_handler() {
    $error = error_get_last();
    
    if ($error !== null && ($error['type'] === E_ERROR || $error['type'] === E_PARSE || $error['type'] === E_COMPILE_ERROR)) {
        global $log_dir;
        
        // Format pesan error
        $error_message = date('[Y-m-d H:i:s]') . " Fatal Error: " . $error['message'] . 
                         " in " . $error['file'] . " on line " . $error['line'] . "\n";
        
        // Tulis ke log
        error_log($error_message, 3, "{$log_dir}/error.log");
        
        // Tampilkan halaman error
        ob_clean();
        include 'error.php';
        exit;
    }
}

/**
 * Dapatkan jenis error
 */
function get_error_type($errno) {
    switch ($errno) {
        case E_ERROR:
            return 'Fatal Error';
        case E_WARNING:
            return 'Warning';
        case E_PARSE:
            return 'Parse Error';
        case E_NOTICE:
            return 'Notice';
        case E_CORE_ERROR:
            return 'Core Error';
        case E_CORE_WARNING:
            return 'Core Warning';
        case E_COMPILE_ERROR:
            return 'Compile Error';
        case E_COMPILE_WARNING:
            return 'Compile Warning';
        case E_USER_ERROR:
            return 'User Error';
        case E_USER_WARNING:
            return 'User Warning';
        case E_USER_NOTICE:
            return 'User Notice';
        case E_STRICT:
            return 'Strict';
        case E_RECOVERABLE_ERROR:
            return 'Recoverable Error';
        case E_DEPRECATED:
            return 'Deprecated';
        case E_USER_DEPRECATED:
            return 'User Deprecated';
        default:
            return 'Unknown Error';
    }
}