/**
 * Modern Address Interaction JS
 * LelangMobil Web App - Versi 2025
 * Enhanced version with improved interactivity
 */

document.addEventListener('DOMContentLoaded', function() {
    // Get form elements that will be used throughout the script
    const provinceSelect = document.getElementById('province');
    const citySelect = document.getElementById('city');
    const addressForm = document.getElementById('addressForm');
    // Initialize toast container
    const toastContainer = document.createElement('div');
    toastContainer.className = 'address-toast-container';
    document.body.appendChild(toastContainer);
    
    // Toast notification function
    function showToast(type, title, message, duration = 5000) {
        const toast = document.createElement('div');
        toast.className = `address-toast ${type}`;
        
        let iconClass = 'fa-info-circle';
        if (type === 'success') iconClass = 'fa-check-circle';
        if (type === 'error') iconClass = 'fa-exclamation-circle';
        if (type === 'warning') iconClass = 'fa-exclamation-triangle';
        
        toast.innerHTML = `
            <div class="address-toast-icon">
                <i class="fas ${iconClass}"></i>
            </div>
            <div class="address-toast-content">
                <div class="address-toast-title">${title}</div>
                <div class="address-toast-message">${message}</div>
            </div>
            <button class="address-toast-close">
                <i class="fas fa-times"></i>
            </button>
        `;
        
        toastContainer.appendChild(toast);
        
        // Auto-remove after duration
        const timeout = setTimeout(() => {
            toast.style.animation = 'slide-out 0.3s forwards';
            setTimeout(() => {
                toast.remove();
            }, 300);
        }, duration);
        
        // Handle close button
        const closeButton = toast.querySelector('.address-toast-close');
        closeButton.addEventListener('click', () => {
            clearTimeout(timeout);
            toast.style.animation = 'slide-out 0.3s forwards';
            setTimeout(() => {
                toast.remove();
            }, 300);
        });
    }
    
    // Form validation functions
    
    // Real-time form validation
    function validateField(field) {
        if (field.hasAttribute('required') && !field.value.trim()) {
            field.classList.add('is-invalid');
            field.classList.remove('is-valid');
            
            // Check if error message exists, if not create one
            let errorMessage = field.nextElementSibling;
            if (!errorMessage || !errorMessage.classList.contains('invalid-feedback')) {
                errorMessage = document.createElement('div');
                errorMessage.className = 'invalid-feedback';
                field.parentNode.insertBefore(errorMessage, field.nextSibling);
            }
            
            // Set error message
            const fieldName = field.previousElementSibling.textContent.replace('*', '').trim();
            errorMessage.textContent = `${fieldName} tidak boleh kosong`;
            
            return false;
        } else {
            if (field.value.trim()) {
                field.classList.add('is-valid');
                field.classList.remove('is-invalid');
                
                // Check if error message exists and remove it
                const errorMessage = field.nextElementSibling;
                if (errorMessage && errorMessage.classList.contains('invalid-feedback')) {
                    errorMessage.remove();
                }
            } else {
                field.classList.remove('is-valid');
                field.classList.remove('is-invalid');
            }
            
            return true;
        }
    }
    
    // Form fields real-time validation
    if (addressForm) {
        const formFields = addressForm.querySelectorAll('input, select, textarea');
        
        formFields.forEach(field => {
            field.addEventListener('blur', function() {
                validateField(this);
            });
            
            field.addEventListener('input', function() {
                if (this.classList.contains('is-invalid')) {
                    validateField(this);
                }
            });
        });
        
        // Special handling for address type
        const addressType = document.getElementById('address_type');
        const addressLabel = document.getElementById('address_label');
        
        if (addressType && addressLabel) {
            addressType.addEventListener('change', function() {
                if (this.value === 'other') {
                    addressLabel.setAttribute('required', 'required');
                    addressLabel.nextElementSibling.innerHTML = '<small class="text-danger">* Wajib diisi untuk tipe alamat Lainnya</small>';
                } else {
                    addressLabel.removeAttribute('required');
                    addressLabel.nextElementSibling.innerHTML = '<small class="text-muted">Opsional untuk tipe alamat ini</small>';
                }
            });
        }
        
        // Validate the whole form before submission
        addressForm.addEventListener('submit', function(e) {
            let isValid = true;
            
            // Validate all required fields
            const requiredFields = this.querySelectorAll('[required]');
            requiredFields.forEach(field => {
                if (!validateField(field)) {
                    isValid = false;
                }
            });
            
            // Additional validation for address type "other"
            if (addressType && addressType.value === 'other' && (!addressLabel.value.trim())) {
                addressLabel.classList.add('is-invalid');
                isValid = false;
                
                // Add error message if doesn't exist
                let errorMessage = addressLabel.nextElementSibling;
                if (!errorMessage || !errorMessage.classList.contains('invalid-feedback')) {
                    errorMessage = document.createElement('div');
                    errorMessage.className = 'invalid-feedback';
                    addressLabel.parentNode.insertBefore(errorMessage, addressLabel.nextSibling);
                }
                errorMessage.textContent = 'Label alamat wajib diisi untuk tipe Lainnya';
            }
            
            if (!isValid) {
                e.preventDefault();
                showToast('error', 'Validasi Gagal', 'Mohon periksa kembali form dan lengkapi semua field yang diperlukan.');
            } else {
                // Add loading animation to button
                const submitButton = this.querySelector('button[type="submit"]');
                const originalText = submitButton.innerHTML;
                submitButton.innerHTML = '<span class="loading-spinner"></span> Menyimpan...';
                submitButton.disabled = true;
                
                // Add progress animation
                const progressBar = document.createElement('div');
                progressBar.className = 'animated-progress';
                this.parentNode.prepend(progressBar);
                progressBar.style.display = 'block';
                
                // Revert back after submission or timeout
                setTimeout(() => {
                    submitButton.innerHTML = originalText;
                    submitButton.disabled = false;
                    progressBar.style.display = 'none';
                }, 10000); // Fallback timeout
            }
        });
    }
    
    // Handle edit address button
    const editButtons = document.querySelectorAll('.edit-address-btn, .edit-address');
    const modalTitle = document.getElementById('addAddressModalLabel');
    const addAddressModal = document.getElementById('addAddressModal');
    let modal;
    
    if (addAddressModal) {
        modal = new bootstrap.Modal(addAddressModal);
    }
    
    // Form steps management
    const formSteps = document.querySelectorAll('.form-step');
    const stepIndicators = document.querySelectorAll('.step');
    const stepButtons = {
        next: document.querySelectorAll('.btn-next-step'),
        prev: document.querySelectorAll('.btn-prev-step')
    };
    
    let currentStep = 0;
    
    // Initialize multi-step form if it exists
    if (formSteps.length > 0) {
        // Show only the first step initially
        showFormStep(0);
        
        // Handle next buttons
        stepButtons.next.forEach(button => {
            button.addEventListener('click', function() {
                const stepIndex = parseInt(this.getAttribute('data-step'));
                if (validateStep(stepIndex)) {
                    showFormStep(stepIndex + 1);
                }
            });
        });
        
        // Handle previous buttons
        stepButtons.prev.forEach(button => {
            button.addEventListener('click', function() {
                const stepIndex = parseInt(this.getAttribute('data-step'));
                showFormStep(stepIndex - 1);
            });
        });
    }
    
    // Function to show a specific form step
    function showFormStep(stepIndex) {
        if (stepIndex < 0 || stepIndex >= formSteps.length) return;
        
        // Hide all steps
        formSteps.forEach(step => step.style.display = 'none');
        
        // Show the current step
        formSteps[stepIndex].style.display = 'block';
        
        // Update step indicators
        stepIndicators.forEach((indicator, index) => {
            if (index < stepIndex) {
                indicator.classList.remove('active');
                indicator.classList.add('completed');
            } else if (index === stepIndex) {
                indicator.classList.add('active');
                indicator.classList.remove('completed');
            } else {
                indicator.classList.remove('active', 'completed');
            }
        });
        
        // Update current step tracker
        currentStep = stepIndex;
        
        // Animate the current step
        formSteps[stepIndex].classList.add('animate__animated', 'animate__fadeIn');
        setTimeout(() => {
            formSteps[stepIndex].classList.remove('animate__animated', 'animate__fadeIn');
        }, 500);
    }
    
    // Validate the current step before proceeding
    function validateStep(stepIndex) {
        const currentStepElement = formSteps[stepIndex];
        const requiredFields = currentStepElement.querySelectorAll('[required]');
        let isValid = true;
        
        requiredFields.forEach(field => {
            if (!validateField(field)) {
                isValid = false;
            }
        });
        
        if (!isValid) {
            showToast('warning', 'Harap lengkapi semua field yang diperlukan');
            currentStepElement.scrollIntoView({ behavior: 'smooth' });
        }
        
        return isValid;
    }
    
    // Initialize province-city dependent dropdown if available
    if (provinceSelect && citySelect) {
        // Map of provinces to cities for demonstration
        const cityData = {
            'DKI Jakarta': ['Jakarta Pusat', 'Jakarta Utara', 'Jakarta Barat', 'Jakarta Selatan', 'Jakarta Timur', 'Kepulauan Seribu'],
            'Jawa Barat': ['Bandung', 'Bekasi', 'Bogor', 'Cimahi', 'Cirebon', 'Depok', 'Sukabumi', 'Tasikmalaya'],
            'Jawa Tengah': ['Semarang', 'Solo', 'Magelang', 'Pekalongan', 'Salatiga', 'Tegal'],
            'Jawa Timur': ['Surabaya', 'Malang', 'Batu', 'Blitar', 'Kediri', 'Madiun', 'Mojokerto', 'Pasuruan', 'Probolinggo'],
            'Banten': ['Serang', 'Cilegon', 'Tangerang', 'Tangerang Selatan'],
            'DI Yogyakarta': ['Yogyakarta', 'Bantul', 'Sleman', 'Kulon Progo', 'Gunung Kidul']
        };
        
        provinceSelect.addEventListener('change', function() {
            const selectedProvince = this.value;
            
            // Clear current options
            citySelect.innerHTML = '<option value="">Pilih Kota/Kabupaten</option>';
            
            // Add new options based on selected province
            if (selectedProvince && cityData[selectedProvince]) {
                cityData[selectedProvince].forEach(city => {
                    const option = document.createElement('option');
                    option.value = city;
                    option.textContent = city;
                    citySelect.appendChild(option);
                });
            }
        });
    }
    
    editButtons.forEach(button => {
        button.addEventListener('click', function() {
            // Reset form validation state
            const formFields = addressForm.querySelectorAll('.is-invalid, .is-valid');
            formFields.forEach(field => {
                field.classList.remove('is-invalid', 'is-valid');
                
                // Remove any error messages
                const errorMessage = field.nextElementSibling;
                if (errorMessage && errorMessage.classList.contains('invalid-feedback')) {
                    errorMessage.remove();
                }
            });
            
            // Get address data from attributes
            const addressId = this.getAttribute('data-id');
            const addressType = this.getAttribute('data-type');
            const addressLabel = this.getAttribute('data-label') || '';
            const recipientName = this.getAttribute('data-recipient');
            const phone = this.getAttribute('data-phone');
            const province = this.getAttribute('data-province');
            const city = this.getAttribute('data-city');
            const district = this.getAttribute('data-district') || '';
            const postalCode = this.getAttribute('data-postal') || '';
            const fullAddress = this.getAttribute('data-address');
            const isDefault = this.getAttribute('data-default') === '1';
            
            // Set form values
            document.getElementById('address_id').value = addressId;
            document.getElementById('address_type').value = addressType;
            document.getElementById('address_label').value = addressLabel;
            document.getElementById('recipient_name').value = recipientName;
            document.getElementById('phone').value = phone;
            document.getElementById('province').value = province;
            document.getElementById('city').value = city;
            document.getElementById('district').value = district;
            document.getElementById('postal_code').value = postalCode;
            document.getElementById('full_address').value = fullAddress;
            document.getElementById('is_default').checked = isDefault;
            
            // Update modal title
            modalTitle.innerHTML = '<i class="fas fa-edit"></i> Edit Alamat';
            
            // Reset step to first step for edit action
            if (formSteps.length > 0) {
                showFormStep(0);
            }
            
            // Open modal
            if (modal) modal.show();
        });
    });
    
    // Reset form when adding new address
    const addAddressButtons = document.querySelectorAll('button[data-bs-target="#addAddressModal"]:not(.edit-address-btn)');
    
    addAddressButtons.forEach(button => {
        button.addEventListener('click', function() {
            // Reset form
            if (addressForm) addressForm.reset();
            
            // Reset validation state
            const formFields = addressForm.querySelectorAll('.is-invalid, .is-valid');
            formFields.forEach(field => {
                field.classList.remove('is-invalid', 'is-valid');
                
                // Remove any error messages
                const errorMessage = field.nextElementSibling;
                if (errorMessage && errorMessage.classList.contains('invalid-feedback')) {
                    errorMessage.remove();
                }
            });
            
            // Reset to first step for new address
            if (formSteps.length > 0) {
                showFormStep(0);
            }
            
            // Reset hidden fields and modal title
            document.getElementById('address_id').value = '';
            modalTitle.innerHTML = '<i class="fas fa-plus"></i> Tambah Alamat Baru';
            
            // Reset address label help text
            if (addressType && addressType.value !== 'other' && addressLabel) {
                addressLabel.removeAttribute('required');
                addressLabel.nextElementSibling.innerHTML = '<small class="text-muted">Opsional untuk tipe alamat ini</small>';
            }
        });
    });
    
    // Add form submission animation and validation
    if (addressForm) {
        addressForm.addEventListener('submit', function(e) {
            if (formSteps.length > 0) {
                // For multi-step form, validate the final step
                if (!validateStep(currentStep)) {
                    e.preventDefault();
                    return false;
                }
            } else {
                // For single-step form, validate all fields
                let isValid = true;
                const requiredFields = this.querySelectorAll('[required]');
                
                requiredFields.forEach(field => {
                    if (!validateField(field)) {
                        isValid = false;
                    }
                });
                
                if (!isValid) {
                    e.preventDefault();
                    showToast('warning', 'Harap lengkapi semua field yang diperlukan');
                    return false;
                }
            }
            
            // If valid, show loading animation
            const submitButton = this.querySelector('[type="submit"]');
            const originalText = submitButton.innerHTML;
            submitButton.disabled = true;
            submitButton.innerHTML = '<span class="spinner-border spinner-border-sm me-2" role="status" aria-hidden="true"></span>Menyimpan...';
            
            // Add success message in toast after submission
            showToast('success', 'Data alamat sedang diproses...');
            
            return true;
        });
    }
    
    // Handle set as default button
    const defaultButtons = document.querySelectorAll('.set-default-btn');
    
    defaultButtons.forEach(button => {
        button.addEventListener('click', function() {
            const addressId = this.getAttribute('data-id');
            const addressName = this.getAttribute('data-name');
            
            // Confirm before setting as default
            if (confirm(`Jadikan alamat "${addressName}" sebagai alamat utama?`)) {
                // Add loading spinner
                const originalText = this.innerHTML;
                this.innerHTML = '<span class="loading-spinner"></span> Mengubah...';
                this.disabled = true;
                
                // Create and submit the form
                const form = document.createElement('form');
                form.method = 'post';
                form.style.display = 'none';
                
                const action = document.createElement('input');
                action.type = 'hidden';
                action.name = 'action';
                action.value = 'set_default_address';
                
                const id = document.createElement('input');
                id.type = 'hidden';
                id.name = 'address_id';
                id.value = addressId;
                
                form.appendChild(action);
                form.appendChild(id);
                document.body.appendChild(form);
                
                form.submit();
            }
        });
    });
    
    // Handle delete address button
    const deleteButtons = document.querySelectorAll('.delete-address-btn');
    
    deleteButtons.forEach(button => {
        button.addEventListener('click', function() {
            const addressId = this.getAttribute('data-id');
            const addressName = this.getAttribute('data-name');
            
            // Confirm before deleting
            if (confirm(`Apakah Anda yakin ingin menghapus alamat "${addressName}"? Tindakan ini tidak dapat dibatalkan.`)) {
                // Add loading spinner
                const originalText = this.innerHTML;
                this.innerHTML = '<span class="loading-spinner"></span> Menghapus...';
                this.disabled = true;
                
                // Create and submit the form
                const form = document.createElement('form');
                form.method = 'post';
                form.style.display = 'none';
                
                const action = document.createElement('input');
                action.type = 'hidden';
                action.name = 'action';
                action.value = 'delete_address';
                
                const id = document.createElement('input');
                id.type = 'hidden';
                id.name = 'address_id';
                id.value = addressId;
                
                form.appendChild(action);
                form.appendChild(id);
                document.body.appendChild(form);
                
                form.submit();
            }
        });
    });
    
    // Handle automatic city/district suggestion
    const provinceSelect = document.getElementById('province');
    const cityInput = document.getElementById('city');
    
    if (provinceSelect && cityInput) {
        provinceSelect.addEventListener('change', function() {
            // Reset city value when province changes
            cityInput.value = '';
            
            // Optionally, you could implement an API call here to get cities for the selected province
            // For now, we'll just focus on the city input
            cityInput.focus();
        });
    }
    
    // Show success toast if there's a success message
    const successMessage = document.querySelector('.modern-alert-success');
    if (successMessage) {
        const message = successMessage.textContent.trim();
        if (message) {
            // Hide the alert
            successMessage.style.display = 'none';
            
            // Show as toast instead
            showToast('success', 'Berhasil', message);
        }
    }
    
    // Show error toast if there's an error message
    const errorMessage = document.querySelector('.modern-alert-danger');
    if (errorMessage) {
        const message = errorMessage.textContent.trim();
        if (message) {
            // Hide the alert
            errorMessage.style.display = 'none';
            
            // Show as toast instead
            showToast('error', 'Terjadi Kesalahan', message);
        }
    }
    
    // Handle phone number formatting
    const phoneInput = document.getElementById('phone');
    if (phoneInput) {
        phoneInput.addEventListener('input', function(e) {
            // Remove non-numeric characters
            let value = e.target.value.replace(/\D/g, '');
            
            // Format with proper spacing
            if (value.length > 4) {
                value = value.slice(0, 4) + ' ' + value.slice(4);
            }
            if (value.length > 9) {
                value = value.slice(0, 9) + ' ' + value.slice(9);
            }
            
            // Update the input value
            e.target.value = value;
        });
    }
    
    // Handle postal code formatting
    const postalInput = document.getElementById('postal_code');
    if (postalInput) {
        postalInput.addEventListener('input', function(e) {
            // Remove non-numeric characters
            let value = e.target.value.replace(/\D/g, '');
            
            // Limit to 5 digits
            if (value.length > 5) {
                value = value.slice(0, 5);
            }
            
            // Update the input value
            e.target.value = value;
        });
    }
    
        // Add hover effects for address cards
    const addressCards = document.querySelectorAll('.address-card');
    addressCards.forEach(card => {
        card.addEventListener('mouseenter', function() {
            const actionsDiv = this.querySelector('.address-actions');
            if (actionsDiv) {
                actionsDiv.style.opacity = '1';
                actionsDiv.style.transform = 'translateY(0)';
            }
        });
        
        card.addEventListener('mouseleave', function() {
            const actionsDiv = this.querySelector('.address-actions');
            if (actionsDiv) {
                actionsDiv.style.opacity = '0.7';
                actionsDiv.style.transform = 'translateY(5px)';
            }
        });
    });
    
    // Add animation to newly added address cards
    function animateNewElements() {
        const newElements = document.querySelectorAll('.address-card:not(.animated)');
        newElements.forEach(element => {
            element.classList.add('animate__animated', 'animate__fadeInUp', 'animated');
            setTimeout(() => {
                element.classList.remove('animate__animated', 'animate__fadeInUp');
            }, 1000);
        });
    }
    
    // Run animation on load
    animateNewElements();
    
    // Initialize Google Maps autocomplete if available
    const fullAddressField = document.getElementById('full_address');
    if (fullAddressField && window.google && window.google.maps) {
        const autocomplete = new google.maps.places.Autocomplete(fullAddressField, {
            types: ['address'],
            componentRestrictions: {country: 'id'}
        });
        
        autocomplete.addListener('place_changed', function() {
            const place = autocomplete.getPlace();
            if (!place.geometry) return;
            
            // Extract address components
            for (const component of place.address_components) {
                const componentType = component.types[0];
                
                switch (componentType) {
                    case "administrative_area_level_1":
                        // Province
                        if (provinceSelect) {
                            setSelectValue(provinceSelect, component.long_name);
                        }
                        break;
                    case "administrative_area_level_2":
                    case "locality":
                        // City
                        if (citySelect) {
                            setTimeout(() => {
                                setSelectValue(citySelect, component.long_name);
                            }, 100);
                        }
                        break;
                    case "sublocality_level_1":
                        // District
                        const districtField = document.getElementById('district');
                        if (districtField) {
                            districtField.value = component.long_name;
                        }
                        break;
                    case "postal_code":
                        // Postal code
                        const postalField = document.getElementById('postal_code');
                        if (postalField) {
                            postalField.value = component.long_name;
                        }
                        break;
                }
            }
        });
    }
    
    // Helper function to set select value by text
    function setSelectValue(selectElement, textToMatch) {
        for (const option of selectElement.options) {
            if (option.text.includes(textToMatch)) {
                selectElement.value = option.value;
                selectElement.dispatchEvent(new Event('change'));
                break;
            }
        }
    }
});
