/**
 * Modern Effects JavaScript
 * LelangMobil Web App - Versi 2025
 */

document.addEventListener('DOMContentLoaded', function() {
    // Initialize scroll reveal effects
    initScrollReveal();
    
    // Initialize hover effects
    initHoverEffects();
    
    // Initialize parallax effects
    initParallax();
    
    // Initialize 3D card effects
    init3DCards();
});

/**
 * Initialize scroll reveal animations
 */
function initScrollReveal() {
    const scrollRevealElements = document.querySelectorAll('.scroll-reveal');
    
    if (scrollRevealElements.length === 0) return;
    
    const observer = new IntersectionObserver((entries) => {
        entries.forEach(entry => {
            if (entry.isIntersecting) {
                entry.target.classList.add('revealed');
                observer.unobserve(entry.target);
            }
        });
    }, {
        threshold: 0.1
    });
    
    scrollRevealElements.forEach(element => {
        observer.observe(element);
    });
}

/**
 * Initialize hover effects
 */
function initHoverEffects() {
    // Card hover border effect
    document.querySelectorAll('.card-hover-border').forEach(card => {
        card.addEventListener('mouseenter', function() {
            this.style.borderColor = getComputedStyle(document.documentElement).getPropertyValue('--primary').trim();
        });
        
        card.addEventListener('mouseleave', function() {
            this.style.borderColor = 'transparent';
        });
    });
    
    // Button ripple effect
    document.querySelectorAll('.btn-ripple').forEach(button => {
        button.addEventListener('click', function(e) {
            const rect = this.getBoundingClientRect();
            const x = e.clientX - rect.left;
            const y = e.clientY - rect.top;
            
            const ripple = document.createElement('span');
            ripple.classList.add('ripple');
            ripple.style.left = `${x}px`;
            ripple.style.top = `${y}px`;
            
            this.appendChild(ripple);
            
            setTimeout(() => {
                ripple.remove();
            }, 600);
        });
    });
}

/**
 * Initialize parallax effects
 */
function initParallax() {
    const parallaxElements = document.querySelectorAll('.parallax');
    
    if (parallaxElements.length === 0) return;
    
    window.addEventListener('scroll', function() {
        parallaxElements.forEach(element => {
            const scrollPosition = window.pageYOffset;
            const speed = element.dataset.speed || 0.5;
            element.style.backgroundPositionY = `${scrollPosition * speed}px`;
        });
    });
}

/**
 * Initialize 3D card effects
 */
function init3DCards() {
    const cards = document.querySelectorAll('.card-3d');
    
    if (cards.length === 0) return;
    
    cards.forEach(card => {
        card.addEventListener('mousemove', function(e) {
            const rect = this.getBoundingClientRect();
            const x = e.clientX - rect.left;
            const y = e.clientY - rect.top;
            
            const centerX = rect.width / 2;
            const centerY = rect.height / 2;
            
            const angleY = (x - centerX) / 20;
            const angleX = (centerY - y) / 20;
            
            this.style.transform = `rotateY(${angleY}deg) rotateX(${angleX}deg)`;
        });
        
        card.addEventListener('mouseleave', function() {
            this.style.transform = 'rotateY(0deg) rotateX(0deg)';
        });
    });
}

/**
 * Add typing effect to element
 * @param {HTMLElement} element - Element to add typing effect to
 * @param {string} text - Text to type
 * @param {number} speed - Typing speed in milliseconds
 */
function addTypingEffect(element, text, speed = 100) {
    let i = 0;
    element.textContent = '';
    element.classList.add('typing');
    
    function type() {
        if (i < text.length) {
            element.textContent += text.charAt(i);
            i++;
            setTimeout(type, speed);
        } else {
            element.classList.remove('typing');
        }
    }
    
    type();
}

/**
 * Add floating animation to element
 * @param {HTMLElement} element - Element to add floating animation to
 * @param {number} amplitude - Floating amplitude in pixels
 * @param {number} period - Floating period in seconds
 */
function addFloatingEffect(element, amplitude = 10, period = 3) {
    let startPosition = 0;
    let time = 0;
    
    function animate() {
        time += 0.05;
        const position = startPosition + amplitude * Math.sin(2 * Math.PI * time / period);
        element.style.transform = `translateY(${position}px)`;
        requestAnimationFrame(animate);
    }
    
    animate();
}

/**
 * Add shine effect to element
 * @param {HTMLElement} element - Element to add shine effect to
 */
function addShineEffect(element) {
    element.classList.add('shine');
}

/**
 * Add pulse animation to element
 * @param {HTMLElement} element - Element to add pulse animation to
 */
function addPulseEffect(element) {
    element.classList.add('btn-pulse');
}

/**
 * Add bounce animation to element
 * @param {HTMLElement} element - Element to add bounce animation to
 */
function addBounceEffect(element) {
    element.classList.add('bounce');
}

/**
 * Add fade-in animation to element
 * @param {HTMLElement} element - Element to add fade-in animation to
 * @param {number} delay - Animation delay in seconds
 */
function addFadeInEffect(element, delay = 0) {
    element.classList.add('fade-in');
    element.style.animationDelay = `${delay}s`;
}

/**
 * Add slide-up animation to element
 * @param {HTMLElement} element - Element to add slide-up animation to
 * @param {number} delay - Animation delay in seconds
 */
function addSlideUpEffect(element, delay = 0) {
    element.classList.add('slide-up');
    element.style.animationDelay = `${delay}s`;
}

/**
 * Add slide-down animation to element
 * @param {HTMLElement} element - Element to add slide-down animation to
 * @param {number} delay - Animation delay in seconds
 */
function addSlideDownEffect(element, delay = 0) {
    element.classList.add('slide-down');
    element.style.animationDelay = `${delay}s`;
}

/**
 * Add slide-left animation to element
 * @param {HTMLElement} element - Element to add slide-left animation to
 * @param {number} delay - Animation delay in seconds
 */
function addSlideLeftEffect(element, delay = 0) {
    element.classList.add('slide-left');
    element.style.animationDelay = `${delay}s`;
}

/**
 * Add slide-right animation to element
 * @param {HTMLElement} element - Element to add slide-right animation to
 * @param {number} delay - Animation delay in seconds
 */
function addSlideRightEffect(element, delay = 0) {
    element.classList.add('slide-right');
    element.style.animationDelay = `${delay}s`;
}

/**
 * Apply staggered animation to a group of elements
 * @param {NodeList} elements - Elements to animate
 * @param {string} animationClass - Animation class to apply
 * @param {number} staggerDelay - Delay between each element animation in seconds
 */
function applyStaggeredAnimation(elements, animationClass, staggerDelay = 0.1) {
    elements.forEach((element, index) => {
        element.classList.add(animationClass);
        element.style.animationDelay = `${index * staggerDelay}s`;
    });
}