/**
 * WebSocket Handler
 * LelangMobil Web App - Versi 2025
 */

let socket;
let reconnectAttempts = 0;
const maxReconnectAttempts = 5;
const reconnectDelay = 3000; // 3 seconds

document.addEventListener('DOMContentLoaded', function() {
    // Only initialize WebSocket if user is logged in
    if (isUserLoggedIn()) {
        initWebSocket();
    }
});

/**
 * Initialize WebSocket connection
 */
function initWebSocket() {
    // Get WebSocket server URL from meta tag
    const wsServer = getWebSocketServer();
    
    if (!wsServer) {
        console.error('WebSocket server URL not found');
        return;
    }
    
    try {
        socket = new WebSocket(wsServer);
        
        // Connection opened
        socket.addEventListener('open', function(event) {
            console.log('WebSocket connection established');
            reconnectAttempts = 0;
            
            // Send authentication message
            authenticateWebSocket();
        });
        
        // Listen for messages
        socket.addEventListener('message', function(event) {
            handleWebSocketMessage(event.data);
        });
        
        // Connection closed
        socket.addEventListener('close', function(event) {
            console.log('WebSocket connection closed');
            
            // Try to reconnect
            if (reconnectAttempts < maxReconnectAttempts) {
                reconnectAttempts++;
                setTimeout(initWebSocket, reconnectDelay);
            }
        });
        
        // Connection error
        socket.addEventListener('error', function(event) {
            console.error('WebSocket error:', event);
        });
    } catch (error) {
        console.error('Failed to initialize WebSocket:', error);
    }
}

/**
 * Authenticate WebSocket connection
 */
function authenticateWebSocket() {
    if (socket && socket.readyState === WebSocket.OPEN) {
        const userId = getUserId();
        const authToken = getAuthToken();
        
        if (userId && authToken) {
            const authMessage = {
                type: 'auth',
                userId: userId,
                token: authToken
            };
            
            socket.send(JSON.stringify(authMessage));
        }
    }
}

/**
 * Handle WebSocket messages
 */
function handleWebSocketMessage(data) {
    try {
        const message = JSON.parse(data);
        
        switch (message.type) {
            case 'notification':
                handleNotification(message.data);
                break;
                
            case 'bid_update':
                handleBidUpdate(message.data);
                break;
                
            case 'auction_status':
                handleAuctionStatus(message.data);
                break;
                
            case 'auto_bid':
                handleAutoBid(message.data);
                break;
                
            case 'transaction_update':
                handleTransactionUpdate(message.data);
                break;
                
            case 'ping':
                // Respond to ping with pong
                sendPong();
                break;
                
            default:
                console.log('Unknown message type:', message.type);
                break;
        }
    } catch (error) {
        console.error('Error parsing WebSocket message:', error);
    }
}

/**
 * Handle notification message
 */
function handleNotification(data) {
    // Update notification badge
    updateNotificationCount();
    
    // Show toast notification
    showToast(data.title, data.message);
    
    // Play notification sound
    playNotificationSound();
}

/**
 * Handle bid update message
 */
function handleBidUpdate(data) {
    // Update bid information on the page
    const bidAmountElement = document.getElementById('current-bid-amount');
    const bidderElement = document.getElementById('current-bidder');
    const bidCountElement = document.getElementById('bid-count');
    
    if (bidAmountElement) {
        bidAmountElement.textContent = formatMoney(data.bid_amount);
    }
    
    if (bidderElement) {
        bidderElement.textContent = data.bidder_name;
    }
    
    if (bidCountElement) {
        bidCountElement.textContent = data.bid_count;
    }
    
    // Update countdown if auction extended
    if (data.end_time) {
        updateAuctionEndTime(data.end_time);
    }
    
    // Show toast notification
    showToast('Bid Baru', `Bid baru sebesar ${formatMoney(data.bid_amount)} oleh ${data.bidder_name}`);
}

/**
 * Handle auction status message
 */
function handleAuctionStatus(data) {
    // Update auction status on the page
    const statusElement = document.getElementById('auction-status');
    
    if (statusElement) {
        statusElement.textContent = data.status_text;
        statusElement.className = `badge bg-${getStatusClass(data.status)}`;
    }
    
    // If auction ended, show result
    if (data.status === 'ended' || data.status === 'sold' || data.status === 'not_sold') {
        showAuctionResult(data);
    }
}

/**
 * Handle auto bid message
 */
function handleAutoBid(data) {
    // Update bid information on the page
    const bidAmountElement = document.getElementById('current-bid-amount');
    
    if (bidAmountElement) {
        bidAmountElement.textContent = formatMoney(data.bid_amount);
    }
    
    // Show toast notification if it's the user's auto bid
    if (data.is_user_bid) {
        showToast('Auto Bid', `Auto bid Anda sebesar ${formatMoney(data.bid_amount)} berhasil`);
    }
}

/**
 * Handle transaction update message
 */
function handleTransactionUpdate(data) {
    // Show toast notification
    showToast('Transaksi Update', data.message);
    
    // Update transaction status if on transaction page
    const transactionStatusElement = document.getElementById(`transaction-status-${data.transaction_id}`);
    
    if (transactionStatusElement) {
        transactionStatusElement.textContent = data.status_text;
        transactionStatusElement.className = `badge bg-${getTransactionStatusClass(data.status)}`;
    }
}

/**
 * Send pong response
 */
function sendPong() {
    if (socket && socket.readyState === WebSocket.OPEN) {
        const pongMessage = {
            type: 'pong',
            timestamp: Date.now()
        };
        
        socket.send(JSON.stringify(pongMessage));
    }
}

/**
 * Update notification count
 */
function updateNotificationCount() {
    fetch('api/notifications.php?action=count')
        .then(response => response.json())
        .then(data => {
            if (data.success) {
                const badge = document.querySelector('.notification-badge');
                
                if (badge) {
                    if (data.count > 0) {
                        badge.textContent = data.count > 99 ? '99+' : data.count;
                        badge.style.display = 'block';
                    } else {
                        badge.style.display = 'none';
                    }
                }
            }
        })
        .catch(error => console.error('Error updating notification count:', error));
}

/**
 * Show toast notification
 */
function showToast(title, message) {
    // Create toast container if not exists
    let toastContainer = document.querySelector('.toast-container');
    
    if (!toastContainer) {
        toastContainer = document.createElement('div');
        toastContainer.className = 'toast-container';
        document.body.appendChild(toastContainer);
    }
    
    // Create toast element
    const toast = document.createElement('div');
    toast.className = 'toast';
    toast.innerHTML = `
        <div class="toast-header">
            <div class="toast-title">${title}</div>
            <button type="button" class="toast-close">&times;</button>
        </div>
        <div class="toast-body">
            ${message}
        </div>
    `;
    
    // Add to container
    toastContainer.appendChild(toast);
    
    // Add close event
    const closeButton = toast.querySelector('.toast-close');
    closeButton.addEventListener('click', function() {
        toast.remove();
    });
    
    // Auto remove after 5 seconds
    setTimeout(function() {
        toast.style.opacity = '0';
        setTimeout(function() {
            toast.remove();
        }, 300);
    }, 5000);
}

/**
 * Play notification sound
 */
function playNotificationSound() {
    const audio = new Audio('assets/notification-sound.mp3');
    audio.play().catch(error => console.error('Error playing notification sound:', error));
}

/**
 * Update auction end time
 */
function updateAuctionEndTime(endTime) {
    const countdownElement = document.querySelector('.auction-countdown');
    
    if (countdownElement) {
        countdownElement.setAttribute('data-end-time', endTime);
    }
}

/**
 * Show auction result
 */
function showAuctionResult(data) {
    // Create result modal
    const modal = document.createElement('div');
    modal.className = 'modal fade';
    modal.id = 'auctionResultModal';
    modal.setAttribute('tabindex', '-1');
    modal.setAttribute('aria-labelledby', 'auctionResultModalLabel');
    modal.setAttribute('aria-hidden', 'true');
    
    let resultContent = '';
    
    if (data.status === 'sold') {
        resultContent = `
            <div class="text-center mb-4">
                <div class="auction-result-icon success">
                    <i class="fa fa-check-circle fa-3x"></i>
                </div>
                <h4 class="mt-3">Lelang Berakhir</h4>
                <p>Kendaraan terjual dengan harga ${formatMoney(data.final_price)}</p>
                <p>Pemenang: ${data.winner_name}</p>
            </div>
        `;
        
        if (data.is_winner) {
            resultContent += `
                <div class="alert alert-success">
                    <i class="fa fa-trophy me-2"></i> Selamat! Anda memenangkan lelang ini.
                </div>
                <p>Silakan lakukan pembayaran dalam waktu 24 jam untuk menyelesaikan transaksi.</p>
                <div class="d-grid">
                    <a href="payment.php?auction_id=${data.auction_id}" class="btn btn-primary">
                        <i class="fa fa-credit-card me-2"></i> Lakukan Pembayaran
                    </a>
                </div>
            `;
        }
    } else {
        resultContent = `
            <div class="text-center mb-4">
                <div class="auction-result-icon danger">
                    <i class="fa fa-times-circle fa-3x"></i>
                </div>
                <h4 class="mt-3">Lelang Berakhir</h4>
                <p>Kendaraan tidak terjual</p>
            </div>
        `;
    }
    
    modal.innerHTML = `
        <div class="modal-dialog modal-dialog-centered">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="auctionResultModalLabel">Hasil Lelang</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    ${resultContent}
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Tutup</button>
                </div>
            </div>
        </div>
    `;
    
    // Add to body
    document.body.appendChild(modal);
    
    // Show modal
    const bsModal = new bootstrap.Modal(modal);
    bsModal.show();
}

/**
 * Helper functions
 */
function isUserLoggedIn() {
    return document.querySelector('.dropdown-toggle i.fa-user-circle') !== null;
}

function getUserId() {
    const userIdMeta = document.querySelector('meta[name="user-id"]');
    return userIdMeta ? userIdMeta.getAttribute('content') : null;
}

function getAuthToken() {
    const authTokenMeta = document.querySelector('meta[name="auth-token"]');
    return authTokenMeta ? authTokenMeta.getAttribute('content') : null;
}

function getWebSocketServer() {
    const wsServerMeta = document.querySelector('meta[name="websocket-server"]');
    return wsServerMeta ? wsServerMeta.getAttribute('content') : null;
}

function formatMoney(amount) {
    return 'Rp' + parseInt(amount).toLocaleString('id-ID');
}

function getStatusClass(status) {
    const statusClasses = {
        'upcoming': 'info',
        'active': 'success',
        'ended': 'secondary',
        'sold': 'primary',
        'not_sold': 'danger'
    };
    
    return statusClasses[status] || 'secondary';
}

function getTransactionStatusClass(status) {
    const statusClasses = {
        'pending': 'warning',
        'verification': 'info',
        'completed': 'success',
        'rejected': 'danger',
        'cancelled': 'secondary'
    };
    
    return statusClasses[status] || 'secondary';
}