<?php
/**
 * Registration Page
 * LelangMobil Web App - Versi 2025
 */

// Include initialization file
require_once 'config/init.php';

// Redirect if already logged in
if (is_logged_in()) {
    header("Location: account-modern.php");
    exit;
}

$error = '';
$success = '';

// Process registration form
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['register'])) {
    // Get form data
    $username = trim($_POST['username'] ?? '');
    $email = trim($_POST['email'] ?? '');
    $password = trim($_POST['password'] ?? '');
    $confirm_password = trim($_POST['confirm_password'] ?? '');
    $full_name = trim($_POST['full_name'] ?? '');
    $phone = trim($_POST['phone'] ?? '');
    
    // Validate input
    if (empty($username) || empty($email) || empty($password) || empty($confirm_password)) {
        $error = "Semua field wajib diisi.";
    } elseif (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $error = "Format email tidak valid.";
    } elseif ($password !== $confirm_password) {
        $error = "Password dan konfirmasi password tidak cocok.";
    } elseif (strlen($password) < 8) {
        $error = "Password minimal harus 8 karakter.";
    } else {
        // Check if username or email already exists
        $check_sql = "SELECT * FROM users WHERE username = ? OR email = ?";
        $check_stmt = $conn->prepare($check_sql);
        $check_stmt->bind_param("ss", $username, $email);
        $check_stmt->execute();
        $check_result = $check_stmt->get_result();
        
        if ($check_result->num_rows > 0) {
            $user = $check_result->fetch_assoc();
            if ($user['username'] === $username) {
                $error = "Username sudah digunakan. Silakan pilih username lain.";
            } else {
                $error = "Email sudah terdaftar. Silakan gunakan email lain atau login.";
            }
        } else {
            // Hash password
            $hashed_password = password_hash($password, PASSWORD_DEFAULT);
            
            // Generate verification token
            $verification_token = bin2hex(random_bytes(32));
            $token_expiry = date('Y-m-d H:i:s', strtotime('+24 hours'));
            
            // Insert new user
            $insert_sql = "INSERT INTO users (username, email, password, full_name, phone, verification_token, token_expiry, created_at) 
                          VALUES (?, ?, ?, ?, ?, ?, ?, NOW())";
            $insert_stmt = $conn->prepare($insert_sql);
            $insert_stmt->bind_param("sssssss", $username, $email, $hashed_password, $full_name, $phone, $verification_token, $token_expiry);
            
            if ($insert_stmt->execute()) {
                // Send verification email
                if (function_exists('send_verification_email') && send_verification_email($email, $full_name ?: $username, $verification_token)) {
                    $success = "Pendaftaran berhasil! Silakan periksa email Anda untuk verifikasi akun.";
                } else {
                    $success = "Pendaftaran berhasil! Namun gagal mengirim email verifikasi. Silakan hubungi admin.";
                }
            } else {
                $error = "Gagal mendaftar. Silakan coba lagi: " . $conn->error;
            }
        }
    }
}

// Aktifkan flag untuk halaman login
$page_title = "Daftar Akun";
$is_auth_page = true;
$use_modern_auth = true;

// Custom CSS untuk halaman auth
$page_specific_css = '<link href="css/auth-modern.css" rel="stylesheet" type="text/css">';

// Include header
include("includes/header.php");
?>

<div class="auth-container">
    <div class="auth-card register-card">
        <div class="auth-card-header text-center">
            <h2><i class="fa fa-user-plus"></i> Daftar Akun</h2>
            <p class="text-muted">Buat akun baru untuk mulai mengikuti lelang</p>
        </div>
        
        <div class="auth-card-body">
            <?php if (!empty($error)): ?>
                <div class="alert alert-danger">
                    <i class="fa fa-exclamation-circle me-2"></i><?php echo $error; ?>
                </div>
            <?php endif; ?>
            
            <?php if (!empty($success)): ?>
                <div class="alert alert-success">
                    <i class="fa fa-check-circle me-2"></i><?php echo $success; ?>
                </div>
                
                <div class="registration-success text-center">
                    <div class="success-icon">
                        <i class="fa fa-envelope-open-text"></i>
                    </div>
                    <h4>Pendaftaran Berhasil!</h4>
                    <p>Silakan periksa email Anda untuk verifikasi akun.</p>
                    <p class="text-muted">Jika Anda tidak menerima email dalam beberapa menit, periksa folder spam atau <a href="resend-verification.php">kirim ulang email verifikasi</a>.</p>
                    
                    <div class="mt-4">
                        <a href="login.php" class="btn btn-primary">
                            <i class="fa fa-sign-in-alt me-2"></i>Ke Halaman Login
                        </a>
                    </div>
                </div>
            <?php else: ?>
                <form method="post" action="" id="registerForm">
                    <div class="row">
                        <div class="col-md-6 mb-3">
                            <label for="username" class="form-label">Username *</label>
                            <div class="input-group">
                                <span class="input-group-text"><i class="fa fa-user"></i></span>
                                <input type="text" class="form-control" id="username" name="username" required>
                            </div>
                        </div>
                        
                        <div class="col-md-6 mb-3">
                            <label for="email" class="form-label">Email *</label>
                            <div class="input-group">
                                <span class="input-group-text"><i class="fa fa-envelope"></i></span>
                                <input type="email" class="form-control" id="email" name="email" required>
                            </div>
                        </div>
                    </div>
                    
                    <div class="row">
                        <div class="col-md-6 mb-3">
                            <label for="password" class="form-label">Password *</label>
                            <div class="input-group">
                                <span class="input-group-text"><i class="fa fa-lock"></i></span>
                                <input type="password" class="form-control" id="password" name="password" required>
                                <button class="btn btn-outline-secondary toggle-password" type="button">
                                    <i class="fa fa-eye"></i>
                                </button>
                            </div>
                            <small class="text-muted">Minimal 8 karakter</small>
                        </div>
                        
                        <div class="col-md-6 mb-3">
                            <label for="confirm_password" class="form-label">Konfirmasi Password *</label>
                            <div class="input-group">
                                <span class="input-group-text"><i class="fa fa-lock"></i></span>
                                <input type="password" class="form-control" id="confirm_password" name="confirm_password" required>
                                <button class="btn btn-outline-secondary toggle-password" type="button">
                                    <i class="fa fa-eye"></i>
                                </button>
                            </div>
                        </div>
                    </div>
                    
                    <div class="row">
                        <div class="col-md-6 mb-3">
                            <label for="full_name" class="form-label">Nama Lengkap</label>
                            <div class="input-group">
                                <span class="input-group-text"><i class="fa fa-id-card"></i></span>
                                <input type="text" class="form-control" id="full_name" name="full_name">
                            </div>
                        </div>
                        
                        <div class="col-md-6 mb-3">
                            <label for="phone" class="form-label">Nomor Telepon</label>
                            <div class="input-group">
                                <span class="input-group-text"><i class="fa fa-phone"></i></span>
                                <input type="text" class="form-control" id="phone" name="phone">
                            </div>
                        </div>
                    </div>
                    
                    <div class="mb-3 form-check">
                        <input type="checkbox" class="form-check-input" id="terms" name="terms" required>
                        <label class="form-check-label" for="terms">
                            Saya menyetujui <a href="terms.php" target="_blank">Syarat dan Ketentuan</a> serta <a href="privacy.php" target="_blank">Kebijakan Privasi</a>
                        </label>
                    </div>
                    
                    <div class="d-grid mb-4">
                        <button type="submit" name="register" class="btn btn-primary">
                            <i class="fa fa-user-plus me-2"></i>Daftar
                        </button>
                    </div>
                    
                    <div class="text-center">
                        Sudah punya akun? <a href="login.php" class="text-decoration-none">Login di sini</a>
                    </div>
                </form>
            <?php endif; ?>
        </div>
    </div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Toggle password visibility
    const toggleButtons = document.querySelectorAll('.toggle-password');
    
    toggleButtons.forEach(button => {
        button.addEventListener('click', function() {
            const input = this.previousElementSibling;
            const icon = this.querySelector('i');
            
            if (input.type === 'password') {
                input.type = 'text';
                icon.classList.remove('fa-eye');
                icon.classList.add('fa-eye-slash');
            } else {
                input.type = 'password';
                icon.classList.remove('fa-eye-slash');
                icon.classList.add('fa-eye');
            }
        });
    });
    
    // Form validation
    const form = document.getElementById('registerForm');
    if (form) {
        form.addEventListener('submit', function(e) {
            const password = document.getElementById('password').value;
            const confirmPassword = document.getElementById('confirm_password').value;
            
            if (password.length < 8) {
                e.preventDefault();
                alert('Password minimal harus 8 karakter.');
                return false;
            }
            
            if (password !== confirmPassword) {
                e.preventDefault();
                alert('Password dan konfirmasi password tidak cocok.');
                return false;
            }
            
            return true;
        });
    }
});
</script>

<?php include("includes/footer.php"); ?>