<?php
/**
 * Run Workers
 * LelangMobil Web App - Versi 2025
 * 
 * This script runs background workers for the application
 * Run with: php run_workers.php
 */

require_once __DIR__ . '/../../config/init.php';
require_once __DIR__ . '/AutoBidWorker.php';
require_once __DIR__ . '/NotificationWorker.php';

// Set script execution time to unlimited
set_time_limit(0);

// Log file
$logFile = __DIR__ . '/../../logs/workers.log';

// Create log directory if not exists
if (!file_exists(dirname($logFile))) {
    mkdir(dirname($logFile), 0755, true);
}

// Log function
function logMessage($message) {
    global $logFile;
    $timestamp = date('Y-m-d H:i:s');
    $logMessage = "[{$timestamp}] {$message}" . PHP_EOL;
    
    // Log to file
    file_put_contents($logFile, $logMessage, FILE_APPEND);
    
    // Output to console
    echo $logMessage;
}

// Initialize workers
$autoBidWorker = new AutoBidWorker($conn);
$notificationWorker = new NotificationWorker($conn);

logMessage("Workers started");

// Main loop
while (true) {
    try {
        // Run auto bid worker
        $autoBidWorker->run();
        
        // Run notification worker
        $notificationWorker->run();
        
        // Check for ending auctions
        checkEndingAuctions();
        
        // Check for expired transactions
        checkExpiredTransactions();
        
        // Sleep for a while
        sleep(10);
    } catch (Exception $e) {
        logMessage("Error: " . $e->getMessage());
        sleep(30); // Sleep longer on error
    }
}

/**
 * Check for ending auctions
 */
function checkEndingAuctions() {
    global $conn;
    
    try {
        // Get auctions ending in the next minute
        $sql = "SELECT * FROM vehicles 
                WHERE status = 'active' 
                AND (end_date <= DATE_ADD(NOW(), INTERVAL 1 MINUTE) OR auction_end <= DATE_ADD(NOW(), INTERVAL 1 MINUTE))";
        $result = $conn->query($sql);
        
        if ($result->num_rows > 0) {
            while ($auction = $result->fetch_assoc()) {
                $vehicleId = $auction['vehicle_id'];
                $endDate = $auction['end_date'] ?? $auction['auction_end'];
                
                logMessage("Auction #{$vehicleId} ending soon at {$endDate}");
                
                // Send notification to bidders
                notifyAuctionEnding($vehicleId);
            }
        }
        
        // End auctions that have passed their end time
        $sql = "SELECT * FROM vehicles 
                WHERE status = 'active' 
                AND ((end_date IS NOT NULL AND end_date <= NOW()) 
                    OR (auction_end IS NOT NULL AND auction_end <= NOW()))";
        $result = $conn->query($sql);
        
        if ($result->num_rows > 0) {
            while ($auction = $result->fetch_assoc()) {
                $vehicleId = $auction['vehicle_id'];
                endAuction($vehicleId);
            }
        }
    } catch (Exception $e) {
        logMessage("Error checking ending auctions: " . $e->getMessage());
    }
}

/**
 * End auction
 */
function endAuction($vehicleId) {
    global $conn;
    
    try {
        // Get auction details
        $sql = "SELECT * FROM vehicles WHERE vehicle_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $vehicleId);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows === 0) {
            logMessage("Auction #{$vehicleId} not found");
            return;
        }
        
        $auction = $result->fetch_assoc();
        $currentBid = $auction['current_bid'] ?? $auction['current_price'] ?? 0;
        $currentBidder = $auction['current_bidder'] ?? null;
        $reservePrice = $auction['reserve_price'] ?? 0;
        
        // Check if auction has bids and meets reserve price
        if ($currentBidder && $currentBid >= $reservePrice) {
            // Auction sold
            $sql = "UPDATE vehicles SET status = 'sold' WHERE vehicle_id = ?";
            $stmt = $conn->prepare($sql);
            $stmt->bind_param("i", $vehicleId);
            $stmt->execute();
            
            logMessage("Auction #{$vehicleId} ended - SOLD for {$currentBid} to bidder #{$currentBidder}");
            
            // Create transaction for winner
            createWinningTransaction($vehicleId, $currentBidder, $currentBid);
            
            // Notify winner and seller
            notifyAuctionWinner($vehicleId, $currentBidder);
            notifyAuctionSeller($vehicleId, true);
        } else {
            // Auction not sold
            $sql = "UPDATE vehicles SET status = 'not_sold' WHERE vehicle_id = ?";
            $stmt = $conn->prepare($sql);
            $stmt->bind_param("i", $vehicleId);
            $stmt->execute();
            
            logMessage("Auction #{$vehicleId} ended - NOT SOLD");
            
            // Release bidder's balance if there was a bid
            if ($currentBidder) {
                releaseUserBalance($currentBidder, $currentBid, $vehicleId);
            }
            
            // Notify seller
            notifyAuctionSeller($vehicleId, false);
        }
        
        // Notify all bidders
        notifyAllBidders($vehicleId);
    } catch (Exception $e) {
        logMessage("Error ending auction #{$vehicleId}: " . $e->getMessage());
    }
}

/**
 * Create winning transaction
 */
function createWinningTransaction($vehicleId, $userId, $amount) {
    global $conn;
    
    try {
        // Insert transaction
        $sql = "INSERT INTO transactions (user_id, amount, type, status, reference_number, created_at) 
                VALUES (?, ?, 'bid_win', 'completed', ?, NOW())";
        $stmt = $conn->prepare($sql);
        $reference = "WIN-" . $vehicleId . "-" . time();
        $stmt->bind_param("ids", $userId, $amount, $reference);
        $stmt->execute();
        
        // Update user pending balance
        $sql = "UPDATE users 
                SET pending_balance = pending_balance - ? 
                WHERE user_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("di", $amount, $userId);
        $stmt->execute();
        
        logMessage("Created winning transaction for user #{$userId} for auction #{$vehicleId} - Amount: {$amount}");
    } catch (Exception $e) {
        logMessage("Error creating winning transaction: " . $e->getMessage());
    }
}

/**
 * Release user balance
 */
function releaseUserBalance($userId, $amount, $vehicleId) {
    global $conn;
    
    try {
        // Insert transaction
        $sql = "INSERT INTO transactions (user_id, amount, type, status, reference_number, created_at) 
                VALUES (?, ?, 'bid_release', 'completed', ?, NOW())";
        $stmt = $conn->prepare($sql);
        $reference = "RELEASE-" . $vehicleId . "-" . time();
        $stmt->bind_param("ids", $userId, $amount, $reference);
        $stmt->execute();
        
        // Update user balance
        $sql = "UPDATE users 
                SET balance = balance + ?, pending_balance = pending_balance - ? 
                WHERE user_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("ddi", $amount, $amount, $userId);
        $stmt->execute();
        
        logMessage("Released balance for user #{$userId} for auction #{$vehicleId} - Amount: {$amount}");
    } catch (Exception $e) {
        logMessage("Error releasing balance: " . $e->getMessage());
    }
}

/**
 * Notify auction ending
 */
function notifyAuctionEnding($vehicleId) {
    global $conn;
    
    try {
        // Get auction details
        $sql = "SELECT v.*, 
                COALESCE(v.brand, v.make) as brand, 
                COALESCE(v.model, '') as model 
                FROM vehicles v 
                WHERE v.vehicle_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $vehicleId);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows === 0) {
            return;
        }
        
        $auction = $result->fetch_assoc();
        $vehicleName = $auction['brand'] . ' ' . $auction['model'];
        
        // Get all bidders
        $sql = "SELECT DISTINCT bidder_id FROM bids WHERE vehicle_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $vehicleId);
        $stmt->execute();
        $result = $stmt->get_result();
        
        while ($row = $result->fetch_assoc()) {
            $bidderId = $row['bidder_id'];
            
            // Insert notification
            $title = "Lelang Akan Berakhir";
            $message = "Lelang untuk {$vehicleName} akan berakhir dalam beberapa menit.";
            $url = "vehicle.php?id={$vehicleId}";
            
            insertNotification($bidderId, 'auction', $title, $message, $url);
        }
        
        logMessage("Sent ending notifications for auction #{$vehicleId}");
    } catch (Exception $e) {
        logMessage("Error notifying auction ending: " . $e->getMessage());
    }
}

/**
 * Notify auction winner
 */
function notifyAuctionWinner($vehicleId, $winnerId) {
    global $conn;
    
    try {
        // Get auction details
        $sql = "SELECT v.*, 
                COALESCE(v.brand, v.make) as brand, 
                COALESCE(v.model, '') as model,
                COALESCE(v.current_bid, v.current_price) as final_price
                FROM vehicles v 
                WHERE v.vehicle_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $vehicleId);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows === 0) {
            return;
        }
        
        $auction = $result->fetch_assoc();
        $vehicleName = $auction['brand'] . ' ' . $auction['model'];
        $finalPrice = $auction['final_price'];
        
        // Insert notification
        $title = "Selamat! Anda Memenangkan Lelang";
        $message = "Anda memenangkan lelang untuk {$vehicleName} dengan harga Rp" . number_format($finalPrice, 0, ',', '.');
        $url = "vehicle.php?id={$vehicleId}";
        
        insertNotification($winnerId, 'auction', $title, $message, $url);
        
        logMessage("Sent winner notification to user #{$winnerId} for auction #{$vehicleId}");
    } catch (Exception $e) {
        logMessage("Error notifying auction winner: " . $e->getMessage());
    }
}

/**
 * Notify auction seller
 */
function notifyAuctionSeller($vehicleId, $sold) {
    global $conn;
    
    try {
        // Get auction details
        $sql = "SELECT v.*, 
                COALESCE(v.brand, v.make) as brand, 
                COALESCE(v.model, '') as model,
                COALESCE(v.current_bid, v.current_price) as final_price,
                COALESCE(v.seller_id, 0) as seller_id
                FROM vehicles v 
                WHERE v.vehicle_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $vehicleId);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows === 0) {
            return;
        }
        
        $auction = $result->fetch_assoc();
        $vehicleName = $auction['brand'] . ' ' . $auction['model'];
        $finalPrice = $auction['final_price'];
        $sellerId = $auction['seller_id'];
        
        if ($sellerId <= 0) {
            return;
        }
        
        // Insert notification
        if ($sold) {
            $title = "Kendaraan Anda Terjual";
            $message = "Kendaraan {$vehicleName} terjual dengan harga Rp" . number_format($finalPrice, 0, ',', '.');
        } else {
            $title = "Kendaraan Anda Tidak Terjual";
            $message = "Kendaraan {$vehicleName} tidak terjual dalam lelang.";
        }
        
        $url = "vehicle.php?id={$vehicleId}";
        
        insertNotification($sellerId, 'auction', $title, $message, $url);
        
        logMessage("Sent seller notification to user #{$sellerId} for auction #{$vehicleId}");
    } catch (Exception $e) {
        logMessage("Error notifying auction seller: " . $e->getMessage());
    }
}

/**
 * Notify all bidders
 */
function notifyAllBidders($vehicleId) {
    global $conn;
    
    try {
        // Get auction details
        $sql = "SELECT v.*, 
                COALESCE(v.brand, v.make) as brand, 
                COALESCE(v.model, '') as model,
                COALESCE(v.current_bid, v.current_price) as final_price,
                COALESCE(v.current_bidder, 0) as winner_id
                FROM vehicles v 
                WHERE v.vehicle_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $vehicleId);
        $stmt->execute();
        $result = $stmt->get_result();
        
        if ($result->num_rows === 0) {
            return;
        }
        
        $auction = $result->fetch_assoc();
        $vehicleName = $auction['brand'] . ' ' . $auction['model'];
        $finalPrice = $auction['final_price'];
        $winnerId = $auction['winner_id'];
        
        // Get all bidders except winner
        $sql = "SELECT DISTINCT bidder_id FROM bids WHERE vehicle_id = ? AND bidder_id != ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("ii", $vehicleId, $winnerId);
        $stmt->execute();
        $result = $stmt->get_result();
        
        while ($row = $result->fetch_assoc()) {
            $bidderId = $row['bidder_id'];
            
            // Insert notification
            $title = "Lelang Berakhir";
            $message = "Lelang untuk {$vehicleName} telah berakhir.";
            $url = "vehicle.php?id={$vehicleId}";
            
            insertNotification($bidderId, 'auction', $title, $message, $url);
        }
        
        logMessage("Sent end notifications to all bidders for auction #{$vehicleId}");
    } catch (Exception $e) {
        logMessage("Error notifying all bidders: " . $e->getMessage());
    }
}

/**
 * Check for expired transactions
 */
function checkExpiredTransactions() {
    global $conn;
    
    try {
        // Get pending transactions older than 24 hours
        $sql = "SELECT * FROM transactions 
                WHERE status = 'pending' 
                AND created_at <= DATE_SUB(NOW(), INTERVAL 24 HOUR)";
        $result = $conn->query($sql);
        
        if ($result->num_rows > 0) {
            while ($transaction = $result->fetch_assoc()) {
                $transactionId = $transaction['transaction_id'];
                $userId = $transaction['user_id'];
                $amount = $transaction['amount'];
                $type = $transaction['type'];
                
                logMessage("Transaction #{$transactionId} expired - Type: {$type}, Amount: {$amount}");
                
                // Cancel transaction
                $sql = "UPDATE transactions 
                        SET status = 'cancelled', updated_at = NOW() 
                        WHERE transaction_id = ?";
                $stmt = $conn->prepare($sql);
                $stmt->bind_param("i", $transactionId);
                $stmt->execute();
                
                // Notify user
                $title = "Transaksi Dibatalkan";
                $message = "Transaksi #{$transactionId} sebesar Rp" . number_format($amount, 0, ',', '.') . " dibatalkan karena melebihi batas waktu.";
                $url = "transactions-modern.php";
                
                insertNotification($userId, 'transaction', $title, $message, $url);
            }
        }
    } catch (Exception $e) {
        logMessage("Error checking expired transactions: " . $e->getMessage());
    }
}

/**
 * Insert notification
 */
function insertNotification($userId, $type, $title, $message, $url = null) {
    global $conn;
    
    try {
        $sql = "INSERT INTO notifications (user_id, type, title, message, url, is_read, created_at) 
                VALUES (?, ?, ?, ?, ?, 0, NOW())";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("issss", $userId, $type, $title, $message, $url);
        $stmt->execute();
        
        return true;
    } catch (Exception $e) {
        logMessage("Error inserting notification: " . $e->getMessage());
        return false;
    }
}