<?php
/**
 * Upload Payment Proof Page
 * LelangMobil Web App - Versi 2025
 */

// Include initialization file
require_once 'config/init.php';

// Redirect if not logged in
require_login();

$error = '';
$success = '';
$user_id = $_SESSION['user_id'];

// Check if transaction ID is provided
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    header("Location: topup-modern.php");
    exit;
}

$transaction_id = intval($_GET['id']);

// Get transaction details
try {
    $transaction_sql = "SELECT * FROM transactions WHERE transaction_id = ? AND user_id = ? AND type = 'deposit'";
    $transaction_stmt = $conn->prepare($transaction_sql);
    $transaction_stmt->bind_param("ii", $transaction_id, $user_id);
    $transaction_stmt->execute();
    $transaction_result = $transaction_stmt->get_result();
    
    if ($transaction_result->num_rows == 0) {
        header("Location: topup-modern.php");
        exit;
    }
    
    $transaction = $transaction_result->fetch_assoc();
    
    // If transaction is already completed or has payment proof, redirect to topup page
    if ($transaction['status'] == 'completed' || !empty($transaction['payment_proof'])) {
        header("Location: topup-modern.php?success=payment_already_uploaded");
        exit;
    }
} catch (Throwable $e) {
    die("Error fetching transaction data: " . $e->getMessage());
}

// Process payment proof upload
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_FILES['payment_proof'])) {
    $allowed_types = ['image/jpeg', 'image/jpg', 'image/png', 'image/gif'];
    $max_size = 5 * 1024 * 1024; // 5MB
    
    if (!in_array($_FILES['payment_proof']['type'], $allowed_types)) {
        $error = "Jenis file tidak didukung. Gunakan format JPG, JPEG, PNG, atau GIF.";
    } elseif ($_FILES['payment_proof']['size'] > $max_size) {
        $error = "Ukuran file terlalu besar. Maksimal 5MB.";
    } elseif ($_FILES['payment_proof']['error'] != 0) {
        $error = "Terjadi kesalahan saat upload file. Kode error: " . $_FILES['payment_proof']['error'];
    } else {
        // Create upload directory if it doesn't exist
        $upload_dir = 'uploads/payment_proofs/';
        if (!file_exists($upload_dir)) {
            mkdir($upload_dir, 0777, true);
        }
        
        // Generate unique filename
        $file_extension = pathinfo($_FILES['payment_proof']['name'], PATHINFO_EXTENSION);
        $filename = 'payment_' . $transaction_id . '_' . time() . '.' . $file_extension;
        $target_file = $upload_dir . $filename;
        
        if (move_uploaded_file($_FILES['payment_proof']['tmp_name'], $target_file)) {
            // Update transaction with payment proof
            $update_sql = "UPDATE transactions SET payment_proof = ?, status = 'pending', updated_at = NOW() WHERE transaction_id = ?";
            $update_stmt = $conn->prepare($update_sql);
            $update_stmt->bind_param("si", $target_file, $transaction_id);
            
            if ($update_stmt->execute()) {
                $success = "Bukti pembayaran berhasil diunggah. Admin akan memverifikasi pembayaran Anda dalam 1x24 jam.";
                
                // Send notification to admin
                if (function_exists('send_notification')) {
                    $admin_sql = "SELECT user_id FROM users WHERE is_admin = 1 LIMIT 1";
                    $admin_result = $conn->query($admin_sql);
                    if ($admin_result && $admin_result->num_rows > 0) {
                        $admin = $admin_result->fetch_assoc();
                        $title = "Bukti Pembayaran Baru";
                        $message = "Bukti pembayaran baru telah diunggah untuk transaksi #" . $transaction_id . " sebesar " . format_money($transaction['amount']);
                        send_notification($admin['user_id'], 'payment_proof', $title, $message);
                    }
                }
                
                // Redirect after successful upload
                header("Location: topup-modern.php?success=payment_uploaded");
                exit;
            } else {
                $error = "Gagal memperbarui data transaksi: " . $conn->error;
            }
        } else {
            $error = "Gagal mengunggah file. Silakan coba lagi.";
        }
    }
}

// Set page title and flags
$page_title = "Upload Bukti Pembayaran";
$is_dashboard_page = true;
$use_modern_dashboard = true;

// Include header
include("includes/header.php");
?>

<!-- Main Content Container -->
<div class="container-fluid py-5">
    <?php if (!empty($success)): ?>
    <div class="modern-alert modern-alert-success mb-4 fade-in">
        <i class="fa fa-check-circle"></i>
        <div><?php echo $success; ?></div>
    </div>
    <?php endif; ?>
    
    <?php if (!empty($error)): ?>
    <div class="modern-alert modern-alert-danger mb-4 fade-in">
        <i class="fa fa-exclamation-circle"></i>
        <div><?php echo $error; ?></div>
    </div>
    <?php endif; ?>
    
    <div class="row">
        <!-- Sidebar Navigation -->
        <div class="col-lg-3">
            <?php include("includes/account-navbar.php"); ?>
        </div>
        
        <!-- Main Content -->
        <div class="col-lg-9">
            <h2 class="mb-4 fade-in"><?php echo $page_title; ?></h2>
            
            <div class="row">
                <div class="col-lg-8">
                    <!-- Upload Form -->
                    <div class="modern-card fade-in">
                        <div class="modern-card-header">
                            <h3 class="modern-card-title"><i class="fa fa-upload"></i> Upload Bukti Pembayaran</h3>
                        </div>
                        <div class="modern-card-body">
                            <div class="transaction-details mb-4">
                                <h5>Detail Transaksi</h5>
                                <div class="transaction-info">
                                    <div class="info-row">
                                        <div class="info-label">ID Transaksi</div>
                                        <div class="info-value">#<?php echo $transaction['transaction_id']; ?></div>
                                    </div>
                                    <div class="info-row">
                                        <div class="info-label">Jumlah</div>
                                        <div class="info-value">Rp <?php echo number_format($transaction['amount'], 0, ',', '.'); ?></div>
                                    </div>
                                    <div class="info-row">
                                        <div class="info-label">Tanggal</div>
                                        <div class="info-value"><?php echo date('d M Y H:i', strtotime($transaction['created_at'])); ?></div>
                                    </div>
                                    <div class="info-row">
                                        <div class="info-label">Status</div>
                                        <div class="info-value">
                                            <span class="badge bg-warning">Menunggu Pembayaran</span>
                                        </div>
                                    </div>
                                    <?php if (!empty($transaction['reference_number'])): ?>
                                    <div class="info-row">
                                        <div class="info-label">Nomor Referensi</div>
                                        <div class="info-value"><?php echo $transaction['reference_number']; ?></div>
                                    </div>
                                    <?php endif; ?>
                                    <div class="info-row">
                                        <div class="info-label">Metode Pembayaran</div>
                                        <div class="info-value"><?php echo $transaction['payment_method']; ?></div>
                                    </div>
                                </div>
                            </div>
                            
                            <form method="post" action="" enctype="multipart/form-data" id="upload-form">
                                <div class="mb-4">
                                    <label for="payment_proof" class="modern-form-label">Bukti Pembayaran</label>
                                    <div class="upload-area" id="upload-area">
                                        <div class="upload-icon">
                                            <i class="fa fa-cloud-upload-alt"></i>
                                        </div>
                                        <p>Drag & drop file di sini atau klik untuk memilih</p>
                                        <input type="file" name="payment_proof" id="payment_proof" class="file-input" accept="image/*" required>
                                    </div>
                                    <div id="preview-container" class="mt-3 d-none">
                                        <img src="" alt="Preview" id="image-preview" class="img-fluid rounded">
                                        <button type="button" class="btn btn-sm btn-danger mt-2" id="remove-image">
                                            <i class="fa fa-times me-1"></i>Hapus
                                        </button>
                                    </div>
                                    <small class="text-muted">Format yang didukung: JPG, JPEG, PNG, GIF. Ukuran maksimal: 5MB.</small>
                                </div>
                                
                                <div class="payment-instructions alert alert-info mb-4">
                                    <h6><i class="fa fa-info-circle me-2"></i>Petunjuk Pembayaran</h6>
                                    <ol class="mb-0">
                                        <li>Transfer ke rekening berikut:
                                            <ul>
                                                <?php if ($transaction['payment_method'] == 'BCA'): ?>
                                                <li>Bank BCA: 1234567890 a/n LelangMobil</li>
                                                <?php elseif ($transaction['payment_method'] == 'Mandiri'): ?>
                                                <li>Bank Mandiri: 1234567890 a/n LelangMobil</li>
                                                <?php elseif ($transaction['payment_method'] == 'BNI'): ?>
                                                <li>Bank BNI: 1234567890 a/n LelangMobil</li>
                                                <?php elseif ($transaction['payment_method'] == 'BRI'): ?>
                                                <li>Bank BRI: 1234567890 a/n LelangMobil</li>
                                                <?php else: ?>
                                                <li>Bank BCA: 1234567890 a/n LelangMobil</li>
                                                <li>Bank Mandiri: 1234567890 a/n LelangMobil</li>
                                                <li>Bank BNI: 1234567890 a/n LelangMobil</li>
                                                <li>Bank BRI: 1234567890 a/n LelangMobil</li>
                                                <?php endif; ?>
                                            </ul>
                                        </li>
                                        <li>Jumlah transfer: <strong>Rp <?php echo number_format($transaction['amount'], 0, ',', '.'); ?></strong></li>
                                        <li>Sertakan nomor referensi <strong><?php echo $transaction['reference_number']; ?></strong> pada keterangan transfer</li>
                                        <li>Upload bukti pembayaran berupa screenshot atau foto</li>
                                        <li>Pastikan bukti pembayaran jelas dan terbaca</li>
                                    </ol>
                                </div>
                                
                                <div class="d-grid">
                                    <button type="submit" class="modern-button modern-button-primary" id="upload-button">
                                        <i class="fa fa-upload me-2"></i>Upload Bukti Pembayaran
                                    </button>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
                
                <div class="col-lg-4">
                    <!-- Info Card -->
                    <div class="modern-card fade-in">
                        <div class="modern-card-header">
                            <h3 class="modern-card-title"><i class="fa fa-info-circle"></i> Informasi</h3>
                        </div>
                        <div class="modern-card-body">
                            <div class="info-item">
                                <div class="info-icon">
                                    <i class="fa fa-clock"></i>
                                </div>
                                <div class="info-content">
                                    <h5>Waktu Proses</h5>
                                    <p>Top-up akan diproses dalam 1x24 jam setelah bukti pembayaran diunggah.</p>
                                </div>
                            </div>
                            
                            <div class="info-item">
                                <div class="info-icon">
                                    <i class="fa fa-image"></i>
                                </div>
                                <div class="info-content">
                                    <h5>Bukti Pembayaran</h5>
                                    <p>Pastikan bukti pembayaran jelas dan menunjukkan jumlah transfer, tanggal, dan nomor rekening.</p>
                                </div>
                            </div>
                            
                            <div class="info-item">
                                <div class="info-icon">
                                    <i class="fa fa-question-circle"></i>
                                </div>
                                <div class="info-content">
                                    <h5>Butuh Bantuan?</h5>
                                    <p>Hubungi customer service kami di <a href="mailto:support@lelangmobil.com">support@lelangmobil.com</a></p>
                                </div>
                            </div>
                            
                            <div class="alert alert-warning mt-4">
                                <i class="fa fa-exclamation-triangle me-2"></i>
                                <strong>Penting:</strong> Setelah bukti pembayaran diunggah, admin akan memverifikasi pembayaran Anda. Saldo akan ditambahkan ke akun Anda setelah pembayaran diverifikasi.
                            </div>
                        </div>
                    </div>
                    
                    <!-- Actions -->
                    <div class="modern-card mt-4 fade-in">
                        <div class="modern-card-body">
                            <a href="topup-modern.php" class="modern-button modern-button-outline w-100">
                                <i class="fa fa-arrow-left me-2"></i>Kembali ke Top-up
                            </a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    const uploadArea = document.getElementById('upload-area');
    const fileInput = document.getElementById('payment_proof');
    const previewContainer = document.getElementById('preview-container');
    const imagePreview = document.getElementById('image-preview');
    const removeImageBtn = document.getElementById('remove-image');
    const uploadForm = document.getElementById('upload-form');
    const uploadButton = document.getElementById('upload-button');
    
    // Handle drag and drop
    ['dragenter', 'dragover', 'dragleave', 'drop'].forEach(eventName => {
        uploadArea.addEventListener(eventName, preventDefaults, false);
    });
    
    function preventDefaults(e) {
        e.preventDefault();
        e.stopPropagation();
    }
    
    ['dragenter', 'dragover'].forEach(eventName => {
        uploadArea.addEventListener(eventName, highlight, false);
    });
    
    ['dragleave', 'drop'].forEach(eventName => {
        uploadArea.addEventListener(eventName, unhighlight, false);
    });
    
    function highlight() {
        uploadArea.classList.add('dragover');
    }
    
    function unhighlight() {
        uploadArea.classList.remove('dragover');
    }
    
    // Handle file drop
    uploadArea.addEventListener('drop', handleDrop, false);
    
    function handleDrop(e) {
        const dt = e.dataTransfer;
        const files = dt.files;
        
        if (files.length > 0) {
            fileInput.files = files;
            handleFiles(files);
        }
    }
    
    // Handle file selection
    fileInput.addEventListener('change', function() {
        if (this.files.length > 0) {
            handleFiles(this.files);
        }
    });
    
    function handleFiles(files) {
        const file = files[0];
        
        // Check file type
        const validTypes = ['image/jpeg', 'image/jpg', 'image/png', 'image/gif'];
        if (!validTypes.includes(file.type)) {
            alert('Jenis file tidak didukung. Gunakan format JPG, JPEG, PNG, atau GIF.');
            resetFileInput();
            return;
        }
        
        // Check file size (max 5MB)
        if (file.size > 5 * 1024 * 1024) {
            alert('Ukuran file terlalu besar. Maksimal 5MB.');
            resetFileInput();
            return;
        }
        
        // Show preview
        const reader = new FileReader();
        reader.onload = function(e) {
            imagePreview.src = e.target.result;
            previewContainer.classList.remove('d-none');
            uploadArea.classList.add('d-none');
        };
        reader.readAsDataURL(file);
    }
    
    // Remove image preview
    if (removeImageBtn) {
        removeImageBtn.addEventListener('click', function() {
            resetFileInput();
        });
    }
    
    function resetFileInput() {
        fileInput.value = '';
        previewContainer.classList.add('d-none');
        uploadArea.classList.remove('d-none');
    }
    
    // Form validation
    if (uploadForm) {
        uploadForm.addEventListener('submit', function(e) {
            if (!fileInput.files || fileInput.files.length === 0) {
                e.preventDefault();
                alert('Silakan pilih file bukti pembayaran.');
                return false;
            }
            
            // Disable button to prevent double submission
            uploadButton.disabled = true;
            uploadButton.innerHTML = '<i class="fa fa-spinner fa-spin me-2"></i>Mengunggah...';
            
            return true;
        });
    }
});
</script>

<?php include("includes/footer.php"); ?>