<?php
/**
 * Vehicle Detail Page
 * LelangMobil Web App - Versi 2025
 */

// Include initialization file
require_once 'config/init.php';

// Check if vehicle ID is provided
if (!isset($_GET['id']) || empty($_GET['id'])) {
    header("Location: auctions.php");
    exit;
}

$vehicle_id = (int)$_GET['id'];

// Get vehicle details
try {
    $vehicle_sql = "SELECT 
                    v.*,
                    COALESCE(v.brand, v.make) as brand_name,
                    COALESCE(v.image_main, v.image, 'images/no-image.svg') as main_image,
                    COALESCE(v.starting_price, v.start_price, 0) as auction_start_price, 
                    COALESCE(v.current_bid, v.current_price, 0) as auction_current_bid, 
                    COALESCE(v.end_date, v.auction_end) as auction_end_date,
                    u.username as seller_username,
                    u.full_name as seller_name
                    FROM vehicles v
                    LEFT JOIN users u ON v.seller_id = u.user_id
                    WHERE v.vehicle_id = ?";
    $vehicle_stmt = $conn->prepare($vehicle_sql);
    $vehicle_stmt->bind_param("i", $vehicle_id);
    $vehicle_stmt->execute();
    $vehicle_result = $vehicle_stmt->get_result();
    
    if ($vehicle_result->num_rows == 0) {
        header("Location: auctions.php");
        exit;
    }
    
    $vehicle = $vehicle_result->fetch_assoc();
} catch (Throwable $e) {
    error_log("Error fetching vehicle: " . $e->getMessage());
    header("Location: auctions.php");
    exit;
}

// Get vehicle images
try {
    $images_sql = "SELECT * FROM vehicle_images WHERE vehicle_id = ? ORDER BY is_main DESC";
    $images_stmt = $conn->prepare($images_sql);
    $images_stmt->bind_param("i", $vehicle_id);
    $images_stmt->execute();
    $images_result = $images_stmt->get_result();
} catch (Throwable $e) {
    error_log("Error fetching vehicle images: " . $e->getMessage());
    $images_result = false;
}

// Get bids for this vehicle
try {
    $bids_sql = "SELECT b.*, u.username, u.full_name
                FROM bids b
                LEFT JOIN users u ON b.bidder_id = u.user_id
                WHERE b.vehicle_id = ?
                ORDER BY b.bid_amount DESC
                LIMIT 10";
    $bids_stmt = $conn->prepare($bids_sql);
    $bids_stmt->bind_param("i", $vehicle_id);
    $bids_stmt->execute();
    $bids_result = $bids_stmt->get_result();
} catch (Throwable $e) {
    error_log("Error fetching bids: " . $e->getMessage());
    $bids_result = false;
}

// Process bid submission
$bid_error = '';
$bid_success = '';

if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['submit_bid'])) {
    // Check if user is logged in
    if (!is_logged_in()) {
        $bid_error = "Anda harus login untuk mengajukan bid.";
    } else {
        $user_id = $_SESSION['user_id'];
        $bid_amount = (float)$_POST['bid_amount'];
        $min_bid = max($vehicle['auction_current_bid'], $vehicle['auction_start_price']);
        
        // Validate bid amount
        if ($bid_amount <= $min_bid) {
            $bid_error = "Bid harus lebih tinggi dari bid saat ini.";
        } else {
            // Check user balance
            $balance_sql = "SELECT balance FROM users WHERE user_id = ?";
            $balance_stmt = $conn->prepare($balance_sql);
            $balance_stmt->bind_param("i", $user_id);
            $balance_stmt->execute();
            $balance_result = $balance_stmt->get_result();
            $user_balance = $balance_result->fetch_assoc()['balance'];
            
            if ($user_balance < $bid_amount) {
                $bid_error = "Saldo Anda tidak mencukupi untuk mengajukan bid ini.";
            } else {
                // Insert bid
                $conn->begin_transaction();
                
                try {
                    // Insert bid record
                    $bid_sql = "INSERT INTO bids (vehicle_id, bidder_id, bid_amount, bid_time) VALUES (?, ?, ?, NOW())";
                    $bid_stmt = $conn->prepare($bid_sql);
                    $bid_stmt->bind_param("iid", $vehicle_id, $user_id, $bid_amount);
                    $bid_stmt->execute();
                    
                    // Update vehicle current bid
                    $update_sql = "UPDATE vehicles SET current_bid = ?, current_price = ? WHERE vehicle_id = ?";
                    $update_stmt = $conn->prepare($update_sql);
                    $update_stmt->bind_param("ddi", $bid_amount, $bid_amount, $vehicle_id);
                    $update_stmt->execute();
                    
                    // Create transaction record for bid hold
                    $transaction_sql = "INSERT INTO transactions (user_id, amount, type, status, notes, created_at) 
                                      VALUES (?, ?, 'bid_hold', 'pending', ?, NOW())";
                    $notes = "Bid hold for vehicle ID: " . $vehicle_id;
                    $transaction_stmt = $conn->prepare($transaction_sql);
                    $transaction_stmt->bind_param("ids", $user_id, $bid_amount, $notes);
                    $transaction_stmt->execute();
                    
                    $conn->commit();
                    $bid_success = "Bid berhasil diajukan!";
                    
                    // Refresh page to show updated bid
                    header("Location: vehicle.php?id=" . $vehicle_id . "&bid_success=1");
                    exit;
                } catch (Throwable $e) {
                    $conn->rollback();
                    error_log("Error submitting bid: " . $e->getMessage());
                    $bid_error = "Terjadi kesalahan saat mengajukan bid. Silakan coba lagi.";
                }
            }
        }
    }
}

// Check for bid success message
if (isset($_GET['bid_success']) && $_GET['bid_success'] == 1) {
    $bid_success = "Bid berhasil diajukan!";
}

// Set page title
$page_title = $vehicle['brand_name'] . " " . $vehicle['model'] . " - LelangMobil";

// Include header
include("includes/header.php");
?>

<!-- Subheader -->
<section id="subheader" class="text-light">
    <div class="center-y relative text-center">
        <div class="container">
            <div class="row">
                <div class="col-md-12 text-center">
                    <h1><?php echo htmlspecialchars($vehicle['brand_name'] . " " . $vehicle['model']); ?></h1>
                </div>
                <div class="clearfix"></div>
            </div>
        </div>
    </div>
</section>

<!-- Vehicle Detail Section -->
<section id="section-vehicle-detail" class="pt60 pb60">
    <div class="container">
        <?php if (!empty($bid_error)): ?>
        <div class="alert alert-danger">
            <i class="fa fa-exclamation-circle"></i> <?php echo $bid_error; ?>
        </div>
        <?php endif; ?>
        
        <?php if (!empty($bid_success)): ?>
        <div class="alert alert-success">
            <i class="fa fa-check-circle"></i> <?php echo $bid_success; ?>
        </div>
        <?php endif; ?>
        
        <div class="row">
            <!-- Vehicle Images -->
            <div class="col-md-6">
                <div class="vehicle-image-main mb-3">
                    <img src="images/placeholder.svg" 
                         data-src="<?php echo htmlspecialchars($vehicle['main_image']); ?>" 
                         class="img-fluid" 
                         alt="<?php echo htmlspecialchars($vehicle['brand_name'] . " " . $vehicle['model']); ?>" 
                         onerror="this.src='images/no-image.svg';">
                </div>
                
                <?php if ($images_result && $images_result->num_rows > 0): ?>
                <div class="vehicle-image-thumbs">
                    <div class="row">
                        <?php while ($image = $images_result->fetch_assoc()): ?>
                        <div class="col-3 mb-3">
                            <img src="images/placeholder.svg" 
                                 data-src="<?php echo htmlspecialchars($image['image_url']); ?>" 
                                 class="img-fluid thumbnail" 
                                 alt="" 
                                 onerror="this.src='images/no-image.svg';"
                                 loading="lazy">
                        </div>
                        <?php endwhile; ?>
                    </div>
                </div>
                <?php endif; ?>
            </div>
            
            <!-- Vehicle Info -->
            <div class="col-md-6">
                <div class="vehicle-info">
                    <h2><?php echo htmlspecialchars($vehicle['brand_name'] . " " . $vehicle['model']); ?></h2>
                    <p class="vehicle-year">Tahun <?php echo htmlspecialchars($vehicle['year']); ?></p>
                    
                    <div class="vehicle-bid-info">
                        <div class="row">
                            <div class="col-6">
                                <div class="bid-label">Bid Saat Ini</div>
                                <div class="bid-amount">Rp<?php echo number_format(max($vehicle['auction_current_bid'], $vehicle['auction_start_price']), 0, ',', '.'); ?></div>
                            </div>
                            <div class="col-6">
                                <div class="bid-label">Sisa Waktu</div>
                                <?php
                                $now = new DateTime();
                                $end_date = new DateTime($vehicle['auction_end_date']);
                                $interval = $now->diff($end_date);
                                
                                $time_label = "";
                                if ($interval->days > 0) {
                                    $time_label = $interval->days . " hari " . $interval->h . " jam";
                                } else if ($interval->h > 0) {
                                    $time_label = $interval->h . " jam " . $interval->i . " menit";
                                } else {
                                    $time_label = $interval->i . " menit";
                                }
                                ?>
                                <div class="time-remaining"><?php echo $time_label; ?></div>
                            </div>
                        </div>
                    </div>
                    
                    <div class="vehicle-description mt-4">
                        <h4>Deskripsi</h4>
                        <p><?php echo nl2br(htmlspecialchars($vehicle['description'] ?? 'Tidak ada deskripsi')); ?></p>
                    </div>
                    
                    <div class="vehicle-specs mt-4">
                        <h4>Spesifikasi</h4>
                        <div class="row">
                            <div class="col-6">
                                <div class="spec-item">
                                    <div class="spec-label">Merek</div>
                                    <div class="spec-value"><?php echo htmlspecialchars($vehicle['brand_name']); ?></div>
                                </div>
                            </div>
                            <div class="col-6">
                                <div class="spec-item">
                                    <div class="spec-label">Model</div>
                                    <div class="spec-value"><?php echo htmlspecialchars($vehicle['model']); ?></div>
                                </div>
                            </div>
                            <div class="col-6">
                                <div class="spec-item">
                                    <div class="spec-label">Tahun</div>
                                    <div class="spec-value"><?php echo htmlspecialchars($vehicle['year']); ?></div>
                                </div>
                            </div>
                            <div class="col-6">
                                <div class="spec-item">
                                    <div class="spec-label">Kilometer</div>
                                    <div class="spec-value"><?php echo number_format($vehicle['mileage'] ?? 0, 0, ',', '.'); ?> km</div>
                                </div>
                            </div>
                        </div>
                    </div>
                    
                    <?php if ($vehicle['status'] == 'active'): ?>
                    <div class="bid-form mt-4">
                        <h4>Ajukan Bid</h4>
                        <form method="post" action="" id="bidForm">
                            <div class="input-group mb-3">
                                <div class="input-group-prepend">
                                    <span class="input-group-text">Rp</span>
                                </div>
                                <input type="number" class="form-control" name="bid_amount" id="bidAmount" placeholder="Masukkan jumlah bid" min="<?php echo max($vehicle['auction_current_bid'], $vehicle['auction_start_price']) + 1; ?>" required>
                                <div class="input-group-append">
                                    <button class="btn btn-primary" type="submit" name="submit_bid">Ajukan Bid</button>
                                </div>
                            </div>
                            <small class="form-text text-muted">Bid minimum: Rp<?php echo number_format(max($vehicle['auction_current_bid'], $vehicle['auction_start_price']) + 1, 0, ',', '.'); ?></small>
                        </form>

                        <!-- Auto-bid Form -->
                        <div class="auto-bid-section mt-4">
                            <h4>Auto Bid</h4>
                            <form method="post" action="" id="autoBidForm">
                                <div class="form-group">
                                    <label for="maxAmount">Jumlah Maksimum Auto-Bid</label>
                                    <div class="input-group">
                                        <div class="input-group-prepend">
                                            <span class="input-group-text">Rp</span>
                                        </div>
                                        <input type="number" class="form-control" name="max_amount" id="maxAmount" placeholder="Jumlah maksimum auto-bid" required>
                                    </div>
                                </div>
                                <div class="form-group">
                                    <label for="bidIncrement">Kenaikan per Bid</label>
                                    <div class="input-group">
                                        <div class="input-group-prepend">
                                            <span class="input-group-text">Rp</span>
                                        </div>
                                        <input type="number" class="form-control" name="bid_increment" id="bidIncrement" placeholder="Kenaikan per bid" required>
                                    </div>
                                </div>
                                <button type="submit" class="btn btn-success" name="submit_auto_bid">
                                    <i class="fa fa-robot"></i> Aktifkan Auto-Bid
                                </button>
                            </form>
                        </div>

                        <!-- Favorite Button -->
                        <div class="mt-3">
                            <button class="btn btn-outline-danger" id="favoriteBtn" data-vehicle-id="<?php echo $vehicle_id; ?>">
                                <i class="fa fa-heart"></i> Tambah ke Favorit
                            </button>
                        </div>
                    </div>
                    <?php else: ?>
                    <div class="alert alert-info mt-4">
                        <i class="fa fa-info-circle"></i> Lelang ini sudah berakhir.
                    </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
        
        <!-- Bid History -->
        <div class="row mt-5">
            <div class="col-12">
                <h3>Riwayat Bid</h3>
                <div class="table-responsive">
                    <table class="table table-striped" id="bidHistory">
                        <thead>
                            <tr>
                                <th>Bidder</th>
                                <th>Jumlah Bid</th>
                                <th>Waktu</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php
                            if ($bids_result && $bids_result->num_rows > 0) {
                                while ($bid = $bids_result->fetch_assoc()) {
                                    echo '<tr>';
                                    echo '<td>' . htmlspecialchars($bid['full_name'] ?: $bid['username']) . '</td>';
                                    echo '<td>Rp' . number_format($bid['bid_amount'], 0, ',', '.') . '</td>';
                                    echo '<td>' . date('d M Y H:i', strtotime($bid['bid_time'])) . '</td>';
                                    echo '</tr>';
                                }
                            } else {
                                echo '<tr><td colspan="3" class="text-center">Belum ada bid untuk kendaraan ini.</td></tr>';
                            }
                            ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>

        <!-- Comments Section -->
        <div class="row mt-5">
            <div class="col-12">
                <div class="card">
                    <div class="card-header">
                        <h3 class="mb-0">Komentar</h3>
                    </div>
                    <div class="card-body">
                        <?php if (is_logged_in()): ?>
                        <form id="commentForm" class="mb-4">
                            <div class="form-group">
                                <textarea class="form-control" name="comment" rows="3" placeholder="Tulis komentar Anda..." required></textarea>
                            </div>
                            <button type="submit" class="btn btn-primary">
                                <i class="fa fa-comment"></i> Kirim Komentar
                            </button>
                        </form>
                        <?php else: ?>
                        <div class="alert alert-info">
                            <i class="fa fa-info-circle"></i> Silakan <a href="login.php">login</a> untuk menambahkan komentar.
                        </div>
                        <?php endif; ?>

                        <div id="commentsList">
                            <?php
                            // Get comments
                            $comments_sql = "SELECT c.*, u.username, u.full_name 
                                          FROM vehicle_comments c 
                                          JOIN users u ON c.user_id = u.user_id 
                                          WHERE c.vehicle_id = ? AND c.status = 'approved'
                                          ORDER BY c.created_at DESC";
                            $comments_stmt = $conn->prepare($comments_sql);
                            $comments_stmt->bind_param("i", $vehicle_id);
                            $comments_stmt->execute();
                            $comments_result = $comments_stmt->get_result();

                            while ($comment = $comments_result->fetch_assoc()):
                            ?>
                            <div class="comment mb-3">
                                <div class="d-flex">
                                    <div class="comment-avatar">
                                        <i class="fa fa-user-circle fa-2x"></i>
                                    </div>
                                    <div class="comment-content ms-3">
                                        <div class="comment-header">
                                            <strong><?php echo htmlspecialchars($comment['full_name'] ?: $comment['username']); ?></strong>
                                            <small class="text-muted ms-2">
                                                <?php echo date('d M Y H:i', strtotime($comment['created_at'])); ?>
                                            </small>
                                        </div>
                                        <div class="comment-text">
                                            <?php echo nl2br(htmlspecialchars($comment['comment'])); ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <?php endwhile; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <!-- Seller Rating Section -->
        <?php if ($vehicle['seller_id'] && is_logged_in() && $_SESSION['user_id'] != $vehicle['seller_id']): ?>
        <div class="row mt-5">
            <div class="col-12">
                <div class="card">
                    <div class="card-header">
                        <h3 class="mb-0">Beri Rating Penjual</h3>
                    </div>
                    <div class="card-body">
                        <form id="ratingForm">
                            <div class="rating-stars mb-3">
                                <?php for ($i = 5; $i >= 1; $i--): ?>
                                <input type="radio" name="rating" value="<?php echo $i; ?>" id="star<?php echo $i; ?>">
                                <label for="star<?php echo $i; ?>"><i class="fa fa-star"></i></label>
                                <?php endfor; ?>
                            </div>
                            <div class="form-group">
                                <textarea class="form-control" name="rating_comment" rows="3" placeholder="Berikan komentar tentang penjual (opsional)"></textarea>
                            </div>
                            <button type="submit" class="btn btn-primary">
                                <i class="fa fa-star"></i> Kirim Rating
                            </button>
                        </form>
                    </div>
                </div>
            </div>
        </div>
        <?php endif; ?>
    </div>
</section>

<style>
.vehicle-image-main {
    border-radius: 10px;
    overflow: hidden;
    box-shadow: 0 5px 15px rgba(0, 0, 0, 0.1);
}

.vehicle-image-thumbs .thumbnail {
    border-radius: 5px;
    cursor: pointer;
    transition: all 0.3s ease;
}

.vehicle-image-thumbs .thumbnail:hover {
    transform: scale(1.05);
}

.vehicle-bid-info {
    background: #f8f9fa;
    border-radius: 10px;
    padding: 20px;
    margin-top: 20px;
}

.bid-label {
    font-size: 14px;
    color: #6c757d;
}

.bid-amount, .time-remaining {
    font-size: 24px;
    font-weight: 700;
    color: #4a6ee0;
}

.vehicle-year {
    color: #6c757d;
    font-size: 18px;
    margin-bottom: 20px;
}

.spec-item {
    margin-bottom: 15px;
}

.spec-label {
    font-size: 14px;
    color: #6c757d;
}

.spec-value {
    font-size: 16px;
    font-weight: 600;
}

/* Rating Stars */
.rating-stars {
    display: flex;
    flex-direction: row-reverse;
    justify-content: flex-end;
}

.rating-stars input {
    display: none;
}

.rating-stars label {
    cursor: pointer;
    font-size: 24px;
    color: #ddd;
    margin: 0 2px;
}

.rating-stars label:hover,
.rating-stars label:hover ~ label,
.rating-stars input:checked ~ label {
    color: #ffd700;
}

/* Comments */
.comment {
    border-bottom: 1px solid #eee;
    padding-bottom: 1rem;
}

.comment:last-child {
    border-bottom: none;
}

.comment-avatar {
    color: #6c757d;
}

.comment-header {
    margin-bottom: 0.5rem;
}

.comment-text {
    color: #333;
    line-height: 1.5;
}

/* Notifications */
.modern-alert {
    position: fixed;
    top: 20px;
    right: 20px;
    padding: 15px 20px;
    border-radius: 8px;
    background: white;
    box-shadow: 0 4px 12px rgba(0, 0, 0, 0.15);
    display: flex;
    align-items: center;
    gap: 12px;
    z-index: 1000;
    max-width: 400px;
    animation: slideIn 0.3s ease-out;
}

.modern-alert-info {
    border-left: 4px solid #4a6ee0;
}

.modern-alert-success {
    border-left: 4px solid #28a745;
}

.modern-alert-error {
    border-left: 4px solid #dc3545;
}

@keyframes slideIn {
    from {
        transform: translateX(100%);
        opacity: 0;
    }
    to {
        transform: translateX(0);
        opacity: 1;
    }
}

.fade-in {
    animation: fadeIn 0.3s ease-out;
}

@keyframes fadeIn {
    from {
        opacity: 0;
    }
    to {
        opacity: 1;
    }
}
</style>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Image gallery functionality
    const thumbnails = document.querySelectorAll('.thumbnail');
    const mainImage = document.querySelector('.vehicle-image-main img');
    
    thumbnails.forEach(thumbnail => {
        thumbnail.addEventListener('click', function() {
            mainImage.src = this.src;
        });
    });

    // WebSocket Connection
    const ws = new WebSocket('ws://localhost:8080');
    const vehicleId = <?php echo $vehicle_id; ?>;
    
    ws.onopen = function() {
        // Authenticate WebSocket connection
        ws.send(JSON.stringify({
            type: 'auth',
            token: '<?php echo $_SESSION['websocket_token'] ?? ''; ?>'
        }));
        
        // Subscribe to vehicle updates
        ws.send(JSON.stringify({
            type: 'subscribe',
            vehicle_id: vehicleId
        }));
    };
    
    ws.onmessage = function(event) {
        const data = JSON.parse(event.data);
        
        if (data.type === 'bid_update' && data.vehicle_id === vehicleId) {
            // Update current bid display
            document.querySelector('.bid-amount').textContent = 'Rp' + 
                new Intl.NumberFormat('id-ID').format(data.amount);
            
            // Add new bid to history table
            const bidTable = document.querySelector('#bidHistory tbody');
            const newRow = document.createElement('tr');
            newRow.innerHTML = `
                <td>${data.bidder_name}</td>
                <td>Rp${new Intl.NumberFormat('id-ID').format(data.amount)}</td>
                <td>${new Date().toLocaleString('id-ID')}</td>
            `;
            bidTable.insertBefore(newRow, bidTable.firstChild);
            
            // Show notification
            showNotification('Bid Baru', `${data.bidder_name} mengajukan bid Rp${new Intl.NumberFormat('id-ID').format(data.amount)}`);
        }
    };
    
    // Auto-bid form handling
    const autoBidForm = document.getElementById('autoBidForm');
    if (autoBidForm) {
        autoBidForm.addEventListener('submit', function(e) {
            e.preventDefault();
            
            const formData = new FormData(this);
            fetch('api/auto-bid.php', {
                method: 'POST',
                body: formData
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    showNotification('Auto-Bid', 'Auto-bid berhasil diaktifkan');
                } else {
                    showNotification('Error', data.message, 'error');
                }
            });
        });
    }
    
    // Favorite button handling
    const favoriteBtn = document.getElementById('favoriteBtn');
    if (favoriteBtn) {
        favoriteBtn.addEventListener('click', function() {
            const vehicleId = this.dataset.vehicleId;
            fetch('api/favorite.php', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({ vehicle_id: vehicleId })
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    this.classList.toggle('active');
                    this.innerHTML = data.is_favorite ? 
                        '<i class="fa fa-heart"></i> Hapus dari Favorit' :
                        '<i class="fa fa-heart"></i> Tambah ke Favorit';
                }
            });
        });
    }
});

// Notification function
function showNotification(title, message, type = 'info') {
    const notification = document.createElement('div');
    notification.className = `modern-alert modern-alert-${type} fade-in`;
    notification.innerHTML = `
        <i class="fa fa-${type === 'error' ? 'exclamation' : 'info'}-circle"></i>
        <div>
            <strong>${title}</strong><br>
            ${message}
        </div>
    `;
    
    document.body.appendChild(notification);
    
    setTimeout(() => {
        notification.remove();
    }, 5000);
}
</script>

<?php include("includes/footer.php"); ?>