/**
 * Service Worker
 * LelangMobil Web App - Versi 2025
 */

const CACHE_NAME = 'lelangmobil-v1';
const ASSETS_TO_CACHE = [
  '/',
  '/index.php',
  '/css/modern-main.css',
  '/css/modern-fixes.css',
  '/css/notification-styles.css',
  '/js/modern-theme-activator.js',
  '/js/form-validator.js',
  '/js/responsive-handler.js',
  '/js/image-lazy-loader.js',
  '/js/theme-switcher.js',
  '/js/notification-system.js',
  '/js/websocket-handler.js',
  '/assets/notification-sound.mp3',
  '/images/logo.png',
  '/images/logo-mobile.png',
  '/images/no-image.svg',
  '/offline.html'
];

// Install event - cache assets
self.addEventListener('install', event => {
  event.waitUntil(
    caches.open(CACHE_NAME)
      .then(cache => {
        console.log('Caching app assets');
        return cache.addAll(ASSETS_TO_CACHE);
      })
  );
});

// Activate event - clean up old caches
self.addEventListener('activate', event => {
  event.waitUntil(
    caches.keys().then(cacheNames => {
      return Promise.all(
        cacheNames.map(cacheName => {
          if (cacheName !== CACHE_NAME) {
            console.log('Deleting old cache:', cacheName);
            return caches.delete(cacheName);
          }
        })
      );
    })
  );
});

// Fetch event - serve from cache, fall back to network, then offline page
self.addEventListener('fetch', event => {
  // Skip for API and WebSocket requests
  if (event.request.url.includes('/api/') || 
      event.request.url.startsWith('ws://') || 
      event.request.url.startsWith('wss://')) {
    return;
  }
  
  event.respondWith(
    caches.match(event.request)
      .then(response => {
        // Return cached response if found
        if (response) {
          return response;
        }
        
        // Clone the request
        const fetchRequest = event.request.clone();
        
        // Make network request
        return fetch(fetchRequest)
          .then(response => {
            // Check if valid response
            if (!response || response.status !== 200 || response.type !== 'basic') {
              return response;
            }
            
            // Clone the response
            const responseToCache = response.clone();
            
            // Cache the response
            caches.open(CACHE_NAME)
              .then(cache => {
                cache.put(event.request, responseToCache);
              });
            
            return response;
          })
          .catch(error => {
            // If the request is for a page (HTML), show offline page
            if (event.request.headers.get('Accept').includes('text/html')) {
              return caches.match('/offline.html');
            }
            
            // Otherwise, just propagate the error
            throw error;
          });
      })
  );
});

// Push event - handle push notifications
self.addEventListener('push', event => {
  const data = event.data.json();
  
  const options = {
    body: data.message,
    icon: '/images/logo-mobile.png',
    badge: '/images/logo-mobile.png',
    vibrate: [100, 50, 100],
    data: {
      url: data.url || '/'
    }
  };
  
  event.waitUntil(
    self.registration.showNotification(data.title, options)
  );
});

// Notification click event - open URL
self.addEventListener('notificationclick', event => {
  event.notification.close();
  
  event.waitUntil(
    clients.openWindow(event.notification.data.url)
  );
});