<?php
/**
 * Modern Transactions Page
 * LelangMobil Web App - Versi 2025
 */

// Include initialization file
require_once 'config/init.php';

// Redirect if not logged in
require_login();

$error = '';
$success = '';
$user_id = $_SESSION['user_id'];

// Get user information
try {
    $user_sql = "SELECT * FROM users WHERE user_id = ?";
    $user_stmt = $conn->prepare($user_sql);
    $user_stmt->bind_param("i", $user_id);
    $user_stmt->execute();
    $user_result = $user_stmt->get_result();
    $user = $user_result->fetch_assoc();
} catch (Throwable $e) {
    die("Error fetching user data: " . $e->getMessage());
}

// Handle filter parameters
$filter_type = isset($_GET['type']) ? clean_input($_GET['type']) : '';
$filter_status = isset($_GET['status']) ? clean_input($_GET['status']) : '';
$filter_period = isset($_GET['period']) ? clean_input($_GET['period']) : '';

// Build WHERE clause based on filters
$where_clause = "user_id = ?";
$params = [$user_id];
$param_types = "i";

if (!empty($filter_type)) {
    $where_clause .= " AND type = ?";
    $params[] = $filter_type;
    $param_types .= "s";
}

if (!empty($filter_status)) {
    $where_clause .= " AND status = ?";
    $params[] = $filter_status;
    $param_types .= "s";
}

if (!empty($filter_period)) {
    switch ($filter_period) {
        case 'today':
            $where_clause .= " AND DATE(created_at) = CURDATE()";
            break;
        case 'week':
            $where_clause .= " AND YEARWEEK(created_at, 1) = YEARWEEK(CURDATE(), 1)";
            break;
        case 'month':
            $where_clause .= " AND YEAR(created_at) = YEAR(CURDATE()) AND MONTH(created_at) = MONTH(CURDATE())";
            break;
        case 'year':
            $where_clause .= " AND YEAR(created_at) = YEAR(CURDATE())";
            break;
    }
}

// Pagination
$items_per_page = 10;
$current_page = isset($_GET['page']) ? intval($_GET['page']) : 1;
$offset = ($current_page - 1) * $items_per_page;

// Get total transactions count
try {
    $count_sql = "SELECT COUNT(*) as total FROM transactions WHERE $where_clause";
    $count_stmt = $conn->prepare($count_sql);
    $count_stmt->bind_param($param_types, ...$params);
    $count_stmt->execute();
    $count_result = $count_stmt->get_result();
    $total_items = $count_result->fetch_assoc()['total'];
    $total_pages = ceil($total_items / $items_per_page);
} catch (Throwable $e) {
    error_log("Error counting transactions: " . $e->getMessage());
    $total_items = 0;
    $total_pages = 1;
}

// Get transactions
try {
    $transactions_sql = "SELECT * FROM transactions 
                        WHERE $where_clause 
                        ORDER BY created_at DESC 
                        LIMIT ?, ?";
    $transactions_stmt = $conn->prepare($transactions_sql);
    $transactions_stmt->bind_param($param_types . "ii", ...[...$params, $offset, $items_per_page]);
    $transactions_stmt->execute();
    $transactions_result = $transactions_stmt->get_result();
} catch (Throwable $e) {
    error_log("Error fetching transactions: " . $e->getMessage());
}

// Get transaction statistics
try {
    $stats_sql = "SELECT 
                    COUNT(*) as total_count,
                    SUM(CASE WHEN type = 'deposit' AND status = 'completed' THEN amount ELSE 0 END) as total_deposit,
                    SUM(CASE WHEN type = 'withdrawal' AND status = 'completed' THEN amount ELSE 0 END) as total_withdrawal,
                    COUNT(CASE WHEN status = 'pending' THEN 1 END) as pending_count
                FROM transactions 
                WHERE user_id = ?";
    $stats_stmt = $conn->prepare($stats_sql);
    $stats_stmt->bind_param("i", $user_id);
    $stats_stmt->execute();
    $stats_result = $stats_stmt->get_result();
    $stats = $stats_result->fetch_assoc();
} catch (Throwable $e) {
    error_log("Error fetching transaction stats: " . $e->getMessage());
    $stats = [
        'total_count' => 0,
        'total_deposit' => 0,
        'total_withdrawal' => 0,
        'pending_count' => 0
    ];
}

// Set page title and flags
$page_title = "Riwayat Transaksi";
$is_dashboard_page = true;
$use_ultra_modern = true;

// Include header
include("includes/header.php");
?>

<!-- Main Content Container -->
<div class="container-fluid py-5">
    <?php if (!empty($success)): ?>
    <div class="modern-alert modern-alert-success mb-4 fade-in">
        <i class="fa fa-check-circle"></i>
        <div><?php echo $success; ?></div>
    </div>
    <?php endif; ?>
    
    <?php if (!empty($error)): ?>
    <div class="modern-alert modern-alert-danger mb-4 fade-in">
        <i class="fa fa-exclamation-circle"></i>
        <div><?php echo $error; ?></div>
    </div>
    <?php endif; ?>
    
    <div class="row">
        <!-- Sidebar Navigation -->
        <div class="col-lg-3">
            <?php include("includes/account-navbar.php"); ?>
        </div>
        
        <!-- Main Content -->
        <div class="col-lg-9">
            <h2 class="mb-4 fade-in"><?php echo $page_title; ?></h2>
            
            <!-- Transaction Statistics -->
            <div class="row mb-4">
                <div class="col-md-3 mb-3">
                    <div class="modern-card fade-in">
                        <div class="modern-card-body text-center py-4">
                            <div class="stat-icon mb-3">
                                <i class="fa fa-exchange-alt"></i>
                            </div>
                            <h3 class="stat-value"><?php echo number_format($stats['total_count']); ?></h3>
                            <p class="stat-label">Total Transaksi</p>
                        </div>
                    </div>
                </div>
                <div class="col-md-3 mb-3">
                    <div class="modern-card fade-in">
                        <div class="modern-card-body text-center py-4">
                            <div class="stat-icon mb-3 deposit-icon">
                                <i class="fa fa-arrow-down"></i>
                            </div>
                            <h3 class="stat-value"><?php echo format_money($stats['total_deposit']); ?></h3>
                            <p class="stat-label">Total Top-up</p>
                        </div>
                    </div>
                </div>
                <div class="col-md-3 mb-3">
                    <div class="modern-card fade-in">
                        <div class="modern-card-body text-center py-4">
                            <div class="stat-icon mb-3 withdraw-icon">
                                <i class="fa fa-arrow-up"></i>
                            </div>
                            <h3 class="stat-value"><?php echo format_money($stats['total_withdrawal']); ?></h3>
                            <p class="stat-label">Total Penarikan</p>
                        </div>
                    </div>
                </div>
                <div class="col-md-3 mb-3">
                    <div class="modern-card fade-in">
                        <div class="modern-card-body text-center py-4">
                            <div class="stat-icon mb-3 pending-icon">
                                <i class="fa fa-clock"></i>
                            </div>
                            <h3 class="stat-value"><?php echo number_format($stats['pending_count']); ?></h3>
                            <p class="stat-label">Transaksi Pending</p>
                        </div>
                    </div>
                </div>
            </div>
            
            <!-- Filter Form -->
            <div class="modern-card mb-4 fade-in">
                <div class="modern-card-body">
                    <form action="" method="get" class="row g-3">
                        <div class="col-md-3">
                            <label class="modern-form-label">Jenis Transaksi</label>
                            <select name="type" class="modern-form-select">
                                <option value="">Semua Jenis</option>
                                <option value="deposit" <?php echo $filter_type == 'deposit' ? 'selected' : ''; ?>>Top-up</option>
                                <option value="withdrawal" <?php echo $filter_type == 'withdrawal' ? 'selected' : ''; ?>>Penarikan</option>
                                <option value="bid_hold" <?php echo $filter_type == 'bid_hold' ? 'selected' : ''; ?>>Hold Bid</option>
                                <option value="bid_release" <?php echo $filter_type == 'bid_release' ? 'selected' : ''; ?>>Release Bid</option>
                                <option value="winning_payment" <?php echo $filter_type == 'winning_payment' ? 'selected' : ''; ?>>Pembayaran Menang</option>
                            </select>
                        </div>
                        <div class="col-md-3">
                            <label class="modern-form-label">Status</label>
                            <select name="status" class="modern-form-select">
                                <option value="">Semua Status</option>
                                <option value="pending" <?php echo $filter_status == 'pending' ? 'selected' : ''; ?>>Pending</option>
                                <option value="completed" <?php echo $filter_status == 'completed' ? 'selected' : ''; ?>>Selesai</option>
                                <option value="rejected" <?php echo $filter_status == 'rejected' ? 'selected' : ''; ?>>Ditolak</option>
                            </select>
                        </div>
                        <div class="col-md-3">
                            <label class="modern-form-label">Periode</label>
                            <select name="period" class="modern-form-select">
                                <option value="">Semua Waktu</option>
                                <option value="today" <?php echo $filter_period == 'today' ? 'selected' : ''; ?>>Hari Ini</option>
                                <option value="week" <?php echo $filter_period == 'week' ? 'selected' : ''; ?>>Minggu Ini</option>
                                <option value="month" <?php echo $filter_period == 'month' ? 'selected' : ''; ?>>Bulan Ini</option>
                                <option value="year" <?php echo $filter_period == 'year' ? 'selected' : ''; ?>>Tahun Ini</option>
                            </select>
                        </div>
                        <div class="col-md-3 d-flex align-items-end">
                            <div class="d-grid gap-2 w-100">
                                <button type="submit" class="modern-button modern-button-primary">
                                    <i class="fa fa-filter me-2"></i>Filter
                                </button>
                                <a href="transactions-modern.php" class="modern-button modern-button-outline">
                                    <i class="fa fa-sync me-2"></i>Reset
                                </a>
                            </div>
                        </div>
                    </form>
                </div>
            </div>
            
            <!-- Transactions Table -->
            <div class="modern-card fade-in">
                <div class="modern-card-header">
                    <h3 class="modern-card-title"><i class="fa fa-history"></i> Riwayat Transaksi</h3>
                    <div class="modern-card-actions">
                        <a href="topup-modern.php" class="modern-button modern-button-primary modern-button-sm">
                            <i class="fa fa-plus me-2"></i>Top Up Baru
                        </a>
                    </div>
                </div>
                <div class="modern-card-body p-0">
                    <div class="table-responsive">
                        <table class="table modern-table">
                            <thead>
                                <tr>
                                    <th>ID</th>
                                    <th>Tanggal</th>
                                    <th>Jumlah</th>
                                    <th>Jenis</th>
                                    <th>Status</th>
                                    <th>Referensi</th>
                                    <th>Bukti</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php
                                if ($transactions_result && $transactions_result->num_rows > 0) {
                                    while ($transaction = $transactions_result->fetch_assoc()) {
                                        echo '<tr>';
                                        echo '<td>#' . $transaction['transaction_id'] . '</td>';
                                        echo '<td>' . date('d M Y H:i', strtotime($transaction['created_at'])) . '</td>';
                                        
                                        // Amount with color based on type
                                        $amount_class = in_array($transaction['type'], ['deposit', 'bid_release']) ? 'text-success' : 'text-danger';
                                        $prefix = in_array($transaction['type'], ['deposit', 'bid_release']) ? '+' : '-';
                                        echo '<td class="' . $amount_class . '">' . $prefix . ' ' . format_money($transaction['amount']) . '</td>';
                                        
                                        // Transaction type
                                        $type_badge = '';
                                        switch ($transaction['type']) {
                                            case 'deposit':
                                                $type_badge = '<span class="badge bg-success">Top-up</span>';
                                                break;
                                            case 'withdrawal':
                                                $type_badge = '<span class="badge bg-warning">Penarikan</span>';
                                                break;
                                            case 'bid_hold':
                                                $type_badge = '<span class="badge bg-info">Hold Bid</span>';
                                                break;
                                            case 'bid_release':
                                                $type_badge = '<span class="badge bg-secondary">Release Bid</span>';
                                                break;
                                            case 'winning_payment':
                                                $type_badge = '<span class="badge bg-primary">Pembayaran Menang</span>';
                                                break;
                                            default:
                                                $type_badge = '<span class="badge bg-secondary">' . ucfirst($transaction['type']) . '</span>';
                                        }
                                        echo '<td>' . $type_badge . '</td>';
                                        
                                        // Status badge
                                        $status_badge = '';
                                        switch ($transaction['status']) {
                                            case 'pending':
                                                $status_badge = '<span class="badge bg-warning">Menunggu Konfirmasi</span>';
                                                break;
                                            case 'completed':
                                                $status_badge = '<span class="badge bg-success">Selesai</span>';
                                                break;
                                            case 'rejected':
                                                $status_badge = '<span class="badge bg-danger">Ditolak</span>';
                                                break;
                                            default:
                                                $status_badge = '<span class="badge bg-secondary">' . ucfirst($transaction['status']) . '</span>';
                                        }
                                        echo '<td>' . $status_badge . '</td>';
                                        
                                        // Reference number
                                        echo '<td>' . ($transaction['reference_number'] ? $transaction['reference_number'] : '-') . '</td>';
                                        
                                        // Payment proof
                                        echo '<td>';
                                        if ($transaction['payment_proof']) {
                                            echo '<a href="' . $transaction['payment_proof'] . '" target="_blank" class="btn btn-sm btn-info"><i class="fa fa-image"></i></a>';
                                        } else if ($transaction['type'] == 'deposit' && $transaction['status'] == 'pending') {
                                            echo '<a href="upload-payment.php?id=' . $transaction['transaction_id'] . '" class="btn btn-sm btn-primary">Upload</a>';
                                        } else {
                                            echo '-';
                                        }
                                        echo '</td>';
                                        
                                        echo '</tr>';
                                    }
                                } else {
                                    echo '<tr><td colspan="7" class="text-center">Belum ada riwayat transaksi.</td></tr>';
                                }
                                ?>
                            </tbody>
                        </table>
                    </div>
                    
                    <?php if ($total_pages > 1): ?>
                    <div class="modern-pagination">
                        <nav aria-label="Page navigation">
                            <ul class="pagination justify-content-center">
                                <?php if ($current_page > 1): ?>
                                <li class="page-item">
                                    <a class="page-link" href="?page=<?php echo $current_page - 1; ?><?php echo !empty($filter_type) ? '&type=' . $filter_type : ''; ?><?php echo !empty($filter_status) ? '&status=' . $filter_status : ''; ?><?php echo !empty($filter_period) ? '&period=' . $filter_period : ''; ?>" aria-label="Previous">
                                        <span aria-hidden="true">&laquo;</span>
                                    </a>
                                </li>
                                <?php endif; ?>
                                
                                <?php for ($i = 1; $i <= $total_pages; $i++): ?>
                                <li class="page-item <?php echo $i == $current_page ? 'active' : ''; ?>">
                                    <a class="page-link" href="?page=<?php echo $i; ?><?php echo !empty($filter_type) ? '&type=' . $filter_type : ''; ?><?php echo !empty($filter_status) ? '&status=' . $filter_status : ''; ?><?php echo !empty($filter_period) ? '&period=' . $filter_period : ''; ?>">
                                        <?php echo $i; ?>
                                    </a>
                                </li>
                                <?php endfor; ?>
                                
                                <?php if ($current_page < $total_pages): ?>
                                <li class="page-item">
                                    <a class="page-link" href="?page=<?php echo $current_page + 1; ?><?php echo !empty($filter_type) ? '&type=' . $filter_type : ''; ?><?php echo !empty($filter_status) ? '&status=' . $filter_status : ''; ?><?php echo !empty($filter_period) ? '&period=' . $filter_period : ''; ?>" aria-label="Next">
                                        <span aria-hidden="true">&raquo;</span>
                                    </a>
                                </li>
                                <?php endif; ?>
                            </ul>
                        </nav>
                    </div>
                    <?php endif; ?>
                </div>
            </div>
            
            <!-- Transaction Info -->
            <div class="modern-card mt-4 fade-in">
                <div class="modern-card-header">
                    <h3 class="modern-card-title"><i class="fa fa-info-circle"></i> Informasi Transaksi</h3>
                </div>
                <div class="modern-card-body">
                    <div class="row">
                        <div class="col-md-6">
                            <div class="info-item">
                                <div class="info-icon">
                                    <i class="fa fa-arrow-down"></i>
                                </div>
                                <div class="info-content">
                                    <h5>Top-up Saldo</h5>
                                    <p>Top-up saldo akan diproses dalam 1x24 jam setelah bukti pembayaran diunggah dan diverifikasi oleh admin.</p>
                                </div>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="info-item">
                                <div class="info-icon">
                                    <i class="fa fa-arrow-up"></i>
                                </div>
                                <div class="info-content">
                                    <h5>Penarikan Saldo</h5>
                                    <p>Penarikan saldo akan diproses dalam 1-3 hari kerja setelah permintaan penarikan disetujui oleh admin.</p>
                                </div>
                            </div>
                        </div>
                        <div class="col-md-6 mt-4">
                            <div class="info-item">
                                <div class="info-icon">
                                    <i class="fa fa-gavel"></i>
                                </div>
                                <div class="info-content">
                                    <h5>Hold Bid</h5>
                                    <p>Saldo akan ditahan sementara saat Anda melakukan bid pada lelang. Saldo akan dikembalikan jika Anda kalah dalam lelang.</p>
                                </div>
                            </div>
                        </div>
                        <div class="col-md-6 mt-4">
                            <div class="info-item">
                                <div class="info-icon">
                                    <i class="fa fa-trophy"></i>
                                </div>
                                <div class="info-content">
                                    <h5>Pembayaran Menang</h5>
                                    <p>Saldo akan dipotong secara otomatis jika Anda memenangkan lelang. Pembayaran akan diteruskan ke penjual.</p>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<?php include("includes/footer.php"); ?>